---@class IXAudioSource
IXAudioSource = {}


---@type number @enum State
IXAudioSource.INITIAL = 0


---@type number @enum State
IXAudioSource.PLAYING = 0


---@type number @enum State
IXAudioSource.PAUSED = 0


---@type number @enum State
IXAudioSource.STOPPED = 0


---@public 获取音频Id
---@return number
function IXAudioSource:GetSourceId() end


---@public 获取音频资源文件名称
---@return string
function IXAudioSource:GetAudioFileName() end


---@public 播放音频
---@return void
function IXAudioSource:Play() end


---@public 停止播放音频
---@return void
function IXAudioSource:Stop() end


---@public 暂停音频
---@return void
function IXAudioSource:Pause() end


---@public 恢复音频
---@return void
function IXAudioSource:Resume() end


---@public 回放音频
---@return void
function IXAudioSource:Rewind() end


---@public 设置音频是否循环播放
---@param looped boolean 是否循环播放
---@return void
function IXAudioSource:SetLoop(looped) end


---@public 获取音频是否循环播放
---@return boolean 是否循环播放
function IXAudioSource:IsLooped() end


---@public 设置音频增益，注意音频增益与音量不同
---@param gain number 增益值Range:[0.0-]
---@return void
function IXAudioSource:SetGain(gain) end


---@public 获取音频增益，注意音频增益与音量不同
---@return number 增益值Range:[0.0-]
function IXAudioSource:GetGain() end


---@public 设置音高
---@param pitch number
---@return void
function IXAudioSource:SetPitch(pitch) end


---@public 获取音高
---@return number 音高
function IXAudioSource:GetPitch() end


---@public 设置音频距离
---@param distance number 音频相对距离
---@return void
function IXAudioSource:SetMinDistance(distance) end


---@public 设置音频衰减系数
---@param attenuation number 衰减系数
---@return void
function IXAudioSource:SetAttenuation(attenuation) end


---@public 获取音频速度
---@return XVECTOR3 音频速度
function IXAudioSource:GetVelocity() end


---@public 设置音频速度
---@param location XVECTOR3
---@return void
function IXAudioSource:SetVelocity(location) end


---@public 设置音频速度
---@param x number 在X方向上的速度值
---@param y number 在Y方向上的速度值
---@param z number 在Z方向上的速度值
---@return void
function IXAudioSource:SetVelocity(x, y, z) end


---@public 获取音频位置
---@return XVECTOR3 音频位置
function IXAudioSource:GetLocation() end


---@public 设置音频位置
---@param velocity XVECTOR3 位置值(x,y,z)
---@return void
function IXAudioSource:SetLocation(velocity) end


---@public 设置音频位置
---@param x number 在X方向上的位置值
---@param y number 在Y方向上的位置值
---@param z number 在Z方向上的位置值
---@return void
function IXAudioSource:SetLocation(x, y, z) end


---@public 设置音频位置
---@param transform XMATRIX4 矩阵，包含位置偏移
---@return void
function IXAudioSource:SetTransform(transform) end


---@public 获取音频当前播放时间
---@return number 当前播放时间（单位：秒）
function IXAudioSource:GetAudioCurrentTime() end


---@public 设置音频播放的时间，即播放偏移
---@param time number 定位播放时间，即播放偏移（单位：秒）
---@return void
function IXAudioSource:Seek(time) end


---@public 获取音频总时长
---@return number
function IXAudioSource:GetAudioDuration() end


---@public 获取音频状态，包括初始化，播放，暂停，停止
---@return number 音频状态
function IXAudioSource:GetState() end


