---粒子模板接口类
---@class IFxTemplate
IFxTemplate = {}


---@public 获取名称
---@return string 名称字符串
function IFxTemplate:GetName() end


---@public 获取粒子元素个数
---@return number 粒子元素个数
function IFxTemplate:GetElementNum() end


---@public 根据索引获取对应的粒子元素
---@param nIndex number 元素索引
---@return FxElement 粒子元素个数
function IFxTemplate:GetElement(nIndex) end


---@public 添加粒子元素
---@param szName string 元素名称
---@param eType number 元素类型
---@return FxElement 添加的粒子元素指针
function IFxTemplate:AddElement(szName, eType) end


---@public 添加粒子元素
---@param pElement FxElement 添加的粒子元素
---@return boolean 是否添加成功
function IFxTemplate:AddElement(pElement) end


---@public 移除某个粒子元素
---@param nIndex number 要移除的元素索引
---@param bDelete boolean 是否同时销毁元素
---@return boolean 是否移除成功
function IFxTemplate:RemoveElement(nIndex, bDelete) end


---@public 移除某个粒子元素
---@param pElement FxElement 要移除的元素指针
---@param bDelete boolean 是否同时销毁元素
---@return boolean 是否移除成功
function IFxTemplate:RemoveElement(pElement, bDelete) end


---@public 移动某个粒子元素在数组中的位置
---@param pElement FxElement 要移动的元素指针
---@param nMoveAmount number 移动距离，正数为向数组尾移动，负数为向数组头移动
---@return boolean 是否移动成功
function IFxTemplate:MoveElement(pElement, nMoveAmount) end


---@public 复制某个粒子元素
---@param nIndex number 要复制的元素索引
---@return boolean 是否复制成功
function IFxTemplate:DumplicateElement(nIndex) end


---@public 复制某个粒子元素
---@param pElement FxElement 要复制的元素指针
---@return boolean 是否复制成功
function IFxTemplate:DumplicateElement(pElement) end


---@public 获取版本号
---@return number 是否复制成功
function IFxTemplate:GetFileVersion() end


---粒子实例接口类
---@class IFxInstance
IFxInstance = {}


---@public 播放粒子特效
---@return void
function IFxInstance:Play() end


---@public 暂停播放粒子特效
---@return void
function IFxInstance:Pause() end


---@public 判断是否暂定播放状态
---@return boolean 是否暂停
function IFxInstance:IsPaused() end


---@public 停止播放
---@param bClearNow boolean 是否立即清除资源，默认为false
---@return void
function IFxInstance:Stop(bClearNow) end


---@public 重新从头播放粒子特效
---@return void
function IFxInstance:Restart() end


---@public 判断是否播放完毕
---@return boolean 是否播放完毕
function IFxInstance:IsCompleted() end


---@public 设置粒子是否为2D模式
---@param b2DRenderMode boolean 是否为2D模式
---@return void
function IFxInstance:Set2DMode(b2DRenderMode) end


---@public 是否为2D模式
---@return boolean 是否为2D模式
function IFxInstance:Is2DMode() end


---@public 设置粒子的层级
---@param pLayer number 在UI前（LO_BeforeUI）或UI后（LO_AfterUI），LO_BetweenUI在当前不起作用
---@return void
function IFxInstance:Set2DModeLayerMask(pLayer) end


---@public 设置是否开启屏幕空间的裁剪
---@param bEnable boolean 是否开启
---@return void
function IFxInstance:EnableScreenMask(bEnable) end


---@public 获取是否开启屏幕空间的裁剪
---@return boolean 是否开启
function IFxInstance:IsScreenMaskEnabled() end


---@public 设置屏幕空间的裁剪区域
---@param vRegion XVECTOR4 裁剪区域xy左下角坐标zw右上角坐标
---@return void
function IFxInstance:SetScreenMaskRegion(vRegion) end


---@public 获取屏幕空间的裁剪区域
---@return XVECTOR4 裁剪区域
function IFxInstance:GetScreenMaskRegion() end


---@public 获取粒子的AABB
---@return  XCusAABB AABB
function IFxInstance:GetAABB() end


---@public 获取粒子特效实例模板指针
---@return IFxTemplate 粒子特效实例模板指针
function IFxInstance:GetFxTemplate() end


---@public 设置骨骼拖尾发射器使用的骨骼
---@param pSkeleton XSkeleton 指定的骨骼指针
---@param FirstBoneName string 父关节名称
---@param SecondBoneName string 子关节名称
---@return number 1:成功0:不包含骨骼拖尾发射器-1:骨骼错误-2:骨骼中找不到父关节-3:骨骼中找不到子关节-4:骨骼中父子关节均找不到
function IFxInstance:SetAnimTrailBindingSkeletonAndBones(pSkeleton, FirstBoneName, SecondBoneName) end


---@public 设置激光发射器发射点位置
---@param EmitterName string 发射器名称
---@param Positions XVECTOR3[] 位置信息
---@return boolean 是否成功
function IFxInstance:SetBeamEmitterSourcePoints(EmitterName, Positions) end


---@public 设置激光发射器目标点位置
---@param EmitterName string 发射器名称
---@param Positions XVECTOR3[] 位置信息
---@return boolean 是否成功
function IFxInstance:SetBeamEmitterTargetPoints(EmitterName, Positions) end


---粒子管理器接口类
---@class IFxManager
IFxManager = {}


---@public 根据模板文件创建一个特效实例
---@param szFxTemplateFile string 模板文件路径名
---@param pLoadInfo string
---@return IFxInstance 粒子特效实例指针
function IFxManager:GetFxInstance(szFxTemplateFile, pLoadInfo) end


---@public 新建一个特效实例，在内存中直接创建
---@param szNewFxTemplateFile string 新建模板文件路径名
---@return IFxInstance 粒子特效实例指针
function IFxManager:CreateFxInstance(szNewFxTemplateFile) end


---@public 将一个FxTemplate对象存到硬盘
---@param szFxTemplateFile string 存储文件路径
---@param pTemplate IFxTemplate 要存储的对象指针
---@return boolean 是否存储成功
function IFxManager:SaveFxTemplate(szFxTemplateFile, pTemplate) end


---@public 设置是否合批渲染
---@param bEnable boolean 是否合批渲染
---@return void
function IFxManager:SetBatchEnabled(bEnable) end


---@public 获取是否合批渲染
---@return boolean 是否合批渲染
function IFxManager:IsBatchEnabled() end


---@public 设置同一层级的粒子是否强制合批(不考虑先后顺序)
---@param bForce boolean
---@return void
function IFxManager:ForceBatchInSameLayer(bForce) end


---@public 获取同一层级的粒子是否强制合批
---@return boolean 是否强制合批
function IFxManager:IsForceBatchInSameLayer() end


---@public 设置合批的最大顶点数
---@param nMaxNum number
---@return void
function IFxManager:SetMaxBatchedVertexNum(nMaxNum) end


---@public 获取同一层级的粒子是否强制合批
---@return number 合批的最大顶点数
function IFxManager:GetMaxBatchedVertexNum() end


---@public 重加载fx模板
---@param szFxTemplateFile string
---@param pLoadInfo string
---@return boolean 是否重加载成功
function IFxManager:ReloadFxTemplate(szFxTemplateFile, pLoadInfo) end


