---@type number @enum X2DJointType
X_2DPHYSICS_JT_UNKNOWN = 0


---@type number @enum X2DJointType
X_2DPHYSICS_JT_REVOLUTE = 0


---@type number @enum X2DJointType
X_2DPHYSICS_JT_PRISMATIC = 0


---@type number @enum X2DJointType
X_2DPHYSICS_JT_DISTANCE = 0


---@type number @enum X2DJointType
X_2DPHYSICS_JT_PULLEY = 0


---@type number @enum X2DJointType
X_2DPHYSICS_JT_MOUSE = 0


---@type number @enum X2DJointType
X_2DPHYSICS_JT_GEAR = 0


---@type number @enum X2DJointType
X_2DPHYSICS_JT_WHEEL = 0


---@type number @enum X2DJointType
X_2DPHYSICS_JT_WELD = 0


---@type number @enum X2DJointType
X_2DPHYSICS_JT_FRICTION = 0


---@type number @enum X2DJointType
X_2DPHYSICS_JT_ROPE = 0


---@type number @enum X2DJointType
X_2DPHYSICS_JT_MOTOR = 0


---这是关节描述类型的基类，保存所有关节的共同属性
---本类用于创建一个关节，见IX2DPhysicalScene::CreateJoint(const X2DJointDesc& desc)
---@class X2DJointDesc
X2DJointDesc = {}


---@public X2DJointDesc_new00
---@return X2DJointDesc
function X2DJointDesc:new() end


---@type number
X2DJointDesc.eType = 0


---@type userdata
X2DJointDesc.pUserData = {}


---@type IX2DRigidBody
X2DJointDesc.pBodyA = {}


---@type IX2DRigidBody
X2DJointDesc.pBodyB = {}


---@type boolean
X2DJointDesc.bCollideConnected = false


---旋转关节的描述类型
---旋转关节会强制两个物体共享一个锚点
---@class X2DRevoluteJointDesc : X2DJointDesc
X2DRevoluteJointDesc = {}


---@public X2DRevoluteJointDesc_new00
---@return X2DRevoluteJointDesc
function X2DRevoluteJointDesc:new() end


---@public 初始化一个X2DRevoluteJointDesc
---@param pA IX2DRigidBody 刚体B
---@param pB IX2DRigidBody
---@param vAnchor XVECTOR2 连接锚点
---@return boolean 成功返回xtrue,失败返回xfalse
function X2DRevoluteJointDesc:Init(pA, pB, vAnchor) end


---@type XVECTOR2 锚点相对A的位置
X2DRevoluteJointDesc.vLocalAnchorA = {}


---@type XVECTOR2 锚点相对B的位置
X2DRevoluteJointDesc.vLocalAnchorB = {}


---@type number A与B的相对角度
X2DRevoluteJointDesc.fReferenceAngle = 0


---@type boolean 是否开启限制
X2DRevoluteJointDesc.bEnableLimit = false


---@type number 最小角度限制
X2DRevoluteJointDesc.fLowerAngle = 0


---@type number 最大角度限制
X2DRevoluteJointDesc.fUpperAngle = 0


---@type boolean 开启关节马达（角速度）
X2DRevoluteJointDesc.bEnableMotor = false


---@type number 最大角速度限制
X2DRevoluteJointDesc.fMotorSpeed = 0


---@type number 最大扭矩
X2DRevoluteJointDesc.fMaxMotorTorque = 0


---移动关节的描述类型
---移动关节允许两个物体沿指定轴相对移动，它会阻止相对旋转。
---@class X2DPrismaticJointDesc : X2DJointDesc
X2DPrismaticJointDesc = {}


---@public X2DPrismaticJointDesc_new00
---@return X2DPrismaticJointDesc
function X2DPrismaticJointDesc:new() end


---@public 初始化一个X2DRevoluteJointDesc
---@param pA IX2DRigidBody 刚体B
---@param pB IX2DRigidBody
---@param vAnchor XVECTOR2 连接锚点
---@param vAxis XVECTOR2
---@return boolean 成功返回xtrue,失败返回xfalse
function X2DPrismaticJointDesc:Init(pA, pB, vAnchor, vAxis) end


---@type XVECTOR2 锚点相对A的位置
X2DPrismaticJointDesc.vLocalAnchorA = {}


---@type XVECTOR2 锚点相对B的位置
X2DPrismaticJointDesc.vLocalAnchorB = {}


---@type XVECTOR2 移动轴向
X2DPrismaticJointDesc.vLocalAxisA = {}


---@type number A与B的相对角度
X2DPrismaticJointDesc.fReferenceAngle = 0


---@type boolean 是否开启限制
X2DPrismaticJointDesc.bEnableLimit = false


---@type number 最小移动距离限制
X2DPrismaticJointDesc.fLowerTranslation = 0


---@type number 最大移动距离限制
X2DPrismaticJointDesc.fUpperTranslation = 0


---@type boolean 开启关节马达（角速度）
X2DPrismaticJointDesc.bEnableMotor = false


---@type number 最大角速度限制
X2DPrismaticJointDesc.fMotorSpeed = 0


---@type number 最大摩擦力
X2DPrismaticJointDesc.fMaxMotorForce = 0


---距离关节的描述类型
---两个物体上面各自有一点，两点之间的距离必须固定不变
---@class X2DDistanceJointDesc : X2DJointDesc
X2DDistanceJointDesc = {}


---@public X2DDistanceJointDesc_new00
---@return X2DDistanceJointDesc
function X2DDistanceJointDesc:new() end


---@public 初始化一个X2DRevoluteJointDesc
---@param pA IX2DRigidBody 刚体B
---@param pB IX2DRigidBody
---@param vAnchorA XVECTOR2
---@param vAnchorB XVECTOR2 连接锚点
---@return boolean 成功返回xtrue,失败返回xfalse
function X2DDistanceJointDesc:Init(pA, pB, vAnchorA, vAnchorB) end


---@type XVECTOR2 锚点相对A的位置
X2DDistanceJointDesc.vLocalAnchorA = {}


---@type XVECTOR2 锚点相对B的位置
X2DDistanceJointDesc.vLocalAnchorB = {}


---@type number 锚点之间的距离
X2DDistanceJointDesc.fLength = 0


---@type number 弹性的频率
X2DDistanceJointDesc.fFrequencyHz = 0


---@type number 弹性的阻尼率
X2DDistanceJointDesc.fDampingRatio = 0


---滑轮关节的描述类型
---滑轮关节将两个物体接地并彼此连接。
---@class X2DPulleyJointDesc : X2DJointDesc
X2DPulleyJointDesc = {}


---@public X2DPulleyJointDesc_new00
---@return X2DPulleyJointDesc
function X2DPulleyJointDesc:new() end


---@public 初始化一个X2DRevoluteJointDesc
---@param pA IX2DRigidBody 刚体B
---@param pB IX2DRigidBody
---@param vGAnchorA XVECTOR2
---@param vGAnchorB XVECTOR2
---@param vAnchorA XVECTOR2
---@param vAnchorB XVECTOR2 连接锚点
---@param ratio number
---@return boolean 成功返回xtrue,失败返回xfalse
function X2DPulleyJointDesc:Init(pA, pB, vGAnchorA, vGAnchorB, vAnchorA, vAnchorB, ratio) end


---@type XVECTOR2 地面的位置
X2DPulleyJointDesc.vGroundAnchorA = {}


---@type XVECTOR2 地面位置
X2DPulleyJointDesc.vGroundAnchorB = {}


---@type XVECTOR2 锚点相对A的位置
X2DPulleyJointDesc.vLocalAnchorA = {}


---@type XVECTOR2 锚点相对B的位置
X2DPulleyJointDesc.vLocalAnchorB = {}


---@type number 滑轮绳子初始长度
X2DPulleyJointDesc.fLengthA = 0


---@type number 滑轮绳子初始长度
X2DPulleyJointDesc.fLengthB = 0


---@type number 滑轮系数
X2DPulleyJointDesc.fRatio = 0


---鼠标关节的描述类型
---鼠标关节通过给定一个目标点来操控物体。
---@class X2DMouseJointDesc : X2DJointDesc
X2DMouseJointDesc = {}


---@public X2DMouseJointDesc_new00
---@return X2DMouseJointDesc
function X2DMouseJointDesc:new() end


---@type XVECTOR2 目标点的位置
X2DMouseJointDesc.vTarget = {}


---@type number 最大力量
X2DMouseJointDesc.fMaxForce = 0


---@type number 弹性的频率
X2DMouseJointDesc.fFrequencyHz = 0


---@type number 弹性的阻尼率
X2DMouseJointDesc.fDampingRatio = 0


---齿轮关节的描述类型
---齿轮关节用于连接旋转关节和移动关节
---齿轮关节总应该先于旋转或移动关节被删除。
---@class X2DGearJointDesc : X2DJointDesc
X2DGearJointDesc = {}


---@public X2DGearJointDesc_new00
---@return X2DGearJointDesc
function X2DGearJointDesc:new() end


---@type IX2DJoint 关节1
X2DGearJointDesc.pJointA = {}


---@type IX2DJoint 关节2
X2DGearJointDesc.pJointB = {}


---@type number 滑轮系数
X2DGearJointDesc.fRatio = 0


---轮子关节的描述类型
---轮子关节限制bodyB上的一个点到bodyA的一条线上。
---@class X2DWheelJointDesc : X2DJointDesc
X2DWheelJointDesc = {}


---@public X2DWheelJointDesc_new00
---@return X2DWheelJointDesc
function X2DWheelJointDesc:new() end


---@public 初始化一个X2DRevoluteJointDesc
---@param pA IX2DRigidBody 刚体B
---@param pB IX2DRigidBody
---@param vAnchor XVECTOR2 连接锚点
---@param vAxis XVECTOR2
---@return boolean 成功返回xtrue,失败返回xfalse
function X2DWheelJointDesc:Init(pA, pB, vAnchor, vAxis) end


---@type XVECTOR2 锚点相对A的位置
X2DWheelJointDesc.vLocalAnchorA = {}


---@type XVECTOR2 锚点相对B的位置
X2DWheelJointDesc.vLocalAnchorB = {}


---@type XVECTOR2 移动轴向
X2DWheelJointDesc.vLocalAxisA = {}


---@type boolean 开启关节马达（角速度）
X2DWheelJointDesc.bEnableMotor = false


---@type number 最大扭矩
X2DWheelJointDesc.fMaxMotorTorque = 0


---@type number 最大角速度限制
X2DWheelJointDesc.fMotorSpeed = 0


---@type number 弹性的频率
X2DWheelJointDesc.fFrequencyHz = 0


---@type number 弹性的阻尼率
X2DWheelJointDesc.fDampingRatio = 0


---焊接关节的描述类型
---焊接关节的用途是使两个物体不能相对运动
---@class X2DWeldJointDesc : X2DJointDesc
X2DWeldJointDesc = {}


---@public X2DWeldJointDesc_new00
---@return X2DWeldJointDesc
function X2DWeldJointDesc:new() end


---@public 初始化一个X2DRevoluteJointDesc
---@param pA IX2DRigidBody 刚体B
---@param pB IX2DRigidBody
---@param vAnchor XVECTOR2 连接锚点
---@return boolean 成功返回xtrue,失败返回xfalse
function X2DWeldJointDesc:Init(pA, pB, vAnchor) end


---@type XVECTOR2 锚点相对A的位置
X2DWeldJointDesc.vLocalAnchorA = {}


---@type XVECTOR2 锚点相对B的位置
X2DWeldJointDesc.vLocalAnchorB = {}


---@type number A与B的相对角度
X2DWeldJointDesc.fReferenceAngle = 0


---@type number 弹性的频率
X2DWeldJointDesc.fFrequencyHz = 0


---@type number 弹性的阻尼率
X2DWeldJointDesc.fDampingRatio = 0


---摩擦关节的描述类型
---用于模拟上下摩擦
---@class X2DFrictionJointDesc : X2DJointDesc
X2DFrictionJointDesc = {}


---@public X2DFrictionJointDesc_new00
---@return X2DFrictionJointDesc
function X2DFrictionJointDesc:new() end


---@public 初始化一个X2DRevoluteJointDesc
---@param pA IX2DRigidBody 刚体B
---@param pB IX2DRigidBody
---@param vAnchor XVECTOR2 连接锚点
---@return boolean 成功返回xtrue,失败返回xfalse
function X2DFrictionJointDesc:Init(pA, pB, vAnchor) end


---@type XVECTOR2 锚点相对A的位置
X2DFrictionJointDesc.vLocalAnchorA = {}


---@type XVECTOR2 锚点相对B的位置
X2DFrictionJointDesc.vLocalAnchorB = {}


---@type number 最大力量
X2DFrictionJointDesc.fMaxForce = 0


---@type number 最大扭矩
X2DFrictionJointDesc.fMaxTorque = 0


---绳子关节的描述类型
---绳子关节限制了两个点之间的最大距离
---@class X2DRopeJointDesc : X2DJointDesc
X2DRopeJointDesc = {}


---@public X2DRopeJointDesc_new00
---@return X2DRopeJointDesc
function X2DRopeJointDesc:new() end


---@type XVECTOR2 锚点相对A的位置
X2DRopeJointDesc.vLocalAnchorA = {}


---@type XVECTOR2 锚点相对B的位置
X2DRopeJointDesc.vLocalAnchorB = {}


---@type number 最大长度
X2DRopeJointDesc.fMaxLength = 0


---马达关节的描述类型
---马达关节通过指定目标位置和旋转偏移来控制物体的移动。
---@class X2DMotorJointDesc : X2DJointDesc
X2DMotorJointDesc = {}


---@public X2DMotorJointDesc_new00
---@return X2DMotorJointDesc
function X2DMotorJointDesc:new() end


---@public 初始化一个X2DRevoluteJointDesc
---@param pA IX2DRigidBody 刚体B
---@param pB IX2DRigidBody
---@return boolean 成功返回xtrue,失败返回xfalse
function X2DMotorJointDesc:Init(pA, pB) end


---@type XVECTOR2 位置偏移
X2DMotorJointDesc.vLinearOffset = {}


---@type number 角度便宜
X2DMotorJointDesc.fAngularOffset = 0


---@type number 最大力量
X2DMotorJointDesc.fMaxForce = 0


---@type number 最大扭矩
X2DMotorJointDesc.fMaxTorque = 0


---@type number 校正因子
X2DMotorJointDesc.fCorrectionFactor = 0


---关节基类
---@class IX2DJoint
IX2DJoint = {}


---@public 返回关节类型
---@return number 关节类型
function IX2DJoint:GetType() end


---@public 获取关节连接的刚体A
---@return IX2DRigidBody 刚体A
function IX2DJoint:GetBodyA() end


---@public 获取关节连接的刚体B
---@return IX2DRigidBody 刚体B
function IX2DJoint:GetBodyB() end


---@public 获取用户自定义数据
---@return userdata 用户自定义数据
function IX2DJoint:GetUserData() end


---@public 设置用户自定义数据
---@param pUserData userdata
---@return void
function IX2DJoint:SetUserData(pUserData) end


---@public 是否激活
---@return boolean
function IX2DJoint:IsActive() end


---@public 获取关节在刚体A上的锚点
---@return XVECTOR2 锚点位置
function IX2DJoint:GetAnchorA() end


---@public 获取关节在刚体B上的锚点
---@return XVECTOR2 锚点位置
function IX2DJoint:GetAnchorB() end


---@public 获取关节的力大小
---@param inv_dt number
---@return XVECTOR2 力
function IX2DJoint:GetReactionForce(inv_dt) end


---@public 获取关节的扭矩
---@param inv_dt number
---@return number 扭矩
function IX2DJoint:GetReactionTorque(inv_dt) end


---旋转关节类
---@class IX2DRevoluteJoint : IX2DJoint
IX2DRevoluteJoint = {}


---@public 请参考描述类
---@return XVECTOR2
function IX2DRevoluteJoint:GetLocalAnchorA() end


---@public 请参考描述类
---@return XVECTOR2
function IX2DRevoluteJoint:GetLocalAnchorB() end


---@public 请参考描述类
---@return number
function IX2DRevoluteJoint:GetReferenceAngle() end


---@public 请参考描述类
---@return number
function IX2DRevoluteJoint:GetJointAngle() end


---@public 请参考描述类
---@return number
function IX2DRevoluteJoint:GetJointSpeed() end


---@public 请参考描述类
---@return boolean
function IX2DRevoluteJoint:IsLimitEnabled() end


---@public 请参考描述类
---@param flag boolean
---@return void
function IX2DRevoluteJoint:EnableLimit(flag) end


---@public 请参考描述类
---@return number
function IX2DRevoluteJoint:GetLowerLimit() end


---@public 请参考描述类
---@return number
function IX2DRevoluteJoint:GetUpperLimit() end


---@public 请参考描述类
---@param lower number
---@param upper number
---@return void
function IX2DRevoluteJoint:SetLimits(lower, upper) end


---@public 请参考描述类
---@return boolean
function IX2DRevoluteJoint:IsMotorEnabled() end


---@public 请参考描述类
---@param flag boolean
---@return void
function IX2DRevoluteJoint:EnableMotor(flag) end


---@public 请参考描述类
---@param speed number
---@return void
function IX2DRevoluteJoint:SetMotorSpeed(speed) end


---@public 请参考描述类
---@return number
function IX2DRevoluteJoint:GetMotorSpeed() end


---@public 请参考描述类
---@param torque number
---@return void
function IX2DRevoluteJoint:SetMaxMotorTorque(torque) end


---@public 请参考描述类
---@return number
function IX2DRevoluteJoint:GetMaxMotorTorque() end


---移动关节类
---@class IX2DPrismaticJoint : IX2DJoint
IX2DPrismaticJoint = {}


---@public 请参考描述类
---@return XVECTOR2
function IX2DPrismaticJoint:GetLocalAnchorA() end


---@public 请参考描述类
---@return XVECTOR2
function IX2DPrismaticJoint:GetLocalAnchorB() end


---@public 请参考描述类
---@return XVECTOR2
function IX2DPrismaticJoint:GetLocalAxisA() end


---@public 请参考描述类
---@return number
function IX2DPrismaticJoint:GetReferenceAngle() end


---@public 请参考描述类
---@return number
function IX2DPrismaticJoint:GetJointTranslation() end


---@public 请参考描述类
---@return number
function IX2DPrismaticJoint:GetJointSpeed() end


---@public 请参考描述类
---@return boolean
function IX2DPrismaticJoint:IsLimitEnabled() end


---@public 请参考描述类
---@param flag boolean
---@return void
function IX2DPrismaticJoint:EnableLimit(flag) end


---@public 请参考描述类
---@return number
function IX2DPrismaticJoint:GetLowerLimit() end


---@public 请参考描述类
---@return number
function IX2DPrismaticJoint:GetUpperLimit() end


---@public 请参考描述类
---@param lower number
---@param upper number
---@return void
function IX2DPrismaticJoint:SetLimits(lower, upper) end


---@public 请参考描述类
---@return boolean
function IX2DPrismaticJoint:IsMotorEnabled() end


---@public 请参考描述类
---@param flag boolean
---@return void
function IX2DPrismaticJoint:EnableMotor(flag) end


---@public 请参考描述类
---@param speed number
---@return void
function IX2DPrismaticJoint:SetMotorSpeed(speed) end


---@public 请参考描述类
---@return number
function IX2DPrismaticJoint:GetMotorSpeed() end


---@public 请参考描述类
---@param force number
---@return void
function IX2DPrismaticJoint:SetMaxMotorForce(force) end


---@public 请参考描述类
---@return number
function IX2DPrismaticJoint:GetMaxMotorForce() end


---@public 请参考描述类
---@param inv_dt number
---@return number
function IX2DPrismaticJoint:GetMotorForce(inv_dt) end


---距离关节类
---@class IX2DDistanceJoint : IX2DJoint
IX2DDistanceJoint = {}


---@public 请参考描述类
---@return XVECTOR2
function IX2DDistanceJoint:GetLocalAnchorA() end


---@public 请参考描述类
---@return XVECTOR2
function IX2DDistanceJoint:GetLocalAnchorB() end


---@public 请参考描述类
---@param length number
---@return void
function IX2DDistanceJoint:SetLength(length) end


---@public 请参考描述类
---@return number
function IX2DDistanceJoint:GetLength() end


---@public 请参考描述类
---@param hz number
---@return void
function IX2DDistanceJoint:SetFrequency(hz) end


---@public 请参考描述类
---@return number
function IX2DDistanceJoint:GetFrequency() end


---@public 请参考描述类
---@param ratio number
---@return void
function IX2DDistanceJoint:SetDampingRatio(ratio) end


---@public 请参考描述类
---@return number
function IX2DDistanceJoint:GetDampingRatio() end


---滑轮关节类
---@class IX2DPulleyJoint : IX2DJoint
IX2DPulleyJoint = {}


---@public 请参考描述类
---@return XVECTOR2
function IX2DPulleyJoint:GetGroundAnchorA() end


---@public 请参考描述类
---@return XVECTOR2
function IX2DPulleyJoint:GetGroundAnchorB() end


---@public 请参考描述类
---@return number
function IX2DPulleyJoint:GetLengthA() end


---@public 请参考描述类
---@return number
function IX2DPulleyJoint:GetLengthB() end


---@public 请参考描述类
---@return number
function IX2DPulleyJoint:GetRatio() end


---@public 请参考描述类
---@return number
function IX2DPulleyJoint:GetCurrentLengthA() end


---@public 请参考描述类
---@return number
function IX2DPulleyJoint:GetCurrentLengthB() end


---鼠标关节类
---@class IX2DMouseJoint : IX2DJoint
IX2DMouseJoint = {}


---@public 请参考描述类
---@param target XVECTOR2
---@return void
function IX2DMouseJoint:SetTarget(target) end


---@public 请参考描述类
---@return XVECTOR2
function IX2DMouseJoint:GetTarget() end


---@public 请参考描述类
---@param force number
---@return void
function IX2DMouseJoint:SetMaxForce(force) end


---@public 请参考描述类
---@return number
function IX2DMouseJoint:GetMaxForce() end


---@public 请参考描述类
---@param hz number
---@return void
function IX2DMouseJoint:SetFrequency(hz) end


---@public 请参考描述类
---@return number
function IX2DMouseJoint:GetFrequency() end


---@public 请参考描述类
---@param ratio number
---@return void
function IX2DMouseJoint:SetDampingRatio(ratio) end


---@public 请参考描述类
---@return number
function IX2DMouseJoint:GetDampingRatio() end


---齿轮关节类
---@class IX2DGearJoint : IX2DJoint
IX2DGearJoint = {}


---@public 请参考描述类
---@return IX2DJoint
function IX2DGearJoint:GetJointA() end


---@public 请参考描述类
---@return IX2DJoint
function IX2DGearJoint:GetJointB() end


---@public 请参考描述类
---@param fRatio number
---@return void
function IX2DGearJoint:SetRatio(fRatio) end


---@public 请参考描述类
---@return number
function IX2DGearJoint:GetRatio() end


---轮子关节类
---@class IX2DWheelJoint : IX2DJoint
IX2DWheelJoint = {}


---@public 请参考描述类
---@return XVECTOR2
function IX2DWheelJoint:GetLocalAnchorA() end


---@public 请参考描述类
---@return XVECTOR2
function IX2DWheelJoint:GetLocalAnchorB() end


---@public 请参考描述类
---@return XVECTOR2
function IX2DWheelJoint:GetLocalAxisA() end


---@public 请参考描述类
---@return number
function IX2DWheelJoint:GetJointTranslation() end


---@public 请参考描述类
---@return number
function IX2DWheelJoint:GetJointLinearSpeed() end


---@public 请参考描述类
---@return number
function IX2DWheelJoint:GetJointAngle() end


---@public 请参考描述类
---@return number
function IX2DWheelJoint:GetJointAngularSpeed() end


---@public 请参考描述类
---@return boolean
function IX2DWheelJoint:IsMotorEnabled() end


---@public 请参考描述类
---@param flag boolean
---@return void
function IX2DWheelJoint:EnableMotor(flag) end


---@public 请参考描述类
---@param speed number
---@return void
function IX2DWheelJoint:SetMotorSpeed(speed) end


---@public 请参考描述类
---@return number
function IX2DWheelJoint:GetMotorSpeed() end


---@public 请参考描述类
---@param torque number
---@return void
function IX2DWheelJoint:SetMaxMotorTorque(torque) end


---@public 请参考描述类
---@return number
function IX2DWheelJoint:GetMaxMotorTorque() end


---@public 请参考描述类
---@param inv_dt number
---@return number
function IX2DWheelJoint:GetMotorTorque(inv_dt) end


---@public 请参考描述类
---@param hz number
---@return void
function IX2DWheelJoint:SetSpringFrequencyHz(hz) end


---@public 请参考描述类
---@return number
function IX2DWheelJoint:GetSpringFrequencyHz() end


---@public 请参考描述类
---@param ratio number
---@return void
function IX2DWheelJoint:SetSpringDampingRatio(ratio) end


---@public 请参考描述类
---@return number
function IX2DWheelJoint:GetSpringDampingRatio() end


---焊接关节类
---@class IX2DWeldJoint : IX2DJoint
IX2DWeldJoint = {}


---@public 请参考描述类
---@return XVECTOR2
function IX2DWeldJoint:GetLocalAnchorA() end


---@public 请参考描述类
---@return XVECTOR2
function IX2DWeldJoint:GetLocalAnchorB() end


---@public 请参考描述类
---@return number
function IX2DWeldJoint:GetReferenceAngle() end


---@public 请参考描述类
---@param hz number
---@return void
function IX2DWeldJoint:SetFrequency(hz) end


---@public 请参考描述类
---@return number
function IX2DWeldJoint:GetFrequency() end


---@public 请参考描述类
---@param ratio number
---@return void
function IX2DWeldJoint:SetDampingRatio(ratio) end


---@public 请参考描述类
---@return number
function IX2DWeldJoint:GetDampingRatio() end


---摩擦关节类
---@class IX2DFrictionJoint : IX2DJoint
IX2DFrictionJoint = {}


---@public 请参考描述类
---@return XVECTOR2
function IX2DFrictionJoint:GetLocalAnchorA() end


---@public 请参考描述类
---@return XVECTOR2
function IX2DFrictionJoint:GetLocalAnchorB() end


---@public 请参考描述类
---@param force number
---@return void
function IX2DFrictionJoint:SetMaxForce(force) end


---@public 请参考描述类
---@return number
function IX2DFrictionJoint:GetMaxForce() end


---@public 请参考描述类
---@param torque number
---@return void
function IX2DFrictionJoint:SetMaxTorque(torque) end


---@public 请参考描述类
---@return number
function IX2DFrictionJoint:GetMaxTorque() end


---绳索关节类
---@class IX2DRopeJoint : IX2DJoint
IX2DRopeJoint = {}


---@public 请参考描述类
---@return XVECTOR2
function IX2DRopeJoint:GetLocalAnchorA() end


---@public 请参考描述类
---@return XVECTOR2
function IX2DRopeJoint:GetLocalAnchorB() end


---@public 请参考描述类
---@param length number
---@return void
function IX2DRopeJoint:SetMaxLength(length) end


---@public 请参考描述类
---@return number
function IX2DRopeJoint:GetMaxLength() end


---马达关节类
---@class IX2DMotorJoint : IX2DJoint
IX2DMotorJoint = {}


---@public 请参考描述类
---@param linearOffset XVECTOR2
---@return void
function IX2DMotorJoint:SetLinearOffset(linearOffset) end


---@public 请参考描述类
---@return XVECTOR2
function IX2DMotorJoint:GetLinearOffset() end


---@public 请参考描述类
---@param angularOffset number
---@return void
function IX2DMotorJoint:SetAngularOffset(angularOffset) end


---@public 请参考描述类
---@return number
function IX2DMotorJoint:GetAngularOffset() end


---@public 请参考描述类
---@param force number
---@return void
function IX2DMotorJoint:SetMaxForce(force) end


---@public 请参考描述类
---@return number
function IX2DMotorJoint:GetMaxForce() end


---@public 请参考描述类
---@param torque number
---@return void
function IX2DMotorJoint:SetMaxTorque(torque) end


---@public 请参考描述类
---@return number
function IX2DMotorJoint:GetMaxTorque() end


---@public 请参考描述类
---@param factor number
---@return void
function IX2DMotorJoint:SetCorrectionFactor(factor) end


---@public 请参考描述类
---@return number
function IX2DMotorJoint:GetCorrectionFactor() end


