---@type number @enum X2DRigidBodyType
X_STATIC = 0


---@type number @enum X2DRigidBodyType
X_KINEMATIC = 0


---@type number @enum X2DRigidBodyType
X_DYNAMIC = 0


---刚体描述类型
---本类用于创建一个刚体
---@class X2DRigidBodyDesc
X2DRigidBodyDesc = {}


---@public X2DRigidBodyDesc_new00
---@return X2DRigidBodyDesc
function X2DRigidBodyDesc:new() end


---@type number 类型
X2DRigidBodyDesc.eType = 0


---@type XVECTOR2 位置
X2DRigidBodyDesc.vPosition = {}


---@type number 角度
X2DRigidBodyDesc.fAngle = 0


---@type XVECTOR2 初始线速度
X2DRigidBodyDesc.vLinearVelocity = {}


---@type number 初始角速度
X2DRigidBodyDesc.fAngularVelocity = 0


---@type number 线速度阻尼
X2DRigidBodyDesc.fLinearDamping = 0


---@type number 角速度阻尼
X2DRigidBodyDesc.fAngularDamping = 0


---@type boolean 允许休眠
X2DRigidBodyDesc.bAllowSleep = false


---@type boolean 休眠状态
X2DRigidBodyDesc.bAwake = false


---@type boolean 固定旋转
X2DRigidBodyDesc.bFixedRotation = false


---@type boolean 高速物体
X2DRigidBodyDesc.bBullet = false


---@type boolean 是否激活
X2DRigidBodyDesc.bActive = false


---@type number 重力系数
X2DRigidBodyDesc.fGravityScale = 0


---碰撞过滤类型
---@class X2DFilter
X2DFilter = {}


---@public X2DFilter_new00
---@return X2DFilter
function X2DFilter:new() end


---@type number
X2DFilter.categoryBits = 0


---@type number
X2DFilter.maskBits = 0


---@type number
X2DFilter.groupIndex = 0


---夹具描述类型
---夹具用于连接刚体和Shape
---@class X2DFixtureDesc
X2DFixtureDesc = {}


---@public X2DFixtureDesc_new00
---@return X2DFixtureDesc
function X2DFixtureDesc:new() end


---@type IX2DShape Shape
X2DFixtureDesc.pShape = {}


---@type number 摩擦系数
X2DFixtureDesc.fFriction = 0


---@type number 恢复系数
X2DFixtureDesc.fRestitution = 0


---@type number 密度,单位usually in kg/m^2.
X2DFixtureDesc.fDensity = 0


---@type boolean sensor类型只判断是否接触,无具体碰撞效果
X2DFixtureDesc.bSensor = false


---@type X2DFilter 碰撞过滤
X2DFixtureDesc.filter = {}


---@class IX2DRigidBody
IX2DRigidBody = {}


---@public 创建一个夹具
---@param def  X2DFixtureDesc 夹具描述类型
---@return void
function IX2DRigidBody:CreateFixture(def) end


---@public 创建一个夹具
---@param pShape IX2DShape shape
---@param fDensity number 密度
---@return void
function IX2DRigidBody:CreateFixture(pShape, fDensity) end


---@public 获取2D刚体位置
---@return XVECTOR2 刚体位置（XVECTOR2类型）
function IX2DRigidBody:GetPosition() end


---@public 获取2D刚体旋转弧度
---@return number 刚体旋转弧度
function IX2DRigidBody:GetAngle() end


---@public 设置线速度
---@param vVelocity XVECTOR2
---@return void
function IX2DRigidBody:SetLinearVelocity(vVelocity) end


---@public 获取线速度
---@return XVECTOR2 线速度
function IX2DRigidBody:GetLinearVelocity() end


---@public 设置角速度
---@param fAngle number
---@return void
function IX2DRigidBody:SetAngularVelocity(fAngle) end


---@public 获取角速度
---@return number 角速度
function IX2DRigidBody:GetAngularVelocity() end


---@public 给刚体施加一个力
---@param force XVECTOR2 力的作用位置
---@param point XVECTOR2
---@param wake boolean 是否唤醒刚体
---@return void
function IX2DRigidBody:ApplyForce(force, point, wake) end


---@public 在刚体重心位置施加一个力
---@param force XVECTOR2 力的方向和大小
---@param wake boolean 是否唤醒刚体
---@return void
function IX2DRigidBody:ApplyForceToCenter(force, wake) end


---@public 给刚体施加一个扭矩
---@param torque number 扭矩大小
---@param wake boolean 是否唤醒刚体
---@return void
function IX2DRigidBody:ApplyTorque(torque, wake) end


---@public 给刚体施加一个线速度变化
---@param impulse XVECTOR2
---@param point XVECTOR2
---@param wake boolean 是否唤醒刚体
---@return void
function IX2DRigidBody:ApplyLinearImpulse(impulse, point, wake) end


---@public 给刚体重心施加一个线速度变化
---@param impulse XVECTOR2
---@param wake boolean 是否唤醒刚体
---@return void
function IX2DRigidBody:ApplyLinearImpulseToCenter(impulse, wake) end


---@public 给刚体施加角速度变化
---@param impulse number 变化量
---@param wake boolean 是否唤醒刚体
---@return void
function IX2DRigidBody:ApplyAngularImpulse(impulse, wake) end


---@public 设置刚体是否为Bullet类型, Bullet类型可以防止高速物体穿透现象
---@param flag boolean Bullet类型
---@return void
function IX2DRigidBody:SetBullet(flag) end


---@public 获取是否为Bullet类型
---@return boolean Bullet类型
function IX2DRigidBody:IsBullet() end


---@public 是否唤醒刚体
---@param flag boolean 是否唤醒刚体
---@return void
function IX2DRigidBody:SetAwake(flag) end


---@public 获取唤醒状态
---@return boolean 是否唤醒状态
function IX2DRigidBody:IsAwake() end


---@public 手动设置一个刚体的位置与旋转
---@param vPosition XVECTOR2 位置
---@param fAngle number 旋转
---@return void
function IX2DRigidBody:SetTransform(vPosition, fAngle) end


