---@type number @enum RigidActorType
RAT_STATIC = 0


---@type number @enum RigidActorType
RAT_DYNAMIC = 0


---******************** ****************
---@class XShapeMaterial
XShapeMaterial = {}


---@public XShapeMaterial_new00
---@return XShapeMaterial
function XShapeMaterial:new() end


---@public XShapeMaterial_new01
---@param sf number
---@param df number
---@param r number
---@return XShapeMaterial
function XShapeMaterial:new(sf, df, r) end


---@type number
XShapeMaterial.fStaticFriction = 0


---@type number
XShapeMaterial.fDynamicFriction = 0


---@type number
XShapeMaterial.fRestitution = 0


---******************** ****************
---@class IXRigidBody
IXRigidBody = {}


---@public 为刚体绑定一个物理资源
---@param pRes IXPhysicsRes 物理资源
---@param bReplace boolean 是否替换,如果为xtrue,则会替换原有资源,如果为xfalse,未绑定则绑定,已绑定则不绑定
---@return boolean 成功返回xtrue,失败返回xfalse
---@attention 如果成功，则物理资源的引用计数加1
function IXRigidBody:BindPhysicsRes(pRes, bReplace) end


---@public 获取坐标空间
---@return XBaseCoordSpace 坐标空间
function IXRigidBody:GetBaseCoordSpace() end


---@public 判断是否开启了物理模拟属性
---@return boolean 是否开启了物理模拟属性
function IXRigidBody:IsSimulate() end


---@public 设置是否开启物理模拟属性
---@param bSet boolean 是否开启物理模拟属性
---@return void
function IXRigidBody:SetSimulate(bSet) end


---@public 获取类型属性
---@return number
function IXRigidBody:GetType() end


---@public 设置类型属性
---@param eType number 类型属性
---@return void
function IXRigidBody:SetType(eType) end


---@public 获取刚体形状表面材质属性
---@return XShapeMaterial 刚体形状表面材质属性
function IXRigidBody:GetMaterial() end


---@public 设置刚体形状表面材质属性
---@param mat  XShapeMaterial 刚体形状表面材质属性
---@return void
function IXRigidBody:SetMaterial(mat) end


---@public 判断是否开启了碰撞事件属性
---如果开启，则在该物体与其他物体碰撞时调用IXPhysicalSceneEventListener::OnContact
---@return boolean 是否开启了碰撞事件属性
function IXRigidBody:IsNotifyContact() end


---@public 设置是否开启了碰撞事件属性
---@param bSet boolean 是否开启碰撞事件属性
---@return void
function IXRigidBody:SetNotifyContact(bSet) end


---@public 判断是否被重力影响
---@return boolean 是否被重力影响
function IXRigidBody:IsGravityEnabled() end


---@public 设置是否被重力影响
---@param bSet boolean 是否被重力影响
---@return void
function IXRigidBody:SetGravityEnabled(bSet) end


---@public 判断是否开启了CCD属性（仅当Type为Dynamic时有效）
---注意：高速物体应开启CCD来避免隧穿效应
---@return boolean 是否开启了CCD属性
function IXRigidBody:IsCCDEnabled() end


---@public 设置是否开启了CCD属性（仅当Type为Dynamic时有效）
---注意：高速物体应开启CCD来避免隧穿效应
---@param bSet boolean 是否开启CCD属性
---@return void
function IXRigidBody:SetCCDEnabled(bSet) end


---@public 获取物体质量，单位kg.
---@return number 物体质量注意，0代表无穷质量。范围：[0,X_MAX_FLT32]
function IXRigidBody:GetMass() end


---@public 设置物体质量，单位kg.
---@param f number 物体质量.注意，0代表无穷质量。范围：[0,X_MAX_FLT32]
---@return void
function IXRigidBody:SetMass(f) end


---@public 获取刚体移动速度（注意：如果未开启模拟,无效）
---@return XVECTOR3 刚体移动速度
function IXRigidBody:GetLinearVelocity() end


---@public 设置刚体移动速度（注意：如果未开启模拟,无效）
---@param vVelocity XVECTOR3 刚体移动速度
---@return void
function IXRigidBody:SetLinearVelocity(vVelocity) end


---@public 获取刚体角速度（注意：如果未开启模拟,无效）
---@return XVECTOR3 刚体角速度
function IXRigidBody:GetAngularVelocity() end


---@public 设置刚体角速度（注意：如果未开启模拟,无效）
---@param vAngle XVECTOR3 刚体角速度
---@return void
function IXRigidBody:SetAngularVelocity(vAngle) end


---@public 获取速度阻尼系数
---@return number 速度阻尼系数[0,X_MAX_FLT32]
function IXRigidBody:GetLinearDamping() end


---@public 设置速度阻尼系数
---@param fLinearDamping number 速度阻尼系数[0,X_MAX_FLT32]
---@return void
function IXRigidBody:SetLinearDamping(fLinearDamping) end


---@public 获取角速度阻尼系数
---@return number 角速度阻尼系数[0,X_MAX_FLT32]
function IXRigidBody:GetAngularDamping() end


---@public 设置角速度阻尼系数
---@param fAngularDamping number
---@return void 角速度阻尼系数[0,X_MAX_FLT32]
function IXRigidBody:SetAngularDamping(fAngularDamping) end


---@public 获取碰撞过滤
---@return number 默认是0xFFFF
function IXRigidBody:GetFilterData() end


---@public 设置碰撞过滤
---@param nFilter number 碰撞过滤
---@return void
function IXRigidBody:SetFilterData(nFilter) end


