---@type number @enum UITypeID
UIID_UNKNOWN = 0


---@type number @enum UITypeID
UIID_NODE = 0


---@type number @enum UITypeID
UIID_WIDGET = 0


---@type number @enum UITypeID
UIID_IMAGE = 0


---@type number @enum UITypeID
UIID_IMAGEARRAY = 0


---@type number @enum UITypeID
UIID_LABEL = 0


---@type number @enum UITypeID
UIID_FX = 0


---@type number @enum UITypeID
UIID_LAYOUT = 0


---@type number @enum UITypeID
UI_VIRTUALLIST = 0


---@type number @enum UITypeID
UIID_PANEL = 0


---@type number @enum UITypeID
UIID_SCENE = 0


---@class XUINode
XUINode = {}


---@public 每一帧被调用的函数，不应当被手动调用。
---@param fDelta number 与上一帧Tick函数的间隔时间。
---@return void
function XUINode:Tick(fDelta) end


---@public 创建并返回一个空的控件实例的指针
---@return XUINode 控件指针
function XUINode:Create() end


---@public 返回指向父节点的指针，在其他节点调用AddChild，并将它作为参数传入后，返回值是那个其他节点，否则是 空值。
---@return XUINode 指向父节点的指针
function XUINode:GetParent() end


---@public 返回指向父节点的指针。
---@return  XUINode 指向父节点的指针
function XUINode:GetParent() end


---@public 从父节点中删除一个节点 如果这个节点是一个孤儿节点，那么什么都不会发生。
---@param bClean boolean true:在这个节点上所有的动作和回调都会被删除并释放其内存（真正被删掉）,false:不会释放，还可以继续使用该节点，并通过AddChild函数将其移入其他父节点下。
---@return void
function XUINode:RemoveFromParent(bClean) end


---@public 从父节点中删除所有的孩子。
---@param bClean boolean true:在这个节点上所有的动作和回调都会被删除并释放其内存（真正被删掉）,false:不会释放，还可以继续使用该节点，并通过AddChild函数将其移入其他父节点下。
---@return void
function XUINode:RemoveAllChildren(bClean) end


---@public 递归地通过名称获取子节点，该函数会返回名字为strChild的最先找到的一个子孙节点，这意味着该函数不仅仅只找自己的子节点，而是还会找子节点的子节点的子节点的子节点的......
---@param strChild string 要找的XUINode的Name值
---@return XUINode
function XUINode:GetAllChildByNameRecrusive(strChild) end


---@public 递归地通过名称获取子节点，该函数会返回ID为unGUID的最先找到的一个子孙节点，这意味着该函数不仅仅只找自己的子节点，而是还会找子节点的子节点的子节点的子节点的......
---@param unGUID number 要找的XUINode的ID值
---@return XUINode
function XUINode:GetAllChildByGUIDRecrusive(unGUID) end


---@public 添加一个子节点到父节点内，z-order是0.
---如果子节点被添加到了一个“running（活动着的）”节点，那么'onEnter'和 'onEnterTransitionDidFinish' 将会立即调用
---@param pChild XUINode 子节点
---@return void
function XUINode:AddChild(pChild) end


---@public 添加一个子节点到父节点内，z-order是 localzorder.
---如果子节点被添加到了一个“running（活动着的）”节点，那么'onEnter'和 'onEnterTransitionDidFinish' 将会立即调用
---@param pChild XUINode 子节点
---@param localZOrder number 用于渲染排序的zorder值.详细可参考函数`SetLocalZOrder(xint32)`.
---@return void
function XUINode:AddChild(pChild, localZOrder) end


---@public 获取子节点总个数
---@return number 子节点总个数
function XUINode:GetChildrenNum() end


---@public 获取所有子节点
---@return XUINode[] 子节点数组
function XUINode:GetChildren() end


---@public 通过子节点名称获取子节点指针
---@param strChild string 查找的子节点名称
---@return XUINode 子节点指针
function XUINode:GetChildByName(strChild) end


---@public 递归地通过名称获取子节点，该函数会返回名字为strChild的最先找到的一个子孙节点，这意味着该函数不仅仅只找自己的子节点，而是还会找子节点的子节点的子节点的子节点的......
---@param strChild string 要找的XUINode的Name值
---@return XUINode
function XUINode:GetChildByNameRecrusive(strChild) end


---@public 递归地通过名称获取子节点，该函数会返回ID为unGUID的最先找到的一个子孙节点，这意味着该函数不仅仅只找自己的子节点，而是还会找子节点的子节点的子节点的子节点的......
---@param unGUID number 要找的XUINode的ID值
---@return XUINode
function XUINode:GetChildByGUIDRecrusive(unGUID) end


---@public 从容器中删除一个孩子，取决于cleanup参数，同时可能会清除所有的活动的动作
---@param pChild XUINode 希望被删除的子节点
---@param bClean boolean true在这个节点上所有的动作和回调都会被删除,false就不会删除
---@return void
function XUINode:RemoveChild(pChild, bClean) end


---@public 在绘画之前，排列所有的孩子数组一次，而不是每次添加或者删除子节点时都排序。 这个方法可以大幅度地提高性能
---@return void
function XUINode:SortChildren() end


---@public 添加一个 Z 值为 0 的子节点。如果当前节点正在运行，那么 'onEnter' 和 'onEnterTransitionDidFinish' 会被立即调用
---@param pChild XUINode 一个子节点
---@return void
function XUINode:AddProtectedChild(pChild) end


---@public 获取所有子节点数目
---@return number 子节点数目
function XUINode:GetProtectedChildrenNum() end


---@public 获取所有子节点,以数组返回
---@return XUINode[]
function XUINode:GetProtectedChildren() end


---@public 通过名称获取子节点
---@param strChild string 查找的子节点名称
---@return XUINode 查找到的子节点指针
function XUINode:GetProtectedChildByName(strChild) end


---@public 通过名称遍历获取子节点
---@param strChild string 查找的子节点名称
---@return XUINode 查找到的子节点指针
function XUINode:GetProtectedChildByNameRecrusive(strChild) end


---@public 通过GUID遍历获取子节点
---@param unGUID number GUID
---@return XUINode 查找到的子节点指针
function XUINode:GetProtectedChildByGUIDRecrusive(unGUID) end


---@public 删除一个子节点。可以通过设置 cleanup 的参数值清理所有正在运行的 action
---@param pChild XUINode 将被删除的子节点
---@param bClean boolean 如果为true，将清理子节点相关的action和回调
---@return void
function XUINode:RemoveProtectedChild(pChild, bClean) end


---@public 在绘制之前对所有子节点进行一次排序。相对于每添加一个节点就排序一次，可以大大提高性能
---@return void
function XUINode:SortProtectedChildren() end


---@public XUINode_MakeProtectedName00
---@param strName string
---@return string
function XUINode:MakeProtectedName(strName) end


---@public 克隆当前节点
---@return XUINode 返回克隆的节点指针
function XUINode:Clone() end


---@public 判断是否是protected节点（Z值为0）
---@return boolean 是返回true,否则返回false
function XUINode:IsProtected() end


---@public 获取类型字符串，并返回
---@return string
function XUINode:GetTypeString() end


---@public 获取节点类型id，并返回
---@return number
function XUINode:GetTypeID() end


---@public 获取对应的场景指针，并返回
---@return XUIScene
function XUINode:GetScene() end


---@public 获取GUID并返回
---@return number
function XUINode:GetGUID() end


---@public 获取节点名称并返回
---@return string
function XUINode:GetName() end


---@public 设置节点名称
---@param strName string 要设置的名称字符串
---@return void
function XUINode:SetName(strName) end


---@public 获取节点用户自定义数据
---@return string
function XUINode:GetUserData() end


---@public 设置节点名称
---@param strUserData string
---@return void
function XUINode:SetUserData(strUserData) end


---@public XUINode_SetLocalZOrder00
---@param nLocalZOrder number
---@return void
function XUINode:SetLocalZOrder(nLocalZOrder) end


---@public LocalZOrder是“key”(关键)来分辨节点和它兄弟节点的相关性。 父节点将会通过LocalZOrder的值来分辨所有的子节点。
---如果两个节点有同样的LocalZOrder,那么先加入子节点数组的节点将会显示在后加入的节点的前面。
---新版本接口优先渲染父节点 子节点 依据localz值大小 先渲染值的子节点
---@param nLocalZOrder number 相邻节点中的顺序值
---@return void
function XUINode:SetLocalZOrderNV(nLocalZOrder) end


---@public 得到这个节点的局部Z顺序
---@return number 局部Z轴顺序(相对于兄弟节点)。
function XUINode:GetLocalZOrder() end


---@public 定义渲染节点的顺序 拥有全局Z顺序越小的节点，最先渲染
---假设两个或者更多的节点拥有相同的全局Z顺序，那么渲染顺序无法保证。 唯一的例外是如果节点的全局Z顺序为零，
---那么场景图顺序是可以使用的。
---默认的，所有的节点全局Z顺序都是零。这就是说，默认使用场景图顺序来渲染节点。
---全局Z顺序是非常有用的当你需要渲染节点按照不同的顺序而不是场景图顺序。
---局限性: 全局Z顺序不能够被拥有继承“SpriteBatchNode”的节点使用。 并且如果“ClippingNode”是其中之一的上代，
---那么“global Z order” 将会和“ClippingNode”有关
---@param fGlobalZOrder number 全局Z轴顺序新版本该接口废弃//19.12.25
---@return void
function XUINode:SetGlobalZOrder(fGlobalZOrder) end


---@public 定义渲染节点的顺序 拥有全局Z顺序越大的节点，最先渲染
---假设两个或者更多的节点拥有相同的全局Z顺序，那么渲染顺序无法保证。 唯一的例外是如果节点的全局Z顺序为零，
---那么场景图顺序是可以使用的。
---默认的，所有的节点全局Z顺序都是零。这就是说，默认使用场景图顺序来渲染节点。
---全局Z顺序是非常有用的当你需要渲染节点按照不同的顺序而不是场景图顺序。
---局限性: 全局Z顺序不能够被拥有继承“SpriteBatchNode”的节点使用。 并且如果“ClippingNode”是其中之一的上代，
---那么“global Z order” 将会和“ClippingNode”有关
---@param fGlobalZOrder number 全局Z轴顺序
---@param setChildren boolean
---@return void
function XUINode:SetGlobalZOrderNV(fGlobalZOrder, setChildren) end


---@public 返回节点的全局Z顺序
---@return number 节点的全局Z轴顺序。
function XUINode:GetGlobalZOrder() end


---@public 设置节点的缩放（x）。
---它是一个缩放因子，将会乘以节点的宽以及它的子节点
---@param fScaleX number X轴的缩放因子
---@return void
function XUINode:SetScaleX(fScaleX) end


---@public 返回该节点的X轴的缩放因子。
---它是一个缩放因子，将会乘以节点的宽以及它的子节点
---@return number X轴的缩放因子
function XUINode:GetScaleX() end


---@public 设置节点的缩放（y）。
---它是一个缩放因子，将会乘以节点的宽以及它的子节点
---@param fScaleY number Y轴的缩放因子
---@return void
function XUINode:SetScaleY(fScaleY) end


---@public 返回该节点的Y轴的缩放因子。
---它是一个缩放因子，将会乘以节点的宽以及它的子节点
---@return number Y轴的缩放因子
function XUINode:GetScaleY() end


---@public 设置节点的缩放因子（x,y）。
---缩放因子将会乘以该节点和它子节点的宽，高和深度
---@param fScaleX number X轴的缩放因子
---@param fScaleY number Y轴的缩放因子
---@return void
function XUINode:SetScale(fScaleX, fScaleY) end


---@public 设置节点的缩放因子（x,y）。
---缩放因子将会乘以该节点和它子节点的宽，高和深度
---@param vScale XVECTOR2 X轴,Y轴的缩放因子
---@return void
function XUINode:SetScale(vScale) end


---@public 返回节点的缩放因子（x,y）。
---@return XVECTOR2 XVECTOR2:X轴,Y轴的缩放因子
function XUINode:GetScale() end


---@public 设置节点在父节点坐标系下的X轴位置
---@param x number X轴坐标
---@return void
function XUINode:SetPositionX(x) end


---@public 获取节点在父节点坐标系下的X轴位置
---@return number xX轴坐标
function XUINode:GetPositionX() end


---@public 设置节点在父节点坐标系下的Y轴位置
---@param y number Y轴坐标
---@return void
function XUINode:SetPositionY(y) end


---@public 获取节点在父节点坐标系下的Y轴位置
---@return number yY轴坐标
function XUINode:GetPositionY() end


---@public 设置节点的位置在父节点的坐标系系统中。
---@param x number 这个节点的位置x
---@param y number 这个节点的位置y
---@return void
function XUINode:SetPosition(x, y) end


---@public 设置节点的位置在父节点的坐标系系统中。
---通常我们使用XVECTOR2(x,y) 来组成 XVECTOR2对象
---@param vPos XVECTOR2 这个节点的位置（x,y）
---@return void
function XUINode:SetPosition(vPos) end


---@public 得到在父节点坐标系中节点的位置（x,y,以XVECTOR2形式)
---@return XVECTOR2 节点在父节点坐标系中的位置
function XUINode:GetPosition() end


---@public 设置锚点，用百分比表示。
---一个锚点是所有的转换和定位操作发生的点。 它就像在节点上连接其父类的大头针。
---锚点是标准化的，就像百分比一样。(0,0)表示左下角，(1,1)表示右上角。
---但是你可以使用比（1,1,）更高的值或者比（0,0）更低的值。 默认的锚点是（0.5,0.5），因此它开始于节点的中心位置
---@param vAnchorPoint XVECTOR2 节点的锚点
---@return void
function XUINode:SetAnchorPoint(vAnchorPoint) end


---@public 返回用百分比表示的锚点
---@return XVECTOR2 节点的锚点
function XUINode:GetAnchorPoint() end


---@public 返回锚点的绝对像素位置
---@return XVECTOR2 绝对像素的锚点
function XUINode:GetAnchorPointInPoints() end


---@public 设置节点的大小。
---contentSize依然是相同的，无论节点是缩放或者旋转。 所有的节点都有大小。图层和场景有相同的屏幕大小。
---@param vContentSize XVECTOR2 未转换节点的大小
---@return void
function XUINode:SetContentSize(vContentSize) end


---@public 设置缩放为1时，节点的大小。
---contentSize依然是相同的，无论节点是缩放或者旋转。所有的节点都有大小。图层和场景有相同的屏幕大小。
---@param fContentX number 节点的大小x
---@param fContentY number 节点的大小y
---@return void
function XUINode:SetContentSize(fContentX, fContentY) end


---@public 返回节点的大小。
---@return XVECTOR2 节点的大小XVECTOR2(x,y)
function XUINode:GetContentSize() end


---@public 设置节点的宽度。
---@param fContentX number 节点的宽度
---@return void
function XUINode:SetContentSizeX(fContentX) end


---@public 返回节点的宽度。
---@return number 未节点的宽度
function XUINode:GetContentSizeX() end


---@public 设置节点的高度。
---@param fContentY number 节点的高度
---@return void
function XUINode:SetContentSizeY(fContentY) end


---@public 返回节点的高度。
---@return number 节点的高度
function XUINode:GetContentSizeY() end


---@public 设置节点的旋转（angle）角度。
---0 是默认的旋转角度。 负数顺时针旋转节点，正数逆时针旋转节点。
---@param fRotation number 节点的旋转角度
---@return void
function XUINode:SetRotation(fRotation) end


---@public 返回节点的旋转角度
---@return number 节点的旋转角度
function XUINode:GetRotation() end


---@public 设置节点是否可见。默认值是true,一个节点默认是可见的
---@param bVisible boolean true,如果节点是可见的，false,如果节点是隐藏的
---@return void
function XUINode:SetVisible(bVisible) end


---@public 返回节点的可见状态
---@return boolean 是否可见
function XUINode:IsVisible() end


---@public 返回节点在场景中的可见状态
---@return boolean 是否可见
function XUINode:IsVisibleInScene() end


---@public 返回节点是否是“running(活动的)”。
---如果节点是活动的，它将会允许事件回调就像onEnter(), onExit(), update()
---@return boolean 节点是否是“running(活动的)"
function XUINode:IsRunning() end


---@public 事件回调函数
---每次当Node进入“stage”时才调用事件回调。 如果Node进入“stage”状态时伴随着一个转换（transition）,
---那么事件将会在这个转换开始的时候被调用。 在onEnter过程中，你不能够接入“sister/brother”兄妹节点。
---如果你重写了onEnter方法，你应该调用它的父类.
---@return void
function XUINode:OnEnter() end


---@public 事件回调函数
---每次当Node离开“stage”时才调用事件回调。 如果Node离开“stage”状态时伴随着一个转换（transition）,
---那么事件将会在这个转换结束的时候被调用。 在onEnter过程中中你不能够接入一个兄妹节点。
---如果你重写onExit, 你应该调用它的父类,
---@return void
function XUINode:OnExit() end


---@public 恢复所有的调度过的选择器，动作和事件监听器。 这个方法被onEnter方法在内部调用
---@return void
function XUINode:Resume() end


---@public 暂停所有的调度过的选择器，动作和事件监听器。 这个方法被onExit方法在内部调用
---@return void
function XUINode:Pause() end


---@public 停止并移除所有的活动着的动作和调度器
---@return void
function XUINode:Cleanup() end


---@public 执行一个动作，并且返回执行的该动作。这个节点将会变成动作的目标.
---@param pAction XUIAction 动作对象
---@return boolean
function XUINode:RunAction(pAction) end


---@public 停止并且从活动动作列表中删除所有的动作
---@return void
function XUINode:StopAllActions() end


---@public 停止并且从活动动作列表中删除一个动作
---@param pAction XUIAction
---@return void
function XUINode:StopAction(pAction) end


---@public XUINode_EnableMask00
---@param bEnable boolean
---@return void
function XUINode:EnableMask(bEnable) end


---@public XUINode_IsMask00
---@return boolean
function XUINode:IsMask() end


---@public XUINode_SetScreenMask00
---@param vPos XVECTOR2
---@param vWAxis XVECTOR2
---@param vHAxis XVECTOR2
---@param fWidth number
---@param fHeight number
---@return void
function XUINode:SetScreenMask(vPos, vWAxis, vHAxis, fWidth, fHeight) end


---@public XUINode_GetMask00
---@return XVECTOR4
---@return XVECTOR4
---@return void
function XUINode:GetMask() end


---@public 返回父坐标系中的一个AABB(轴向包围外框)
---@return XUIRect 轴向包围外框
function XUINode:GetBoundingBox() end


---@public XUINode_GetLeftBoundary00
---@return number
function XUINode:GetLeftBoundary() end


---@public XUINode_GetRightBoundary00
---@return number
function XUINode:GetRightBoundary() end


---@public XUINode_GetTopBoundary00
---@return number
function XUINode:GetTopBoundary() end


---@public XUINode_GetBottomBoundary00
---@return number
function XUINode:GetBottomBoundary() end


---@public 强制更新Transform，通过SetPosition、SetScale等函数修改该节点的Transform时，数据不会立即更新，而是等到该节点需要绘制的时候才会更新，在有些情景下（比如需要使用GetLocalToScreenTransform函数），我们希望该节点的Transform是最新的，这时候需要手动调用该函数。
---@return void
function XUINode:ForceUpdateTransform() end


---@public 获得相对于父节点的Transform矩阵（里面有位置、旋转、缩放信息）
---@return XMATRIX4
function XUINode:GetLocalToParentTransform() end


---@public XUINode_GetScreenToLocalOriginTransform00
---@return XMATRIX4
function XUINode:GetScreenToLocalOriginTransform() end


---@public XUINode_GetLocalOriginToScreenTransform00
---@return XMATRIX4
function XUINode:GetLocalOriginToScreenTransform() end


---@public XUINode_GetLocalOriginToWorldTransform00
---@return XMATRIX4
function XUINode:GetLocalOriginToWorldTransform() end


---@public XUINode_GetLocalToScreenTransform00
---@return XMATRIX4
function XUINode:GetLocalToScreenTransform() end


---@public XUINode_GetLocalToWorldTransform00
---@return XMATRIX4
function XUINode:GetLocalToWorldTransform() end


---@public 刷新布局
---@return void
function XUINode:RefreshLayout() end


---@public 插入一个子节点到父节点内，z-order同原先位置处子节点的z-order.
---如果子节点被添加到了一个“running（活动着的）”节点，那么'onEnter'将会立即调用
---@param index number 子节点序列
---@param pChild XUINode 子节点
---@return boolean
function XUINode:InsertChild(index, pChild) end


---@public 销毁节点，同时释放子节点.
---@return void
function XUINode:Destroy() end


---@public XUINode_AddUINodeComponent00
---@param xelua_var_47 XUIComponent
---@return boolean
function XUINode:AddUINodeComponent(xelua_var_47) end


---@public XUINode_AddUINodeComponentByType00
---@param type string
---@return boolean
function XUINode:AddUINodeComponentByType(type) end


---@public XUINode_GetComponentByTypeID00
---@param nTypeID number
---@return XUIComponent
function XUINode:GetComponentByTypeID(nTypeID) end


---@public XUINode_GetComponentByType00
---@param type string
---@return XUIComponent
function XUINode:GetComponentByType(type) end


---@public XUINode_GetComponentByName00
---@param strName string
---@return XUIComponent
function XUINode:GetComponentByName(strName) end


---@public XUINode_GetComponentsByType00
---@param type string
---@return XUIComponent[]
function XUINode:GetComponentsByType(type) end


---@public XUINode_GetAllUINodeComponents00
---@return XUIComponent[]
function XUINode:GetAllUINodeComponents() end


---@public XUINode_GetAllUINodeComponents01
---@return XUIComponent[]
function XUINode:GetAllUINodeComponents() end


---@public XUINode_RemoveUINodeComponent00
---@param xelua_var_48 XUIComponent
---@param release boolean
---@return boolean
function XUINode:RemoveUINodeComponent(xelua_var_48, release) end


---@public XUINode_RemoveUINodeComponents00
---@param xelua_var_49 XUIComponent[]
---@param release boolean
---@return boolean
function XUINode:RemoveUINodeComponents(xelua_var_49, release) end


---@public XUINode_RemoveAllUINodeComponents00
---@param release boolean
---@return boolean
function XUINode:RemoveAllUINodeComponents(release) end


---@public XUINode_HasComponent00
---@param strType0rName string
---@param bType boolean
---@return boolean
function XUINode:HasComponent(strType0rName, bType) end


---@public XUINode_HasComponent01
---@param xelua_var_50 XUIComponent
---@return boolean
function XUINode:HasComponent(xelua_var_50) end


---@public XUINode_GetUINodeComponentIndex00
---@param xelua_var_51 XUIComponent
---@return number
function XUINode:GetUINodeComponentIndex(xelua_var_51) end


---@public XUINode_ChangeUINodeComponentIndex00
---@param nNewIndex number
---@param xelua_var_52 XUIComponent
---@return boolean
function XUINode:ChangeUINodeComponentIndex(nNewIndex, xelua_var_52) end


---@public XUINode_GetPanel00
---@return XUIPanel
function XUINode:GetPanel() end


---@public XUINode_SetBatchableDrawableRenderOrder00
---@param xelua_var_53 number
---@return void
function XUINode:SetBatchableDrawableRenderOrder(xelua_var_53) end


---@public 获取控件颜色
---@return  XCOLORBASE 控件颜色
function XUINode:GetColor() end


---@public XUINode_PrintSceneTree00
---@return void
function XUINode:PrintSceneTree() end


---@public XUINode_GetCollisionLayer00
---@return number
function XUINode:GetCollisionLayer() end


---@public XUINode_SetCollisionLayer00
---@param nLayer number
---@return void
function XUINode:SetCollisionLayer(nLayer) end


