---@class XUIScene : XUIPanel
XUIScene = {}


---@type number @enum UIRenderMode
XUIScene.eScreenOverLay = 0


---@type number @enum UIRenderMode
XUIScene.eWorldSpace = 0


---@public 获取是否是模态场景。
---@return boolean 返回是否是模态场景。
function XUIScene:IsModal() end


---@public 显示当前场景，XUIScene需要手动调用Show函数来显示出来，即默认为隐藏状态。
---@param bModal boolean 是否是模态场景，true为当前场景会阻断触摸事件，其他场景无法响应。false触摸事件如果没被处理，则会往下传递。
---@return void
function XUIScene:Show(bModal) end


---@public 隐藏当前场景
---@return void
function XUIScene:Hide() end


---@public 判断当前场景是否显示
---@return boolean
function XUIScene:IsShow() end


---@public 设置场景的设计分辨率
---XUI_EXACTFIT 非等比拉伸致宽度和高度与屏幕分辨率一致。
---XUI_NOBORDER 等比拉伸到没有边框的程度，可能会导致横向或者纵向有UI显示不全。
---XUI_SHOWALL 等比拉伸以能够显示全部内容，可能会导致横向或者纵向有黑边。
---XUI_FIXEDHEIGHT 等比拉伸到高度正好和屏幕分辨率一致。
---XUI_FIXEDWIDTH 等比拉伸到宽度正好和屏幕分辨率一致。
---@param vDesignRes XVECTOR2 场景的设计分辨率。
---@param rp number 依据场景的设计分辨率自适应屏幕分辨率的策略。
---@return void
function XUIScene:SetDesignResolution(vDesignRes, rp) end


---@public 获取场景的设计分辨率
---@return XVECTOR2 返回场景的设计分辨率
function XUIScene:GetDesignResolution() end


---@public 设置场景的设计分辨率
---@return number 场景的分辨率适应策略。
function XUIScene:GetResolutionPolicy() end


---@public 设置是否启用自定义适配
---自定义适配，指的是给定一个高宽比，大于该高宽比使用一个策略，小于该高宽比使用另一个策略
---@param bEnable boolean 是否启用自定义适配策略
---@return void
function XUIScene:EnableCustomPolicy(bEnable) end


---@public 是否使用自定义适配
---@return boolean 场景的分辨率适应策略。
function XUIScene:IsCustomPolicy() end


---@public 设定自定义适配的高宽比
---@param fCustomAspect number 自定义适配的高宽比
---@return void
function XUIScene:SetCustomAspect(fCustomAspect) end


---@public 获取自定义适配的高宽比
---@return number 自定义适配的高宽比
function XUIScene:GetCustomAspect() end


---@public 设定大于给定高宽比时的适配策略
---@param rp number 大于给定高宽比时的适配策略
---@return void
function XUIScene:SetCustomUpperResolutionPolicy(rp) end


---@public 获取大于给定高宽比时的适配策略
---@return number 大于给定高宽比时的适配策略
function XUIScene:GetCustomUpperResolutionPolicy() end


---@public 设定小于给定高宽比时的适配策略
---@param rp number 小于给定高宽比时的适配策略
---@return void
function XUIScene:SetCustomLowerResolutionPolicy(rp) end


---@public 获取小于给定高宽比时的适配策略
---@return number 小于给定高宽比时的适配策略
function XUIScene:GetCustomLowerResolutionPolicy() end


---@public 手动让分辨率重新自适应一次。
---@return void
function XUIScene:UpdateDesignResolutionSize() end


---@public 设置是否适应刘海屏。
---@param bSet boolean 是否适应刘海屏。
---@return void
function XUIScene:AdaptNotch(bSet) end


---@public 获取是否适应刘海屏。
---@return boolean 是否适应刘海屏。
function XUIScene:IsAdaptNotch() end


---@public 把当前世界矩阵转成屏幕坐标系矩阵
---@return XMATRIX4 屏幕坐标系矩阵
function XUIScene:GetWorldToScreenMatrix() end


---@public 获取缩放矩阵
---@return XMATRIX4 缩放矩阵
function XUIScene:GetScaleMatrix() end


---@public 添加一个节点到场景中渲染
---@param pNode XUINode 添加的节点指针
---@param global_z_order number 全局排序索引
---@return void
function XUIScene:AddToRenderer(pNode, global_z_order) end


---@public 获取版本号
---@return number 版本号
function XUIScene:GetVersion() end


---@public XUIScene_GetAllRttTextures00
---@return XUITexture[]
function XUIScene:GetAllRttTextures() end


---@public XUIScene_GetScenePath00
---@return string
function XUIScene:GetScenePath() end


---@public XUIScene_IsUsePhysical00
---@return boolean
function XUIScene:IsUsePhysical() end


---@public XUIScene_SetUsePhysical00
---@param bUsePhysical boolean
---@return void
function XUIScene:SetUsePhysical(bUsePhysical) end


---@public XUIScene_SetGravity00
---@param vGravity XVECTOR2
---@return void
function XUIScene:SetGravity(vGravity) end


---@public XUIScene_GetGravity00
---@return XVECTOR2
function XUIScene:GetGravity() end


---@public 两个层之间是否允许碰撞
---@param layer0 number
---@param layer1 number
---@return boolean
function XUIScene:CanCollision2DLayerCollide(layer0, layer1) end


---@public XUIScene_CanCollision2DLayerCollide01
---@param layer0 cppstring
---@param layer1 cppstring
---@return boolean
function XUIScene:CanCollision2DLayerCollide(layer0, layer1) end


---@public XUIScene_SetCollision2DLayerState00
---@param layer0 number
---@param layer1 number
---@param state boolean
---@return void
function XUIScene:SetCollision2DLayerState(layer0, layer1, state) end


---@type number @readonly 
XUIScene.PTM_RATIO = 0


---@public XUIScene_SetUseGlobalFont00
---@param bUseGlobal boolean
---@return void
function XUIScene:SetUseGlobalFont(bUseGlobal) end


---@public XUIScene_IsUseGlobalFont00
---@return boolean
function XUIScene:IsUseGlobalFont() end


