---@class XUITabHeader : XUIAbstractCheckButton
XUITabHeader = {}


---@type number @enum EventType
XUITabHeader.SELECTED = 0


---@type number @enum EventType
XUITabHeader.UNSELECTED = 0


---@public 创建并返回一个页头实例
---@return XUITabHeader 控件指针
function XUITabHeader:Create() end


---@public 创建一个页头实例。
---@param strTitle string 页头文字。
---@param strBackgroundTexture string 页头的背景图片。
---@param strCrossTexture string 页头被选中时显示的图片，不被选中不显示。
---@param texType number 相对路径/绝对路径。
---@return XUITabHeader
function XUITabHeader:Create(strTitle, strBackgroundTexture, strCrossTexture, texType) end


---@public 创建一个页头实例。
---@param strTitle string 页头文字。
---@param strBackgroundTexture string 页头的背景图片。
---@param strBackgroundSelectedTexture string 页头被选中时的背景图片。
---@param strCrossTexture string 页头被选中时显示的图片，不被选中不显示。
---@param strBackgroundDisabledTexture string 页头禁用时的背景图片。
---@param strFrontCrossDisabledTexture string 页头禁用还被选中时显示的图片。
---@param texType number 相对路径/绝对路径。
---@return XUITabHeader
function XUITabHeader:Create(strTitle, strBackgroundTexture, strBackgroundSelectedTexture, strCrossTexture, strBackgroundDisabledTexture, strFrontCrossDisabledTexture, texType) end


---@public 获取页头显示的文字的XUILabel实例
---@return XUILabel
function XUITabHeader:GetTitleRenderer() end


---@public 设置页头显示的文字
---@param strText string 显示的文字。
---@return void
function XUITabHeader:SetTitleText(strText) end


---@public 获取页头显示的文字
---@return string 返回显示的文字。
function XUITabHeader:GetTitleText() end


---@public 设置页头显示文字的颜色
---@param color  XCOLORBASE 文字颜色。
---@return void
function XUITabHeader:SetTitleColor(color) end


---@public 返回页头显示文字的颜色
---@return XCOLORBASE 返回页头显示文字的颜色。
function XUITabHeader:GetTitleColor() end


---@public XUITabHeader_SetTitleFontSize00
---@param fSize number
---@return void
function XUITabHeader:SetTitleFontSize(fSize) end


---@public 获取页头显示文字的字体大小
---@return number 返回文字字体大小。
function XUITabHeader:GetTitleFontSize() end


---@public 设置页头显示文字的字体路径
---@param strFontName string 字体路径。
---@return void
function XUITabHeader:SetTitleFontName(strFontName) end


---@public 获取页头显示文字的字体路径
---@return string 返回字体路径。
function XUITabHeader:GetTitleFontName() end


---@public 获取该页头在Table页中的索引值，如果没有返回-1
---@return number 返回页头在Table页中的索引值。
function XUITabHeader:GetIndexInTabControl() end


---@class XUITabControl : XUIWidget
XUITabControl = {}


---@type number @enum Dock
XUITabControl.TOP = 0


---@type number @enum Dock
XUITabControl.LEFT = 0


---@type number @enum Dock
XUITabControl.BOTTOM = 0


---@type number @enum Dock
XUITabControl.RIGHT = 0


---@type number @enum EventType
XUITabControl.SELECT_CHANGED = 0


---@public XUITabControl_new00
---@return XUITabControl
function XUITabControl:new() end


---@public 创建并返回一个页头实例
---@return XUITabControl 控件指针
function XUITabControl:Create() end


---@public XUITabControl_RemoveTab00
---@param nIndex number
---@return void
function XUITabControl:RemoveTab(nIndex) end


---@public XUITabControl_RemoveTab01
---@param nIndex number
---@param bClean boolean
---@return void
function XUITabControl:RemoveTab(nIndex, bClean) end


---@public XUITabControl_SetSelectTab00
---@param nIndex number
---@return void
function XUITabControl:SetSelectTab(nIndex) end


---@public XUITabControl_SetSelectTab01
---@param pTabHeader XUITabHeader
---@return void
function XUITabControl:SetSelectTab(pTabHeader) end


---@public XUITabControl_GetTabHeader00
---@param nIndex number
---@return XUITabHeader
function XUITabControl:GetTabHeader(nIndex) end


---@public XUITabControl_GetTabContainer00
---@param nIndex number
---@return XUILayout
function XUITabControl:GetTabContainer(nIndex) end


---@public XUITabControl_InsertTab00
---@param nIndex number
---@param pHeader XUITabHeader
---@param pContainer XUILayout
---@return void
function XUITabControl:InsertTab(nIndex, pHeader, pContainer) end


---@public XUITabControl_AppendTab00
---@param pContainer XUILayout
---@return void
function XUITabControl:AppendTab(pContainer) end


---@public XUITabControl_GetIndexByContainer00
---@param pContainer XUILayout
---@return number
function XUITabControl:GetIndexByContainer(pContainer) end


---@public 获取当前Tab页的数量
---@return number
function XUITabControl:GetTabCount() end


---@public 获取当前选中的Tab页的索引
---@return number
function XUITabControl:GetSelectedTabIndex() end


---@public XUITabControl_IndexOfTabHeader00
---@param pTabCell  XUITabHeader
---@return number
function XUITabControl:IndexOfTabHeader(pTabCell) end


---@manual xelua_XEngine_XUITabControl_AddTabChangedEventListener_manual
---@public XUITabControl_AddTabChangedEventListener_manual
---@param callback  std::function<void(XUINode*pNode, xint32 nTabIndex, EventType)>
---@return void
function XUITabControl:AddTabChangedEventListener(callback) end


---@public XUITabControl_SetHeaderWidth00
---@param fHeaderWidth number
---@return void
function XUITabControl:SetHeaderWidth(fHeaderWidth) end


---@public 获取所有的页头宽度
---@return number 当前页头宽度。
function XUITabControl:GetHeaderWidth() end


---@public XUITabControl_SetHeaderHeight00
---@param fHeaderHeight number
---@return void
function XUITabControl:SetHeaderHeight(fHeaderHeight) end


---@public 获取所有的页头高度
---@return number 当前页头高度。
function XUITabControl:GetHeaderHeight() end


---@public XUITabControl_SetHeaderSelectedZoom00
---@param fZoom number
---@return void
function XUITabControl:SetHeaderSelectedZoom(fZoom) end


---@public 获取当前设置的页头被选中时，它的缩放增量
---@return number 返回缩放增量。
function XUITabControl:GetHeaderSelectedZoom() end


---@public XUITabControl_SetHeaderDockPlace00
---@param eDockPlace number
---@return void
function XUITabControl:SetHeaderDockPlace(eDockPlace) end


---@public 返回页头位置
---@return number 页头位置：TOP上、BOTTOM下、LEFT左、RIGHT右。
function XUITabControl:GetHeaderDockPlace() end


