---@class XUIVirtualListView : XUIWidget
XUIVirtualListView = {}


---@type number @enum Direction
XUIVirtualListView.HORIZONTAL = 0


---@type number @enum Direction
XUIVirtualListView.VERTICAL = 0


---@type number @enum ListLayoutType
XUIVirtualListView.SINGLE = 0


---@type number @enum ListLayoutType
XUIVirtualListView.MULTI = 0


---@type number @enum ListLayoutType
XUIVirtualListView.GRID = 0


---@type number @enum EventType
XUIVirtualListView.XUI_SCROLL_TO_TOP = 0


---@type number @enum EventType
XUIVirtualListView.XUI_SCROLL_TO_BOTTOM = 0


---@type number @enum EventType
XUIVirtualListView.XUI_SCROLL_TO_LEFT = 0


---@type number @enum EventType
XUIVirtualListView.XUI_SCROLL_TO_RIGHT = 0


---@type number @enum EventType
XUIVirtualListView.XUI_SCROLLING = 0


---@type number @enum EventType
XUIVirtualListView.XUI_BOUNCE_TOP = 0


---@type number @enum EventType
XUIVirtualListView.XUI_BOUNCE_BOTTOM = 0


---@type number @enum EventType
XUIVirtualListView.XUI_BOUNCE_LEFT = 0


---@type number @enum EventType
XUIVirtualListView.XUI_BOUNCE_RIGHT = 0


---@type number @enum EventType
XUIVirtualListView.XUI_CONTAINER_MOVED = 0


---@type number @enum EventType
XUIVirtualListView.XUI_SCROLLING_BEGAN = 0


---@type number @enum EventType
XUIVirtualListView.XUI_SCROLLING_ENDED = 0


---@type number @enum EventType
XUIVirtualListView.XUI_AUTOSCROLL_BEGAN = 0


---@type number @enum EventType
XUIVirtualListView.XUI_AUTOSCROLL_ENDED = 0


---@type number @enum EventType
XUIVirtualListView.XUI_TOP_ON_RELEASE = 0


---@type number @enum EventType
XUIVirtualListView.XUI_BOTTOM_ON_RELEASE = 0


---@public 创建并返回一个空的控件实例的指针
---@return XUIVirtualListView 控件指针
function XUIVirtualListView:Create() end


---@public 设置用于生成指定索引的Item的代理类实例
---@param pDelegate XUIVirtualListViewDelegate 该代理类需要实现根据索引值获取Item、获取当前Item总个数以及根据索引获取Item大小的功能。
---@return void
function XUIVirtualListView:SetVirtualListDelegate(pDelegate) end


---@public 获取当前设置进去的代理类实例， 没有就返回 空值。
---@return XUIVirtualListViewDelegate
function XUIVirtualListView:GetVirtualListDelegate() end


---@public 在索引 idx处插入一个节点
---该函数在代理的数据源有插入新节点行为时 调用 以此更新缓存的节点位置信息
---@param idx number
---@return void
function XUIVirtualListView:InsertItemAtIndex(idx) end


---@public 在索引 idx处删除一个节点
---该函数在代理的数据源有删除节点行为时 调用 以此更新缓存的节点位置信息
---@param idx number
---@return void
function XUIVirtualListView:RemoveItemAtIndex(idx) end


---@public 新插入节点
---该函数在代理的数据源有插入新节点行为时 调用 以此更新缓存的节点位置信息
---@return void
function XUIVirtualListView:PushBackItem() end


---@public XUIVirtualListView_SetVelocityScale00
---@param velocity number
---@return void
function XUIVirtualListView:SetVelocityScale(velocity) end


---@public XUIVirtualListView_GetVelocityScale00
---@return number
function XUIVirtualListView:GetVelocityScale() end


---@public 滚动至索引处
---@param animate boolean
---@return void
function XUIVirtualListView:ScrollToTopItem(animate) end


---@public 滚动至索引处
---@param animate boolean
---@return void
function XUIVirtualListView:ScrollToBottomItem(animate) end


---@public 滚动至索引处
---@param idx number
---@param animate boolean
---@param setAsFirst boolean
---@return void
function XUIVirtualListView:ScrollToItem(idx, animate, setAsFirst) end


---@public 从代理的数据源中重新接在数据.
---@param needRelease boolean
---@return void
function XUIVirtualListView:ReloadData(needRelease) end


---@public 从freelist poll中获取一个节点,以此达到节点复用目的.
---@return XUIVirtualListViewItem
function XUIVirtualListView:GetFreeItem() end


---@public 获取图片，XUILayout默认有一张图片作为XUILayout的背景。该函数会返回这张图片的实例（XUIImage）
---@return XUIImage 图片指针
function XUIVirtualListView:GetImage() end


---@public 加载一张纹理作为XUILayout的背景图片
---@param strTexture string 纹理文件路径名
---@param eTextureType number 纹理类型（单张、合图、渲染纹理(rtt)）
---@return void
function XUIVirtualListView:LoadBackGroundTexture(strTexture, eTextureType) end


---@public 获取背景图片的纹理路径
---@return string 纹理文件路径名
function XUIVirtualListView:GetBackGroundTexture() end


---@public 设置左侧的空白填充
---@param fLeft number 左侧填充大小
---@return void
function XUIVirtualListView:SetLeftPadding(fLeft) end


---@public 设置右侧的空白填充
---@param fRight number 右侧填充大小
---@return void
function XUIVirtualListView:SetRightPadding(fRight) end


---@public 设置顶部的空白填充
---@param fTop number 顶部填充大小
---@return void
function XUIVirtualListView:SetTopPadding(fTop) end


---@public 设置底部的空白填充
---@param fBottom number 底部填充大小
---@return void
function XUIVirtualListView:SetBottomPadding(fBottom) end


---@public 获取左侧的空白填充
---@return number 左侧填充大小
function XUIVirtualListView:GetLeftPadding() end


---@public 获取右侧的空白填充
---@return number 右侧填充大小
function XUIVirtualListView:GetRightPadding() end


---@public 获取顶部的空白填充
---@return number 顶部填充大小
function XUIVirtualListView:GetTopPadding() end


---@public 获取底部的空白填充
---@return number 底部填充大小
function XUIVirtualListView:GetBottomPadding() end


---@public 设置XUILayout中，两个控件之间的横向间隔
---@param fSpaceX number 间隔值（单位像素）
---@return void
function XUIVirtualListView:SetSpaceX(fSpaceX) end


---@public 获取XUILayout中，两个控件之间的横向间隔
---@return number 两个控件之间的间隔值（单位像素）
function XUIVirtualListView:GetSpaceX() end


---@public 设置XUILayout中，两个控件之间的纵向间隔
---@param fSpaceY number 间隔值（单位像素）
---@return void
function XUIVirtualListView:SetSpaceY(fSpaceY) end


---@public 获取XUILayout中，两个控件之间的纵向间隔
---@return number 两个控件之间的间隔值（单位像素）
function XUIVirtualListView:GetSpaceY() end


---@public 判断节点是否在可见范围内
---@param node XUINode
---@return boolean
function XUIVirtualListView:IsNodeVisible(node) end


---@public 切换布局剪裁。 如果你需要裁剪,你需要传递true给这个函数
---@param bEnabled boolean 是否允许被裁切
---@return void
function XUIVirtualListView:EnableClipping(bEnabled) end


---@public 设置滚动方向 当前仅支持横向或纵向
---@param direction number
---@return void
function XUIVirtualListView:SetDirection(direction) end


---@public XUIVirtualListView_GetDirection00
---@return number
function XUIVirtualListView:GetDirection() end


---@public 设置布局 单行单列 or多行多列
---@param value number
---@return void
function XUIVirtualListView:SetLayout(value) end


---@public XUIVirtualListView_GetLayout00
---@return number
function XUIVirtualListView:GetLayout() end


---@public 设置行列数 尽在布局类型为Multi时起作用
---@param count number
---@return void
function XUIVirtualListView:SetRowCount(count) end


---@public XUIVirtualListView_SetColumCount00
---@param count number
---@return void
function XUIVirtualListView:SetColumCount(count) end


---@public XUIVirtualListView_GetRowCount00
---@return number
function XUIVirtualListView:GetRowCount() end


---@public XUIVirtualListView_GetColumCount00
---@return number
function XUIVirtualListView:GetColumCount() end


---@manual 添加滚动事件监听器
---@public XUIVirtualListView_AddScrollEventListener_manual
---@param callback  XUIScrollEventCallback
---@return void
function XUIVirtualListView:AddScrollEventListener(callback) end


---@public 设置是否允许滚动至边界处回弹
---@param enable boolean
---@return void
function XUIVirtualListView:SetBounceEnabled(enable) end


---@public XUIVirtualListView_GetBounceEnabled00
---@return boolean
function XUIVirtualListView:GetBounceEnabled() end


---@public 设置是否允许松手后的惯性滑动
---@param enable boolean
---@return void
function XUIVirtualListView:SetInertiaScrollEnabled(enable) end


---@public XUIVirtualListView_GetInertiaScrollEnabled00
---@return boolean
function XUIVirtualListView:GetInertiaScrollEnabled() end


---@public 获取屏幕范围可见的索引值
---@return number
function XUIVirtualListView:GetVisibleMinIndex() end


---@public XUIVirtualListView_GetVisibleMaxIndex00
---@return number
function XUIVirtualListView:GetVisibleMaxIndex() end


---@public 手动释放缓存
---@param releaseFreeItem boolean
---@return void
function XUIVirtualListView:ReleaseCache(releaseFreeItem) end


---@public 从缓存的节点池中获取对应节点，不存在 返回nullptr
---@param idx number
---@return XUIVirtualListViewItem
function XUIVirtualListView:GetItem(idx) end


---@class XUIVirtualListViewItem : XUIWidget
XUIVirtualListViewItem = {}


---@public 创建并返回一个空的控件实例的指针
---@return XUIVirtualListViewItem 控件指针
function XUIVirtualListViewItem:Create() end


---@public XUIVirtualListViewItem_GetIdx00
---@return number
function XUIVirtualListViewItem:GetIdx() end


---@public XUIVirtualListViewItem_SetIdx00
---@param uIdx number
---@return void
function XUIVirtualListViewItem:SetIdx(uIdx) end


---@public XUIVirtualListViewItem_Reset00
---@return void
function XUIVirtualListViewItem:Reset() end


---@class XUIVirtualListViewDelegate
XUIVirtualListViewDelegate = {}


