---ActionManager是一个单例类，管理所有动作。 通常你不需要直接使用这个类。99的情况下，你将使用Node的接口，
---它提供了更友好的封装 但也有一些情况下，你可能需要使用这个单例。 示例:
---1 当你想要运行一个动作，但目标不是节点类型。
---2 当你想要暂停/恢复动作。
---@class IXUIActionManager : XOwnerRecorder
IXUIActionManager = {}


---@public 增加一个动作，同时还需要提供动作的目标对象，目标对象是否暂停作为参数。 如果目标已经在节点哈希表中存在，
---动作将会被直接添加到节点的哈希表元素中。 如果目标不存在于节点哈希表中，将为这一目标创建一个新的元素，动作将被添加进去。
---当目标状态paused为true，动作将不会被执行.
---@param pAction XUIAction 需要被添加的动作
---@param pTargetNode XUINode 动作的目标对象
---@param bPaused boolean 目标对象是否暂停
---@return boolean
function IXUIActionManager:AddAction(pAction, pTargetNode, bPaused) end


---@public 删除所有动作
---@return void
function IXUIActionManager:RemoveAllActions() end


---@public 从一个特定的目标删除所有动作。 属于该目标的所有的动作将被删除
---@param pTargetNode XUINode pTargetNode一个特定的目标
---@return void
function IXUIActionManager:RemoveAllActionsFromTarget(pTargetNode) end


---@public 删除一个动作
---@param pAction XUIAction 要删除的动作
---@return void
function IXUIActionManager:RemoveAction(pAction) end


---@public 返回指定目标下所有正在运行的动作数量。 组合动作被算作一个动作。例子:
---如果您正在运行7个动作组成的序列动作（Sequence），这个函数将返回1。
---如果你正在运行2个序列动作（Sequence）和5个普通动作，这个函数将返回7。
---@param pTargetNode  XUINode 一个特定的目标
---@return number
function IXUIActionManager:GetNumberofRunningActionsInTarget(pTargetNode) end


---@public 返回所有正在运行的动作数量。
---@return number
function IXUIActionManager:GetNumberOfRunningActions() end


---@public 暂停目标对象：所有正在运行的动作和新添加的动作都将会暂停
---@param pTargetNode XUINode 一个特定的目标
---@return void
function IXUIActionManager:PauseTarget(pTargetNode) end


---@public 让目标对象恢复运行。在执行序列中所有被暂停的动作将重新恢复运行
---@param pTargetNode XUINode 一个特定的目标
---@return void
function IXUIActionManager:ResumeTarget(pTargetNode) end


---@public 暂停所有正在运行的动作，返回一个动作被暂停的目标对象列表
---@return XUINode[]
function IXUIActionManager:PauseAllRunningActions() end


---@public 让一组目标对象恢复运行（用来逆转pauseAllRunningActions效果的便捷函数）
---@param vTargetsToResume XUINode[]
---@return void
function IXUIActionManager:ResumeTargets(vTargetsToResume) end


---@public 计算并更新
---@param dt number
---@return void
function IXUIActionManager:Tick(dt) end


