---@class XUILayout : XUIWidget
XUILayout = {}


---@type number @enum Type
XUILayout.XUI_ABSOLUTE = 0


---@type number @enum Type
XUILayout.XUI_VERTICAL = 0


---@type number @enum Type
XUILayout.XUI_HORIZONTAL = 0


---@type number @enum Type
XUILayout.XUI_GRID = 0


---@type number @enum Type
XUILayout.XUI_TREE = 0


---@type number @enum Order
XUILayout.XUI_NORMAL = 0


---@type number @enum Order
XUILayout.XUI_INVERSE = 0


---@type number @enum ClippingType
XUILayout.XUI_STENCIL = 0


---@type number @enum ClippingType
XUILayout.XUI_SCISSOR = 0


---@public 创建并返回一个空的控件实例的指针
---@return XUILayout 控件指针
function XUILayout:Create() end


---@public 获取图片，XUILayout默认有一张图片作为XUILayout的背景。该函数会返回这张图片的实例（XUIImage）
---@return XUIImage 图片指针
function XUILayout:GetImage() end


---@public 加载一张纹理作为XUILayout的背景图片
---@param strTexture string 纹理文件路径名
---@param eTextureType number 纹理路径类型（相对路径/全局路径）
---@return void
function XUILayout:LoadBackGroundTexture(strTexture, eTextureType) end


---@public 获取背景图片的纹理路径
---@return string 纹理文件路径名
function XUILayout:GetBackGroundTexture() end


---@public 设置上下左右的空白填充（或者说叫留白）
---@param fLeft number 左侧填充大小
---@param fRight number 右侧填充大小
---@param fTop number 顶部填充大小
---@param fBottom number 底部填充大小
---@return void
function XUILayout:SetPadding(fLeft, fRight, fTop, fBottom) end


---@public 设置左侧的空白填充
---@param fLeft number 左侧填充大小
---@return void
function XUILayout:SetLeftPadding(fLeft) end


---@public 设置右侧的空白填充
---@param fRight number 右侧填充大小
---@return void
function XUILayout:SetRightPadding(fRight) end


---@public 设置顶部的空白填充
---@param fTop number 顶部填充大小
---@return void
function XUILayout:SetTopPadding(fTop) end


---@public 设置底部的空白填充
---@param fBottom number 底部填充大小
---@return void
function XUILayout:SetBottomPadding(fBottom) end


---@public 获取上下左右的空白填充
---@return number
---@return number
---@return number
---@return number
---@return void
function XUILayout:GetPadding() end


---@public 获取左侧的空白填充
---@return number 左侧填充大小
function XUILayout:GetLeftPadding() end


---@public 获取右侧的空白填充
---@return number 右侧填充大小
function XUILayout:GetRightPadding() end


---@public 获取顶部的空白填充
---@return number 顶部填充大小
function XUILayout:GetTopPadding() end


---@public 获取底部的空白填充
---@return number 底部填充大小
function XUILayout:GetBottomPadding() end


---@public 设置XUILayout中，两个控件之间的横向间隔
---@param fSpaceX number 间隔值（单位像素）
---@return void
function XUILayout:SetSpaceX(fSpaceX) end


---@public 获取XUILayout中，两个控件之间的横向间隔
---@return number 两个控件之间的间隔值（单位像素）
function XUILayout:GetSpaceX() end


---@public 设置XUILayout中，两个控件之间的纵向间隔
---@param fSpaceY number 间隔值（单位像素）
---@return void
function XUILayout:SetSpaceY(fSpaceY) end


---@public 获取XUILayout中，两个控件之间的纵向间隔
---@return number 两个控件之间的间隔值（单位像素）
function XUILayout:GetSpaceY() end


---@public 设置是否逆序排序
---@param eOrder number XUI_INVERSE,逆序，该Layout管理的控件会逆向布局XUI_NORMAL,正常，默认为XUI_NORMAL
---@return void
function XUILayout:SetOrder(eOrder) end


---@public 获取当前排序类型
---@return number 返回当前排序类型
function XUILayout:GetOrder() end


---@public XUILayout_SetLineIndent00
---@param fIndent number
---@return void
function XUILayout:SetLineIndent(fIndent) end


---@public XUILayout_GetLineIndent00
---@return number
function XUILayout:GetLineIndent() end


---@public 切换布局剪裁。 如果你需要裁剪,你需要传递true给这个函数
---@param bEnabled boolean 是否允许被裁切
---@return void
function XUILayout:EnableClipping(bEnabled) end


---@public 获取布局是否允许被裁切
---@return boolean 是否允许被裁切
function XUILayout:IsClippingEnabled() end


---@public 改变layout的剪裁类型。
---@param eType number 剪裁类型
---@return void
function XUILayout:SetClippingType(eType) end


---@public 获取layout的剪裁类型。
---@return number 剪裁类型
function XUILayout:GetClippingType() end


---@public 改变布局类型
---@param eType number 布局类型
---@return void
function XUILayout:SetLayoutType(eType) end


---@public 获取布局类型
---@return number 布局类型
function XUILayout:GetLayoutType() end


---@public 强制刷新控件的布局，会立刻调用DoLayout()刷新布局
---@return void
function XUILayout:ForceDoLayout() end


---@public 请求刷新控件的布局，会在渲染前调用DoLayout()刷新布局
---@return void
function XUILayout:RequestDoLayout() end


---@public 刷新该XUILayout的控件布局，更新子节点的位置
---当需要刷新布局时，通常情况下使用RequestDoLayout()即可。
---当需要立即获取到刷新后各子节点位置时，可以调用ForceDoLayout()。
---该函数通常情况下不需要直接手动调用。
---@return void
function XUILayout:DoLayout() end


---@public 创建一个布局管理器
---@return XUILayoutManager 返回创建的布局管理器
function XUILayout:CreateLayoutManager() end


---@public 获取布局区域的大小
---@return XVECTOR2 返回布局区域大小
function XUILayout:GetLayoutContentSize() end


---@public 如果一个布局是循环获取焦点，这意味着焦点在layout中移动
---@param bLoop boolean 传入true则设置内部焦点可以循环传递
---@return void
function XUILayout:SetLoopFocus(bLoop) end


---@public 如果启用了焦点循环,那么它将返回true,否则返回false。默认值是false
---@return boolean
function XUILayout:IsLoopFocus() end


---@public 要指定layout是否传递焦点到它的子节点上
---@param bPass boolean
---@return void
function XUILayout:SetPassFocusToChild(bPass) end


---@public 获取layout是否传递焦点到它的子节点上
---@return boolean
function XUILayout:IsPassFocusToChild() end


---@public 移除所有子节点不包括protectchildren 添加此接口是为替代原有removeallchildren接口 scrollview listview调用存在bug
---@param bClean boolean
---@return void
function XUILayout:RemoveAllChildrenNV(bClean) end


---@public 自动排版
---开启后子节点不可见时，不再占据位置
---@param enable boolean 是否开启
---@return void
function XUILayout:EnableAutoLayout(enable) end


---@public XUILayout_IsAutoLayout00
---@return boolean
function XUILayout:IsAutoLayout() end


---@public 子节点自适应宽高
---@return void
function XUILayout:AutoFitWidthOrHeight() end


