---@class XUIScrollView : XUILayout
XUIScrollView = {}


---@type number @enum ScrollviewEventType
XUIScrollView.SCROLLVIEW_EVENT_SCROLL_TO_TOP = 0


---@type number @enum ScrollviewEventType
XUIScrollView.SCROLLVIEW_EVENT_SCROLL_TO_BOTTOM = 0


---@type number @enum ScrollviewEventType
XUIScrollView.SCROLLVIEW_EVENT_SCROLL_TO_LEFT = 0


---@type number @enum ScrollviewEventType
XUIScrollView.SCROLLVIEW_EVENT_SCROLL_TO_RIGHT = 0


---@type number @enum ScrollviewEventType
XUIScrollView.SCROLLVIEW_EVENT_SCROLLING = 0


---@type number @enum ScrollviewEventType
XUIScrollView.SCROLLVIEW_EVENT_BOUNCE_TOP = 0


---@type number @enum ScrollviewEventType
XUIScrollView.SCROLLVIEW_EVENT_BOUNCE_BOTTOM = 0


---@type number @enum ScrollviewEventType
XUIScrollView.SCROLLVIEW_EVENT_BOUNCE_LEFT = 0


---@type number @enum ScrollviewEventType
XUIScrollView.SCROLLVIEW_EVENT_BOUNCE_RIGHT = 0


---@type number @enum ScrollviewEventType
XUIScrollView.SCROLLVIEW_EVENT_SCROLLING_BEGAN = 0


---@type number @enum ScrollviewEventType
XUIScrollView.SCROLLVIEW_EVENT_SCROLLING_ENDED = 0


---@type number @enum ScrollviewEventType
XUIScrollView.SCROLLVIEW_EVENT_AUTOSCROLL_ENDED = 0


---@type number @enum Direction
XUIScrollView.XUI_NONE = 0


---@type number @enum Direction
XUIScrollView.XUI_VERTICAL = 0


---@type number @enum Direction
XUIScrollView.XUI_HORIZONTAL = 0


---@type number @enum Direction
XUIScrollView.XUI_BOTH = 0


---@type number @enum EventType 因Touch事件引起的滑动到顶端时调用，不包括惯性
XUIScrollView.XUI_SCROLL_TO_TOP = 0


---@type number @enum EventType 因Touch事件引起的滑动到底端时调用，不包括惯性
XUIScrollView.XUI_SCROLL_TO_BOTTOM = 0


---@type number @enum EventType 因Touch事件引起的滑动到左端时调用，不包括惯性
XUIScrollView.XUI_SCROLL_TO_LEFT = 0


---@type number @enum EventType 因Touch事件引起的滑动到右端时调用，不包括惯性
XUIScrollView.XUI_SCROLL_TO_RIGHT = 0


---@type number @enum EventType 因Touch事件引起的滑动时调用
XUIScrollView.XUI_SCROLLING = 0


---@type number @enum EventType
XUIScrollView.XUI_BOUNCE_TOP = 0


---@type number @enum EventType
XUIScrollView.XUI_BOUNCE_BOTTOM = 0


---@type number @enum EventType
XUIScrollView.XUI_BOUNCE_LEFT = 0


---@type number @enum EventType
XUIScrollView.XUI_BOUNCE_RIGHT = 0


---@type number @enum EventType 只要在动就会调用
XUIScrollView.XUI_CONTAINER_MOVED = 0


---@type number @enum EventType 因Touch事件引起的滑动开始时调用
XUIScrollView.XUI_SCROLLING_BEGAN = 0


---@type number @enum EventType 因Touch事件引起的滑动结束时调用
XUIScrollView.XUI_SCROLLING_ENDED = 0


---@type number @enum EventType 惯性滑动开始时调用
XUIScrollView.XUI_AUTOSCROLL_BEGAN = 0


---@type number @enum EventType 惯性滑动结束时调用
XUIScrollView.XUI_AUTOSCROLL_ENDED = 0


---@type number @enum EventType 已经到顶/左了，接着往顶/左滑，然后松手
XUIScrollView.XUI_TOP_ON_RELEASE = 0


---@type number @enum EventType 已经到顶/左了，接着往顶/左滑，持续调用
XUIScrollView.XUI_TOP_ON_MOVE = 0


---@type number @enum EventType 已经到底/右了，接着往底/右滑，然后松手
XUIScrollView.XUI_BOTTOM_ON_RELEASE = 0


---@type number @enum EventType 已经到底/右了，接着往底/右滑，持续调用
XUIScrollView.XUI_BOTTOM_ON_MOVE = 0


---@public 创建并返回一个空的控件实例的指针
---@return XUIScrollView 控件指针
function XUIScrollView:Create() end


---@public 改变滚动视图的方向
---@param eDir number 滚动方向的枚举
---@return void
function XUIScrollView:SetDirection(eDir) end


---@public 获取滚动视图的方向
---@return number 滚动方向的枚举
function XUIScrollView:GetDirection() end


---@public 获取滚动视图的内部布局容器，该布局容器为滚动视图的子节点
---@return XUILayout
function XUIScrollView:GetInnerContainer() end


---@public 停止自动滚动
---@return void
function XUIScrollView:StopAutoScroll() end


---@public 将内部的布局容器滚动到滚动视图的底部边界
---@param fTimeInSec number 该动作所需时间，以秒计
---@param bAttenuated boolean 该动作进行时，滚动速度是否会衰减
---@return void
function XUIScrollView:ScrollToBottom(fTimeInSec, bAttenuated) end


---@public 将内部的布局容器滚动到滚动视图的顶部边界
---@param fTimeInSec number 该动作所需时间，以秒计
---@param bAttenuated boolean 该动作进行时，滚动速度是否会衰减
---@return void
function XUIScrollView:ScrollToTop(fTimeInSec, bAttenuated) end


---@public 将内部的布局容器滚动到滚动视图的左侧边界
---@param fTimeInSec number 该动作所需时间，以秒计
---@param bAttenuated boolean 该动作进行时，滚动速度是否会衰减
---@return void
function XUIScrollView:ScrollToLeft(fTimeInSec, bAttenuated) end


---@public 将内部的布局容器滚动到滚动视图的右侧边界
---@param fTimeInSec number 该动作所需时间，以秒计
---@param bAttenuated boolean 该动作进行时，滚动速度是否会衰减
---@return void
function XUIScrollView:ScrollToRight(fTimeInSec, bAttenuated) end


---@public 将内部的布局容器滚动到滚动视图的左上角
---@param fTimeInSec number 该动作所需时间，以秒计
---@param bAttenuated boolean 该动作进行时，滚动速度是否会衰减
---@return void
function XUIScrollView:ScrollToTopLeft(fTimeInSec, bAttenuated) end


---@public 将内部的布局容器滚动到滚动视图的右上角
---@param fTimeInSec number 该动作所需时间，以秒计
---@param bAttenuated boolean 该动作进行时，滚动速度是否会衰减
---@return void
function XUIScrollView:ScrollToTopRight(fTimeInSec, bAttenuated) end


---@public 将内部的布局容器滚动到滚动视图的左下角
---@param fTimeInSec number 该动作所需时间，以秒计
---@param bAttenuated boolean 该动作进行时，滚动速度是否会衰减
---@return void
function XUIScrollView:ScrollToBottomLeft(fTimeInSec, bAttenuated) end


---@public 将内部的布局容器滚动到滚动视图的右下角
---@param fTimeInSec number 该动作所需时间，以秒计
---@param bAttenuated boolean 该动作进行时，滚动速度是否会衰减
---@return void
function XUIScrollView:ScrollToBottomRight(fTimeInSec, bAttenuated) end


---@public 按百分比竖直滚动内部布局容器
---@param fPercent number 百分比，从0至100
---@param fTimeInSec number 该动作所需时间，以秒计
---@param bAttenuated boolean 该动作进行时，滚动速度是否会衰减
---@return void
function XUIScrollView:ScrollToPercentVertical(fPercent, fTimeInSec, bAttenuated) end


---@public 按百分比水平滚动内部布局容器
---@param fPercent number 百分比，从0至100
---@param fTimeInSec number 该动作所需时间，以秒计
---@param bAttenuated boolean 该动作进行时，滚动速度是否会衰减
---@return void
function XUIScrollView:ScrollToPercentHorizontal(fPercent, fTimeInSec, bAttenuated) end


---@public 在竖直方向和水平方向分别按一定的百分比滚动内部布局容器
---@param vPercent XVECTOR2 百分比，x分量代表水平百分比，y分两代表竖直百分比
---@param fTimeInSec number 该动作所需时间，以秒计
---@param bAttenuated boolean 该动作进行时，滚动速度是否会衰减
---@return void
function XUIScrollView:ScrollToPercentBothDirection(vPercent, fTimeInSec, bAttenuated) end


---@public 获取垂直滚动内部布局容器的百分比，并返回
---@return number
function XUIScrollView:GetScrolledPercentVertical() end


---@public 获取水平滚动内部布局容器的百分比，并返回
---@return number
function XUIScrollView:GetScrolledPercentHorizontal() end


---@public 获取水平和垂直滚动内部布局容器的百分比，并返回（x分量代表水平百分比，y分两代表竖直百分比）
---@return XVECTOR2
function XUIScrollView:GetScrolledPercentBothDirection() end


---@public 将内部布局容器移至视图底端
---@return void
function XUIScrollView:JumpToBottom() end


---@public 将内部布局容器移至视图顶端
---@return void
function XUIScrollView:JumpToTop() end


---@public 将内部布局容器移至视图左侧
---@return void
function XUIScrollView:JumpToLeft() end


---@public 将内部布局容器移至视图右侧
---@return void
function XUIScrollView:JumpToRight() end


---@public 将内部布局容器移至视图左上角
---@return void
function XUIScrollView:JumpToTopLeft() end


---@public 将内部布局容器移至视图右上角
---@return void
function XUIScrollView:JumpToTopRight() end


---@public 将内部布局容器移至视图左下角
---@return void
function XUIScrollView:JumpToBottomLeft() end


---@public 将内部布局容器移至视图右下角
---@return void
function XUIScrollView:JumpToBottomRight() end


---@public 按一定的百分比竖直滚动视图内的布局容器
---@param fPercent number 百分比
---@return void
function XUIScrollView:JumpToPercentVertical(fPercent) end


---@public 按一定的百分比水平滚动视图内的布局容器
---@param fPercent number 百分比
---@return void
function XUIScrollView:JumpToPercentHorizontal(fPercent) end


---@public 按一定的百分比水平和竖直滚动视图内的布局容器
---@param vPercent XVECTOR2 x分量为水平方向的百分比，y分量为竖直方向的百分比
---@return void
function XUIScrollView:JumpToPercentBothDirection(vPercent) end


---@public 更改内部布局容器的尺寸大小，内部容器的尺寸必须大于或等于滚动视图的尺寸
---@param vSize XVECTOR2 内部容器的尺寸
---@return void
function XUIScrollView:SetInnerContainerSize(vSize) end


---@public 获取内部布局容器的尺寸大小，内部容器的尺寸必须大于或等于滚动视图的尺寸
---@return XVECTOR2 内部容器的尺寸
function XUIScrollView:GetInnerContainerSize() end


---@public 设置内部布局容器的位置
---@param vPos XVECTOR2
---@return void
function XUIScrollView:SetInnerContainerPosition(vPos) end


---@public 获取内部布局容器的位置
---@return XVECTOR2 内部容器的位置
function XUIScrollView:GetInnerContainerPosition() end


---@public 设置当滚动到边界时，是否内部容器发生弹回(bounce)效果
---@param bEnabled boolean 是否回弹
---@return void
function XUIScrollView:SetBounceEnabled(bEnabled) end


---@public 获取当滚动到边界时，是否内部容器发生弹回(bounce)效果
---@return boolean 是否回弹
function XUIScrollView:IsBounceEnabled() end


---@public 设置是否开启滚动惯性
---@param bEnabled boolean 是否开启滚动惯性
---@return void
function XUIScrollView:SetInertiaScrollEnabled(bEnabled) end


---@public 获取是否开启滚动惯性
---@return boolean 是否开启滚动惯性
function XUIScrollView:IsInertiaScrollEnabled() end


---@public 设置是否启用滚动条
---@param enabled boolean 是否启用滚动条
---@return void
function XUIScrollView:SetScrollBarEnabled(enabled) end


---@public 获取是否启用滚动条
---@return boolean 是否启用滚动条
function XUIScrollView:IsScrollBarEnabled() end


---@public 设置滚动条宽度
---@param fWidth number 宽度
---@return void
function XUIScrollView:SetScrollBarWidth(fWidth) end


---@public 获取滚动条宽度
---@return number 滚动条宽度
function XUIScrollView:GetScrollBarWidth() end


---@public 设置滚动条颜色
---@param color  XCOLORBASE 颜色
---@return void
function XUIScrollView:SetScrollBarColor(color) end


---@public 获取滚动条颜色
---@return XCOLORBASE 滚动条颜色
function XUIScrollView:GetScrollBarColor() end


---@public 加载滚动条纹理
---@param strTexture string 纹理路径
---@param eTextureType number 纹理类型
---@return void
function XUIScrollView:LoadScrollBarTexture(strTexture, eTextureType) end


---@public 获取滚动条纹理
---@return string 纹理路径
function XUIScrollView:GetScrollBarTexture() end


---@public 获取当前垂直进度条的进度百分比
---@return number 返回当前垂直进度条的进度百分比。
function XUIScrollView:GetVerticalScrollBarPosPercent() end


---@public 获取当前水平进度条的进度百分比
---@return number 返回当前水平进度条的进度百分比。
function XUIScrollView:GetHorizontalScrollBarPosPercent() end


---@public 判断是否滚动
---@return boolean
function XUIScrollView:IsScrolling() end


---@public 判断是否自动滚动
---@return boolean
function XUIScrollView:IsAutoScrolling() end


---@manual xelua_XEngine_XUIScrollView_AddScrollViewEventListener_manual
---@public XUIScrollView_AddScrollViewEventListener_manual
---@param callback  std::function<void(XUINode*, EventType)>
---@return void
function XUIScrollView:AddScrollViewEventListener(callback) end


---@manual xelua_XEngine_XUIScrollView_AddScrollViewDragEnableCallback_manual
---@public XUIScrollView_AddScrollViewDragEnableCallback_manual
---@param callback  std::function<bool(XUINode*)>
---@return void
function XUIScrollView:AddScrollViewDragEnableCallback(callback) end


---@public XUIScrollView_SetMovePrevEnabled00
---@param bMovePrev boolean
---@return void
function XUIScrollView:SetMovePrevEnabled(bMovePrev) end


---@public XUIScrollView_SetMoveNextEnabled00
---@param bMoveNext boolean
---@return void
function XUIScrollView:SetMoveNextEnabled(bMoveNext) end


