---UI的对齐组件
---@class XUIWidgetAlignment : XUIComponent
XUIWidgetAlignment = {}


---@type number @enum HorizontalEdge 不对齐
XUIWidgetAlignment.XUI_NONE = 0


---@type number @enum HorizontalEdge 左对齐
XUIWidgetAlignment.XUI_LEFT = 0


---@type number @enum HorizontalEdge 右对齐
XUIWidgetAlignment.XUI_RIGHT = 0


---@type number @enum HorizontalEdge 左右拉伸对齐
XUIWidgetAlignment.XUI_LEFT_RIGHT = 0


---@type number @enum HorizontalEdge 居中齐
XUIWidgetAlignment.XUI_CENTER = 0


---@type number @enum VerticalEdge 不对齐
XUIWidgetAlignment.XUI_NONE = 0


---@type number @enum VerticalEdge 上对齐
XUIWidgetAlignment.XUI_TOP = 0


---@type number @enum VerticalEdge 下对齐
XUIWidgetAlignment.XUI_BOTTOM = 0


---@type number @enum VerticalEdge 上下拉伸对齐
XUIWidgetAlignment.XUI_TOP_BOTTOM = 0


---@type number @enum VerticalEdge 居中齐
XUIWidgetAlignment.XUI_CENTER = 0


---@type number @enum AlignmentMode 设置一次
XUIWidgetAlignment.XUI_ONCE = 0


---@type number @enum AlignmentMode 大小或位置发生变化时
XUIWidgetAlignment.XUI_TRANSFORM = 0


---@type number @enum AlignmentMode 每帧更新
XUIWidgetAlignment.XUI_PER_FRAME = 0


---@public 创建一个XUIWidgetAlignment对齐组件
---@param pNode XUINode 目标节点
---@return XUIWidgetAlignment 创建出的XUIWidgetAlignment组件
function XUIWidgetAlignment:Create(pNode) end


---@public XUIWidgetAlignment_Create01
---@return XUIWidgetAlignment
function XUIWidgetAlignment:Create() end


---@public XUIWidgetAlignment_new00
---@return XUIWidgetAlignment
function XUIWidgetAlignment:new() end


---@public 获取对齐对象
---@return XUINode 对齐对象
function XUIWidgetAlignment:GetTarget() end


---@public 设置对齐对象
---@param pNode XUINode 对齐的目标节点
---@return void
function XUIWidgetAlignment:SetTarget(pNode) end


---@public 获取水平对齐策略
---@return number 返回水平对齐策略。
function XUIWidgetAlignment:GetHorizontalEdge() end


---@public 设置水平对齐策略
---XUI_LEFT 左对齐，以保证控件的最左边与父控件的最左边重合。
---XUI_RIGHT 右对齐 以保证控件的最右侧与父控件的最右侧重合。
---XUI_LEFT_RIGHT 左右两侧对齐 以保证控件的两侧和父控件的两侧重合，注意可能会拉伸控件来保证两侧对齐。
---XUI_CENTER 居中。
---@param eEdge number
---@return void
function XUIWidgetAlignment:SetHorizontalEdge(eEdge) end


---@public 获取垂直对齐策略
---@return number 返回垂直对齐策略。
function XUIWidgetAlignment:GetVerticalEdge() end


---@public 设置垂直对齐策略
---XUI_TOP 上对齐，以保证控件的最上边与父控件的最上边重合。
---XUI_BOTTOM 下对齐 以保证控件的最下侧与父控件的最下侧重合。
---XUI_TOP_BOTTOM 上下两侧对齐 以保证控件的两侧和父控件的两侧重合，注意可能会拉伸控件来保证两侧对齐。
---XUI_CENTER 居中。
---@param eEdge number
---@return void
function XUIWidgetAlignment:SetVerticalEdge(eEdge) end


---@public 获取左边距
---@return number
function XUIWidgetAlignment:GetLeftMargin() end


---@public 设置左边距，在水平对齐策略为XUI_LEFT或XUI_LEFT_RIGHT时生效。
---@param fMargin number 该值表示左对齐时，控件的最左侧相对于父控件的最左侧(向右)相差fMargin像素。
---@return void
function XUIWidgetAlignment:SetLeftMargin(fMargin) end


---@public 获取右边距
---@return number
function XUIWidgetAlignment:GetRightMargin() end


---@public 设置右边距，在水平对齐策略为XUI_RIGHT或XUI_LEFT_RIGHT时生效。
---@param fMargin number 该值表示右对齐时，控件的最右侧相对于父控件的最右侧(向左)相差fMargin像素。
---@return void
function XUIWidgetAlignment:SetRightMargin(fMargin) end


---@public 获取上边距
---@return number
function XUIWidgetAlignment:GetTopMargin() end


---@public 设置上边距，在垂直对齐策略为XUI_TOP或XUI_TOP_BOTTOM时生效。
---@param fMargin number 该值表示上对齐时，控件的最上侧相对于父控件的最上侧(向下)相差fMargin像素。
---@return void
function XUIWidgetAlignment:SetTopMargin(fMargin) end


---@public 获取下边距
---@return number
function XUIWidgetAlignment:GetBottomMargin() end


---@public 设置下边距，在垂直对齐策略为XUI_BOTTOM或XUI_TOP_BOTTOM时生效。
---@param fMargin number 该值表示下对齐时，控件的最下侧相对于父控件的最下侧(向上)相差fMargin像素。
---@return void
function XUIWidgetAlignment:SetBottomMargin(fMargin) end


---@public 获取左边距(比例)
---@return number 左边距(比例)
function XUIWidgetAlignment:GetLeftMarginPercent() end


---@public 设置左边距(比例)
---@param fMarginPercent number 左边距(比例)
---@return void
function XUIWidgetAlignment:SetLeftMarginPercent(fMarginPercent) end


---@public 获取右边距(比例)
---@return number 右边距(比例)
function XUIWidgetAlignment:GetRightMarginPercent() end


---@public 设置右边距(比例)
---@param fMarginPercent number 右边距(比例)
---@return void
function XUIWidgetAlignment:SetRightMarginPercent(fMarginPercent) end


---@public 获取上边距(比例)
---@return number 上边距(比例)
function XUIWidgetAlignment:GetTopMarginPercent() end


---@public 设置上边距(比例)
---@param fMarginPercent number 上边距(比例)
---@return void
function XUIWidgetAlignment:SetTopMarginPercent(fMarginPercent) end


---@public 获取下边距(比例)
---@return number 下边距(比例)
function XUIWidgetAlignment:GetBottomMarginPercent() end


---@public 设置下边距(比例)
---@param fMarginPercent number 下边距(比例)
---@return void
function XUIWidgetAlignment:SetBottomMarginPercent(fMarginPercent) end


---@public 刷新对齐
---@return void
function XUIWidgetAlignment:RefreshLayout() end


---@public 刷新对齐(水平方向)
---@return void
function XUIWidgetAlignment:RefreshHorizontalMargin() end


---@public 刷新对齐(垂直方向)
---@return void
function XUIWidgetAlignment:RefreshVerticalMargin() end


---@public XUIWidgetAlignment_SetAlignmentMode00
---@param mode number
---@return void
function XUIWidgetAlignment:SetAlignmentMode(mode) end


---@public XUIWidgetAlignment_GetAlignmentMode00
---@return number
function XUIWidgetAlignment:GetAlignmentMode() end


---@type string @readonly 
XUIWidgetAlignment.COMPONENT_TYPENAME = ''


---@type number @readonly 
XUIWidgetAlignment.COMPONENT_TYPEID = 0


