---@class XEMath
XEMath = {}


---@public 平方根倒数
---@param fNumber number 输入数值
---@return number 输出数值
function XEMath:InvSqrt(fNumber) end


---@public 计算一个浮点数的反正弦.
---@param Value number 输入值
---@return number 反正弦结果
function XEMath:FastAsin(Value) end


---@public 把一个角度规范化到[0,2*PI).
---@param radian number 输入值
---@return number 规范化结果
function XEMath:ClampAxis(radian) end


---@public 把一个角度规范化到(-PI,PI].
---@param radian number 输入值
---@return number 规范化结果
function XEMath:NormalizeAxis(radian) end


---@public 取模运算.
---@param X number 输入值X
---@param Y number 输入值Y
---@return number 结果
function XEMath:Xmod(X, Y) end


---@public 计算 y/x 反正切值.
---@param Y number 输入值Y
---@param X number 输入值X
---@return number 结果
function XEMath:Atan2(Y, X) end


---@public 计算三角形面积.
---@param v1 XVECTOR2 点坐标1
---@param v2 XVECTOR2 点坐标2
---@param v3 XVECTOR2 点坐标3
---@return number 结果
function XEMath:AreaOfTriangle(v1, v2, v3) end


---@public 是否是负浮点数.
---@param A number 判断的浮点数
---@return boolean 结果
function XEMath:IsNegativeFloat(A) end


---@public 判定浮点型数据是否溢出
---@param A number 浮点数
---@return boolean 是否溢出
function XEMath:IsNaN(A) end


---@public 如果是一个有限数值返回true (not NaN and not Infinity).
---@param A number
---@return boolean
function XEMath:IsFinite(A) end


---@public 判断一个浮点数是否接近0.
---@param Value number
---@param ErrorTolerance number
---@return boolean
function XEMath:IsNearlyZero(Value, ErrorTolerance) end


---@public 返回对Value的 sin值、cos值.
---@param ScalarSin number [out]Value的sin值
---@param ScalarCos number [out]Value的cos值
---@param Value number 输入数据
---@return void
function XEMath:SinCos(ScalarSin, ScalarCos, Value) end


---@public 四元数转欧拉角
---@param quat XQUATERNION 输入的四元数
---@return number
---@return number
---@return number
---@return void
function XEMath:QuaternionToEuler(quat) end


---@public 欧拉角转矩阵
---@param fPitch number 俯仰角
---@param fYaw number 偏航角
---@param fRoll number 翻滚角
---@return XMATRIX4
---@return void
function XEMath:EulerToMatrix(fPitch, fYaw, fRoll) end


---@public 欧拉角转四元数
---@param fPitch number 俯仰角
---@param fYaw number 偏航角
---@param fRoll number 翻滚角
---@return XQUATERNION
---@return void
function XEMath:EulerToQuaternion(fPitch, fYaw, fRoll) end


---@public 前方向和上方向向量转四元数
---@param vForwardDir XVECTOR3 前方向向量
---@param vUp XVECTOR3 上方向向量
---@return XQUATERNION
---@return void
function XEMath:DirAndUpToQuaternion(vForwardDir, vUp) end


---@public 四元数转前方向和上方向向量
---@param quat XQUATERNION 输入的四元数
---@return XVECTOR3
---@return XVECTOR3
---@return void
function XEMath:QuaternionToDirAndUp(quat) end


---@public 位置、前方向和上方向向量转矩阵
---@param vLocation XVECTOR3 位置坐标
---@param vForwardDir XVECTOR3 前方向向量
---@param vUp XVECTOR3 上方向向量
---@return XMATRIX4
---@return void
function XEMath:LocationDirAndUpToMatrix(vLocation, vForwardDir, vUp) end


---@public 矩阵转位置、前方向和上方向向量
---@param mat4 XMATRIX4 输入的矩阵
---@return XVECTOR3
---@return XVECTOR3
---@return XVECTOR3
---@return void
function XEMath:MatrixToLocationAndDirAndUp(mat4) end


---@public 从矩阵中获取缩放信息
---@param mat XMATRIX4 输入的矩阵
---@return XVECTOR3 缩放信息
function XEMath:GetScaleFromMatrix(mat) end


---@public 从矩阵中获取四元数信息
---@param mat XMATRIX4 输入的矩阵
---@return XQUATERNION 四元数信息
function XEMath:GetQuaternionFromMatrix(mat) end


---@public 四元数转矩阵
---@param quat XQUATERNION 输入的四元数
---@return XMATRIX4 输出的矩阵
function XEMath:GetMatrixFromQuaternion(quat) end


---@public 从矩阵中去除缩放信息
---@param mat XMATRIX4 矩阵
---@return XMATRIX4 返回自身
function XEMath:EliminateScaleFromMatrix(mat) end


---@public 从矩阵中去除旋转信息
---@param mat XMATRIX4 矩阵
---@return XMATRIX4
function XEMath:EliminateRotateFromMatrix(mat) end


---@public 从矩阵中去除位置信息
---@param mat XMATRIX4 矩阵
---@return XMATRIX4
function XEMath:EliminateTranslateFromMatrix(mat) end


---@public 根据平移信息生成平移矩阵
---@param vTranslate XVECTOR3 平移信息
---@return XMATRIX4 平移矩阵
function XEMath:GenerateTranslateMatrixForVector(vTranslate) end


---@public 根据缩放信息生成缩放矩阵
---@param vScale XVECTOR3 缩放信息
---@return XMATRIX4 缩放矩阵矩阵
function XEMath:GenerateScaleMatrixForVector(vScale) end


---@public XEMath_GenerateScaleMatrixForVector01
---@param vScale XVECTOR3
---@param vOriginPoint XVECTOR3
---@return XMATRIX4
function XEMath:GenerateScaleMatrixForVector(vScale, vOriginPoint) end


---@public 旋转矩阵
---@param mat XMATRIX4 矩阵
---@param quat XQUATERNION 旋转四元数信息
---@return void
function XEMath:RotateMatrixWorld(mat, quat) end


---@public 缩放矩阵
---@param mat XMATRIX4 矩阵
---@param vScale XVECTOR3 缩放信息
---@return void
function XEMath:ScaleMatrixWorld(mat, vScale) end


---@public 对Vec按四元数quat旋转
---@param quat XQUATERNION 旋转四元数信息
---@param vec XVECTOR3 输入的向量
---@return XVECTOR3 旋转后的向量
function XEMath:RotateVector(quat, vec) end


---@public 对vec按四元数quat的逆旋转
---@param quat XQUATERNION 旋转四元数信息
---@param vec XVECTOR3 输入的向量
---@return XVECTOR3 逆旋转后的向量
function XEMath:UnrotateVector(quat, vec) end


---@public 判断两个矩阵是否相等
---@param mat1 XMATRIX4 矩阵1
---@param mat2 XMATRIX4 矩阵2
---@param fEpsilon number 精度，默认1.e-6f
---@return boolean 是否相等
function XEMath:Is2MatrixClosed(mat1, mat2, fEpsilon) end


---@public 判断两个矩阵是否相等
---@param mat1 XMATRIX3 矩阵1
---@param mat2 XMATRIX3 矩阵2
---@param fEpsilon number 精度，默认1.e-6f
---@return boolean 是否相等
function XEMath:Is2MatrixClosed(mat1, mat2, fEpsilon) end


---@public 判断矩阵是否为单位矩阵
---@param mat XMATRIX4 矩阵1
---@return boolean 是否为单位矩阵
function XEMath:IsMatrixIdentity(mat) end


---@public 生成一个正交投影矩阵
---@param fLeft number 左平面到原点距离
---@param fRight number 右平面到原点距离
---@param fButtom number 底平面到原点距离
---@param fTop number 上平面到原点距离
---@param fNear number 近平面到原点距离
---@param fFar number 远平面到原点距离
---@return XMATRIX4 正交投影矩阵
function XEMath:GenerateOrthoProjMatrix(fLeft, fRight, fButtom, fTop, fNear, fFar) end


---@public 产生宽高等比(fSizeRate)的最接近原始宽高（vOriginSize）的宽高
---@param vOriginSize XVECTOR2 原始宽高
---@param fSizeRate number 宽高比
---@param nStepSize number 测试步进长度默认为1.f
---@return XVECTOR2 结果宽高
function XEMath:GenerateMostNearSizeWithRate(vOriginSize, fSizeRate, nStepSize) end


---@public 计算下个2的幂值
---1. 最靠近这个数 2. 大于或等于这个数 3. 是2的N次方
---@param nSize number 输入数值
---@return number 输出幂值
function XEMath:ComputerMin2nSubSquare(nSize) end


---@public 根据平移、旋转、缩放得到矩阵
---@param vTranslate XVECTOR3 代表平移信息的向量
---@param quatRotate XQUATERNION 代表旋转信息的四元数
---@param vScale XVECTOR3 代表缩放信息的向量
---@return XMATRIX4 矩阵
function XEMath:GenerateMatrix(vTranslate, quatRotate, vScale) end


---@public 矩阵相乘
---@param mat1 XMATRIX4 矩阵1
---@param mat2 XMATRIX4 矩阵2
---@return XMATRIX4 返回相乘结果
function XEMath:MultMatrix(mat1, mat2) end


