---@class XEUtility
XEUtility = {}


---@public 获取变换矩阵
---@param pActor XEActor [in]场景Actor
---@param socketName string [in]绑定插槽名称
---@return XETransform 变换矩阵
function XEUtility:GetTransform(pActor, socketName) end


---@public XEUtility_GetTransform01
---@param pActor XEActor
---@param socketName string
---@param offset XVECTOR3
---@return XETransform
function XEUtility:GetTransform(pActor, socketName, offset) end


---@manual 通过UV获取三角形面信息
---@public XEUtility_GetTriangleFaceInfoByUV_manual
---@param pModelIns IXModelInstance [in]模型实例指针
---@param szMeshName string [in]所在Mesh名字
---@param szSkinName string [in]所在Skin名字
---@param uv XVECTOR2 [in]UV信息
---@param nOutTriIndex number [out]匹配到的三角形面索引
---@param outVertices XSkinMeshVertex
---@param outVerIndices number
---@return boolean 是否获取成功
function XEUtility:GetTriangleFaceInfoByUV(pModelIns, szMeshName, szSkinName, uv, nOutTriIndex, outVertices, outVerIndices) end


---@public 通过顶点索引获取顶点Position信息
---@param pModelIns IXModelInstance [in]模型实例指针
---@param szMeshName string [in]所在Mesh名字
---@param szSkinName string [in]所在Skin名字
---@param nVertexIndex number [in]顶点索引
---@return XVECTOR3
---@return boolean 是否获取成功
function XEUtility:GetVertexPositionFromIndex(pModelIns, szMeshName, szSkinName, nVertexIndex) end


---@public 通过顶点索引获取模型空间顶点Position信息
---@param pModelIns IXModelInstance [in]模型实例指针
---@param szMeshName string [in]所在Mesh名字
---@param szSkinName string [in]所在Skin名字
---@param nVertexIndex number [in]顶点索引
---@return XVECTOR3
---@return boolean 是否获取成功
function XEUtility:GetVertexPositionInLocalSpaceFromIndex(pModelIns, szMeshName, szSkinName, nVertexIndex) end


---@public 通过UV获取顶点索引信息
---@param pModelIns IXModelInstance [in]模型实例指针
---@param szMeshName string [in]所在Mesh名字
---@param szSkinName string [in]所在Skin名字
---@param uv XVECTOR2 [in]UV信息
---@return number
---@return boolean 是否获取成功
function XEUtility:GetVertexIndexFromUV(pModelIns, szMeshName, szSkinName, uv) end


---@public 通过UV获取顶点Postion信息
---@param pModelIns IXModelInstance [in]模型实例指针
---@param szMeshName string [in]所在Mesh名字
---@param szSkinName string [in]所在Skin名字
---@param uv XVECTOR2 [in]UV信息
---@return XVECTOR3
---@return boolean 是否获取成功
function XEUtility:GetVertexPositionFromUV(pModelIns, szMeshName, szSkinName, uv) end


---@public 获取当前相机到一个包围盒能看到此包围盒全部的最好距离。
---@param pViewPort XViewport 视口对象指针
---@param box  XCusAABB AABB包围盒
---@return number
function XEUtility:GetBestViewDisOfAABB(pViewPort, box) end


---@public 定位Actor(Camera移动带有飞行曲线，但Camera姿态保持不变)
---@param pActor  XEActor 要定位的Actor
---@param fMultiNum number 倍数，默认为1，倍数越大，最终定位的相机位置越远
---@param bNeedFly boolean 是否让相机移动带有飞行曲线，默认为true
---@return boolean 是否定位成功
function XEUtility:LookAtActorWithCurrentCameraRotation(pActor, fMultiNum, bNeedFly) end


---@public 定位组件(Camera移动带有飞行曲线，但Camera姿态保持不变)
---@param pComponent  XEActorComponent 要定位的组件
---@param pWorld  XEWorld 组件所在的世界
---@param fMultiNum number 倍数，默认为1，倍数越大，最终定位的相机位置越远
---@param bNeedFly boolean 是否让相机移动带有飞行曲线，默认为true
---@return boolean 是否定位成功
function XEUtility:LookAtComponentWithCurrentCameraRotation(pComponent, pWorld, fMultiNum, bNeedFly) end


---@public 定位盒状包围盒(Camera移动带有飞行曲线，但Camera姿态保持不变)
---@param box  XCusAABB 要定位的盒状包围盒
---@param pWorld  XEWorld 包围盒所在的世界
---@param fMultiNum number 倍数，默认为1，倍数越大，最终定位的相机位置越远
---@param bNeedFly boolean 是否让相机移动带有飞行曲线，默认为true
---@return boolean 是否定位成功
function XEUtility:LookAtBoundBoxWithCurrentCameraRotation(box, pWorld, fMultiNum, bNeedFly) end


---@public 定位球状包围盒(Camera移动带有飞行曲线，但Camera姿态保持不变)
---@param sphere  XCusSphere 要定位的球状包围盒
---@param pWorld  XEWorld 包围盒所在的世界
---@param fMultiNum number 倍数，默认为1，倍数越大，最终定位的相机位置越远
---@param bNeedFly boolean 是否让相机移动带有飞行曲线，默认为true
---@return boolean 是否定位成功
function XEUtility:LookAtBoundSphereWithCurrentCameraRotation(sphere, pWorld, fMultiNum, bNeedFly) end


---@public 获取相机飞行曲线控制器
---@return XEAnimCurveFlyController
function XEUtility:GetCameraFlyAnimCurveController() end


---@public 获取Actor飞行曲线控制器
---@return XEAnimCurveFlyController
function XEUtility:GetActorFlyAnimCurveController() end


---@public 获取组件飞行曲线控制器
---@return XEAnimCurveFlyController
function XEUtility:GetActorComponentFlyAnimCurveController() end


---@public 把世界坐标转换为屏幕坐标
---@param pViewPort XEViewport ViewPort指针
---@param vWorld XVECTOR3 要转换的世界坐标
---@return XVECTOR3 转换后的屏幕坐标
function XEUtility:TransformWorld2Screen(pViewPort, vWorld) end


---@public 把屏幕坐标转换为世界坐标
---@param pViewPort XEViewport ViewPort指针
---@param vScreenPos XVECTOR3 要转换的屏幕坐标
---@return XVECTOR3 转换后的世界坐标
function XEUtility:TransformScreen2World(pViewPort, vScreenPos) end


---@public 根据像素坐标和视口，计算拾取射线。射线用近裁剪平面的三维坐标点和方向向量来表示
---@param pViewport XViewport [in]3D视口对象
---@param vecScreenPoint XVECTOR3 [in]像素坐标
---@return XVECTOR3
---@return XVECTOR3
---@return void
function XEUtility:CastRay(pViewport, vecScreenPoint) end


---@public XEUtility_CastRay01
---@param pViewport XEViewport
---@param vecScreenPoint XVECTOR3
---@return XVECTOR3
---@return XVECTOR3
---@return void
function XEUtility:CastRay(pViewport, vecScreenPoint) end


---@public 计算空间中的一点(vecPoint)到指定直线的距离，其中根据一个点 vecLinePoint 和 方向向量 vecLineDirection 可确定一条直线，
---此处 vecLineDirection 要求单位化
---@param vecPoint XVECTOR3
---@param vecLinePoint XVECTOR3
---@param vecLineDirection XVECTOR3 空间直线的方向向量(单位化)
---@param pFraction number 表示vecPoint投影到直线上的投影点与vecLinePoint的(带符号，表示与线的方向向量是否方向一致)距离
---@return number 点到直线的距离
function XEUtility:PointToLineDistance(vecPoint, vecLinePoint, vecLineDirection, pFraction) end


---@public 绘制字符串
---@param pCanvasBase IXCanvasBase
---@param x number 绘制的位置坐标的x分量
---@param y number 绘制的位置坐标的y分量
---@param szString string 要绘制的字符串内容
---@param clr  XCOLORBASE 绘制颜色（XCOLORBASE格式）
---@return void
function XEUtility:DrawString(pCanvasBase, x, y, szString, clr) end


---@public 绘制四边形
---@param pCanvasBase IXCanvasBase
---@param x number 绘制的起始位置坐标的x分量
---@param y number 绘制的起始位置坐标的y分量
---@param nWidth number 绘制的四边形宽度
---@param nHeight number 绘制的四边形高度
---@param clr  XCOLORBASE 绘制颜色（XCOLORBASE格式）
---@param bSolid boolean 是否用颜色填充四边形区域，默认是false
---@param pMat XMATRIX3 叠加矩阵，默认为空。（如果设置了叠加矩阵，绘制信息会叠加上这个矩阵数据）
---@return void
function XEUtility:DrawQuad(pCanvasBase, x, y, nWidth, nHeight, clr, bSolid, pMat) end


---@public 绘制2D直线
---@param pCanvasBase IXCanvasBase
---@param xBegin number 直线的起始点坐标x分量
---@param yBegin number 直线的起始点坐标y分量
---@param xEnd number 直线的结束点坐标x分量
---@param yEnd number 直线的结束点坐标y分量
---@param clr  XCOLORBASE 绘制颜色（XCOLORBASE格式）
---@param pMat XMATRIX3 叠加矩阵，默认为空。（如果设置了叠加矩阵，绘制信息会叠加上这个矩阵数据）
---@return void
function XEUtility:Render2DLine(pCanvasBase, xBegin, yBegin, xEnd, yEnd, clr, pMat) end


---@public 绘制圆弧线或扇形线（注意：屏幕坐标，Y轴向下， X轴向左）
---@param pCanvasBase IXCanvasBase
---@param vPos XVECTOR2 圆弧或扇形圆心点坐标
---@param fRadius number 圆弧或扇形半径
---@param vStartNormalizedDir XVECTOR2 圆弧或扇形起始单位方向向量
---@param vEndNormalizedDir XVECTOR2 圆弧或扇形结束单位方向向量
---@param color  XCOLORBASE 绘制颜色（XCOLORBASE格式）
---@param bClockWise boolean 绘制方向，面向屏幕，xtrue:顺时针，xflase:逆时针，默认是xtrue
---@param bSolid boolean 是否用颜色填充绘制的区域，默认是false
---@param pMat XMATRIX3 叠加矩阵，默认为空。（如果设置了叠加矩阵，绘制信息会叠加上这个矩阵数据）
---@return void
function XEUtility:Render2DCircle(pCanvasBase, vPos, fRadius, vStartNormalizedDir, vEndNormalizedDir, color, bClockWise, bSolid, pMat) end


---@public 获取相机的旋转信息（四元数结果）
---@param pCamera XBaseCamera 要获取的相机指针
---@return XQUATERNION 旋转信息
function XEUtility:GetCameraQuaternion(pCamera) end


---@public 获取相机世界矩阵
---@param pCamera XBaseCamera 要获取的相机指针
---@return XMATRIX4 相机世界矩阵
function XEUtility:GetCameraWorldMatrix(pCamera) end


---@public 把pSourceCamera的参数赋给pTargetCamera
---pTargetCamera 目标相机
---pSourceCamera 源相机
---@param pTargetCamera XBaseCamera
---@param pSourceCamera XBaseCamera
---@return void
function XEUtility:AssignCameraParam(pTargetCamera, pSourceCamera) end


---@public 获取圆形曲线点数组
---@return XVECTOR3[] 生成的曲线上的点位置数组
function XEUtility:GetCircleTrackPoint() end


---@public XEUtility_GetCircleTrackPoint01
---@param vCenter XVECTOR3
---@param fRadius number
---@param nSegment number
---@return XVECTOR3[]
function XEUtility:GetCircleTrackPoint(vCenter, fRadius, nSegment) end


---@public 获取对角矩形曲线点数组
---@return XVECTOR3[] 生成的曲线上的点位置数组
function XEUtility:GetCrossRectTrackPoint() end


---@public XEUtility_GetCrossRectTrackPoint01
---@param vCenter XVECTOR3
---@param fRadius number
---@return XVECTOR3[]
function XEUtility:GetCrossRectTrackPoint(vCenter, fRadius) end


---@public 获取正弦曲线点数组
---@return XVECTOR3[] 生成的曲线上的点位置数组
function XEUtility:GetSinTrackPoint() end


---@public XEUtility_GetSinTrackPoint01
---@param vCenter XVECTOR3
---@param fAmplitude number
---@param fPeriod number
---@return XVECTOR3[]
function XEUtility:GetSinTrackPoint(vCenter, fAmplitude, fPeriod) end


---@public 获取从渲染窗口边缘指向某个3D点的方向线段起始位置
---@param pWorld XEWorld 当前世界指针
---@param vLocation XVECTOR3 [in]当前世界中的3D点
---@param nInnerPixel number [in]此值越大，方向线段越长，默认是128像素
---@return XVECTOR2
---@return XVECTOR2
---@return boolean
function XEUtility:GetViewPointOfLookingLocationAtScreen(pWorld, vLocation, nInnerPixel) end


---@class XEUtility__MaterialKey
local XEUtility__MaterialKey = {}
XEUtility.MaterialKey = XEUtility__MaterialKey


---@type number
XEUtility__MaterialKey.skinId = 0


---@type number
XEUtility__MaterialKey.meshId = 0


---@type number
XEUtility__MaterialKey.lodId = 0


---@type number
XEUtility__MaterialKey.macroId = 0


---@type number
XEUtility__MaterialKey.parameterId = 0


---@type string
XEUtility__MaterialKey.skinName = ''


---@type string
XEUtility__MaterialKey.meshName = ''


---@type string useful for the material instance
XEUtility__MaterialKey.parameterName = ''


---@public XEUtility_MaterialKey_new00
---@return XEUtility__MaterialKey
function XEUtility__MaterialKey:new() end


---@public XEUtility_MaterialKey_new01
---@param _sid number
---@param _lid number
---@param _meid number
---@param _maid number
---@param _pid number
---@return XEUtility__MaterialKey
function XEUtility__MaterialKey:new(_sid, _lid, _meid, _maid, _pid) end


---@class XEUtility__MaterialInfo
local XEUtility__MaterialInfo = {}
XEUtility.MaterialInfo = XEUtility__MaterialInfo


---@type XEUtility::MaterialKey
XEUtility__MaterialInfo.key = {}


---@type XSkin
XEUtility__MaterialInfo.pSkin = {}


---@type IXMaterialInstance
XEUtility__MaterialInfo.pIns = {}


---@type XMaterialSupportMacro
XEUtility__MaterialInfo.pMacro = {}


---@type XMaterialParamDescInfo
XEUtility__MaterialInfo.pParamDescInfo = {}


---@type XMaterialParamTypeValue
XEUtility__MaterialInfo.paramTypeValue = {}


---@type boolean
XEUtility__MaterialInfo.bValid = false


---@public XEUtility_MaterialInfo_new00
---@return XEUtility__MaterialInfo
function XEUtility__MaterialInfo:new() end


---@public 应用材质参数
---@param pModelIns IXModelInstance 模型实例指针
---@param mk  XEUtility::MaterialKey 材质信息
---@param nParamIndex number
---@param fParamVal number 对应参数分量nParamIndex的值
---@return boolean 是否应用成功
function XEUtility:ApplyMaterialParameter(pModelIns, mk, nParamIndex, fParamVal) end


---@public 应用某个纹理材质参数
---@param pModelIns IXModelInstance 模型实例指针
---@param mk  XEUtility::MaterialKey 材质信息
---@param pTexPath string 材质纹理路径
---@return boolean 是否应用成功
function XEUtility:ApplyMaterialParameter(pModelIns, mk, pTexPath) end


---@public 为某个材质应用材质模板类型
---@param pModelIns IXModelInstance 模型实例指针
---@param szSkinName string 模型skin名字
---@param szMaterialInsName string 模型材质实例名字
---@param szMTPath string 要应用的材质模板类型路径
---@return boolean 是否应用成功
function XEUtility:ApplyMaterialType(pModelIns, szSkinName, szMaterialInsName, szMTPath) end


---@public 为某个材质应用纹理
---@param pModelIns IXModelInstance 模型实例指针
---@param szSkinName string 模型skin名字
---@param szMaterialInsName string 模型材质实例名字
---@param szParamDesc string 具体参数名称
---@param szTexPath string 纹理路径
---@return boolean 是否应用成功
function XEUtility:ApplyMaterialTextureParameterValue(pModelIns, szSkinName, szMaterialInsName, szParamDesc, szTexPath) end


---@public 获取某个材质纹理对象
---@param pModelIns IXModelInstance 模型实例指针
---@param szSkinName string 模型skin名字
---@param szMaterialInsName string 模型材质实例名字
---@param szParamDesc string 具体参数名称
---@return IXTexture2D 纹理对象
function XEUtility:GetMaterialInstanceTexture(pModelIns, szSkinName, szMaterialInsName, szParamDesc) end


---@public XEUtility_SetMaterialInstanceTexture00
---@param pModelIns IXModelInstance
---@param szSkinName string
---@param szMaterialInsName string
---@param szParamDesc string
---@param pTexture IXTexture2D
---@param bReleaseMatInsTex boolean
---@return boolean
function XEUtility:SetMaterialInstanceTexture(pModelIns, szSkinName, szMaterialInsName, szParamDesc, pTexture, bReleaseMatInsTex) end


---@public 应用材质参数
---@param pModelIns IXModelInstance 模型实例指针
---@param szSkinName string 模型skin名字
---@param szMaterialInsName string 模型材质实例名字
---@param szParamDesc string 具体参数名称
---@param valueSlot XVECTOR4 要应用参数值，最多可以有4个分量
---@return boolean 是否应用成功
function XEUtility:ApplyMaterialVectorParameterValue(pModelIns, szSkinName, szMaterialInsName, szParamDesc, valueSlot) end


---@public 应用材质参数
---@param pMaterialIns IXMaterialInstance 模型材质实例
---@param szParamDesc string 具体参数名称
---@param valueSlot XVECTOR4 要应用参数值，最多可以有4个分量
---@return boolean 是否应用成功
function XEUtility:ApplyMaterialVectorParameterValue(pMaterialIns, szParamDesc, valueSlot) end


---@public 获取材质类型名称
---@param pModelIns IXModelInstance 模型实例指针
---@param szSkinName string 模型skin名字
---@param szMaterialInsName string 模型材质实例名字
---@return string 获取到的材质类型名称
function XEUtility:GetMaterailType(pModelIns, szSkinName, szMaterialInsName) end


---@public 获取材质纹理参数路径
---@param pModelIns IXModelInstance 模型实例指针
---@param szSkinName string 模型skin名字
---@param szMaterialInsName string 模型材质实例名字
---@param szParamDesc string 具体参数名称
---@return string 获取到的纹理参数路径
function XEUtility:GetMaterailTextureParameterValue(pModelIns, szSkinName, szMaterialInsName, szParamDesc) end


---@public 获取材质参数
---@param pModelIns IXModelInstance 模型实例指针
---@param szSkinName string 模型skin名字
---@param szMaterialInsName string 模型材质实例名字
---@param szParamDesc string 具体参数名称
---@return XVECTOR4 获取到的参数值，最多可以有4个分量
function XEUtility:GetMaterialVectorParameterValue(pModelIns, szSkinName, szMaterialInsName, szParamDesc) end


---@public 获取材质参数
---@param pModelIns IXModelInstance 模型实例指针
---@param szSkinName string 模型skin名字
---@param szMaterialInsName string 模型材质实例名字
---@param szParamDesc string 具体参数名称
---@return XEUtility__MaterialInfo 获取到的材质参数结构体
function XEUtility:GetMaterialParamTypeValue(pModelIns, szSkinName, szMaterialInsName, szParamDesc) end


---@public 把一个材质实例的参数信息应用到另一个材质实例上
---@param pSourceMaterialIns  IXMaterialInstance 源材质实例指针
---@param pDestMaterialIns IXMaterialInstance 目标材质实例指针
---@return boolean 是否应用成功
function XEUtility:ApplyMaterailInsParamToOther(pSourceMaterialIns, pDestMaterialIns) end


---@public 获取材质实例参数
---@param pMaterialIns  IXMaterialInstance 材质实例指针
---@param nParamId number 材质参数id
---@return XEVariant
---@return boolean 是否应获取成功
function XEUtility:GetMaterialParamValue(pMaterialIns, nParamId) end


---@public 设置材质实例参数
---@param pMaterialIns IXMaterialInstance 材质实例指针
---@param nParmId number
---@param valParam  XEVariant
---@param pWorld  XEWorld 如果输入world,则参数路径自动修正（按world中的包路径）
---@return boolean 是否应设置成功
function XEUtility:SetMaterialParamValue(pMaterialIns, nParmId, valParam, pWorld) end


---@public 获得材质实例中可变参数缓存
---@param pMaterialIns IXMaterialInstance 源材质实例指针
---@return xhashtable_XString_and_XEVariant
---@return xhashtable_XString_and_xbool
---@return boolean 是否缓存成功
function XEUtility:CacheMaterialInsParamValues(pMaterialIns) end


---@public 将材质实例中可变参数缓存还原到指定材质实例中
---@param pMaterialIns IXMaterialInstance 源材质实例指针
---@param mVariants xhashtable_XString_and_XEVariant 参数缓存HashTable
---@param mMacros xhashtable_XString_and_xbool 宏开启缓存HashTable
---@param pWorld  XEWorld 如果输入world,则参数路径自动修正（按world中的包路径）
---@return boolean 是否缓存成功
function XEUtility:RestoreMaterialInsParamValuesFromCache(pMaterialIns, mVariants, mMacros, pWorld) end


---@public 改变材质实例中的材质模板（ShaderModel改变），并复用材质实例对应的原来的参数, 注意：参数在变换过程中可能因为不匹配而丢失！
---@param pMaterialIns IXMaterialInstance 源材质实例指针
---@param szMtlPath string
---@param bParamDerived boolean 参数值是否继承
---@param pWorld  XEWorld 如果输入world,则参数路径自动修正（按world中的包路径）
---@return boolean 是否更换成功
function XEUtility:ChangeMaterialTemplate(pMaterialIns, szMtlPath, bParamDerived, pWorld) end


---@public 根据材质实例名字获取对应的原始Mesh名字
---@param pModelIns IXModelInstance [in]模型实例指针
---@param szSkinName string [in]模型skin名字
---@param szMaterialInsName string [in]模型材质实例名字
---@param nLod number [in]指定的Lod
---@return string[]
---@return boolean
function XEUtility:GetRawMeshNameByMaterialInsName(pModelIns, szSkinName, szMaterialInsName, nLod) end


---@public 获取所有Actor类型
---@return string[] 返回Actor类型字符串数组
function XEUtility:GetXECoreActorTypes() end


---@public 输入一张带绿幕图像，并生成纹理
---@param pEngineIns  XEngineInstance
---@param szTexPath string 纹理的路径
---@param bDoMask boolean
---@param fMaskMinH number 如果包含绿幕，指定HSV颜色空间的掩码H的最小值
---@param fMaskMaxH number 如果包含绿幕，指定HSV颜色空间的掩码H的最大值
---@return IXTexture2D
function XEUtility:BuildTex2DWithGreenScreen(pEngineIns, szTexPath, bDoMask, fMaskMinH, fMaskMaxH) end


---@public 输入一张带alpha-mask图像，并生成纹理
---@param pEngineIns  XEngineInstance
---@param szTexPath string 纹理的路径
---@param nAlphaMaskMode number
---@param bDoMask boolean
---@return IXTexture2D
function XEUtility:BuildTex2DWithMaskIn2Parts(pEngineIns, szTexPath, nAlphaMaskMode, bDoMask) end


---@public 将输入（采样）纹理扩展成为一张完整纹理 （指定宽高，纹理的起始位置，纹理缩放），该函数需要较多计算，请勿在tick中调用
---@param pEngineIns  XEngineInstance
---@param pTexOrigin IXTexture2D 纹理实例
---@param nWidth number 原始纹理的宽度
---@param nHeight number 原始纹理的高度
---@param nLeft number 采样纹理在原始纹理空间中的左偏移
---@param nTop number 采样纹理在原始纹理空间中的上偏移
---@param fScale number 采样纹理相对原始纹理的缩放系数(0,1)
---@param bLimitSize1024 boolean 是否限制为1024尺寸以内
---@return IXTexture2D
function XEUtility:FullFillTex2DWithSpecificWHLT(pEngineIns, pTexOrigin, nWidth, nHeight, nLeft, nTop, fScale, bLimitSize1024) end


---@public 释放一张纹理
---@param pTexOrigin IXTexture2D
---@return void
function XEUtility:ReleaseTexture(pTexOrigin) end


---@public 加载一张图片到引擎
---@param pEngineIns  XEngineInstance
---@param szTexPath string 纹理的路径
---@return IXTexture2D
function XEUtility:LoadTex2D(pEngineIns, szTexPath) end


---@public 创建一张纹理,4通道
---@param pEngineIns  XEngineInstance
---@param nWidth number 宽度
---@param nHeight number 高度
---@return IXTexture2D
function XEUtility:CreateDynamicTex2DRGBAWith1Mipmap(pEngineIns, nWidth, nHeight) end


---@public 创建一张纹理,1通道，通常为Alpha数据
---@param pEngineIns  XEngineInstance
---@param nWidth number 宽度
---@param nHeight number 高度
---@return IXTexture2D
function XEUtility:CreateDynamicTex2DAlphaWith1Mipmap(pEngineIns, nWidth, nHeight) end


---@public 重新设置纹理对象的大小
---@param pTex IXTexture2D
---@param nWidth number 宽度
---@param nHeight number 高度
---@return boolean
function XEUtility:ResetDynamicTex2DRGBABuffer(pTex, nWidth, nHeight) end


---@public 把纹理保存成PNG格式文件
---@param pTexture IXTexture 保存的纹理指针(目前只支持纹理格式是XTF_R8G8B8A8!!!)
---@param strPNGPath string png文件名
---@param bOverturn boolean 是否翻转（引擎的纹理不用翻转）
---@return boolean 是否成功
function XEUtility:SaveTextureToPNGFile(pTexture, strPNGPath, bOverturn) end


---@public 把数据保存成PNG格式文件，需要保证数据有效且包括RGBA4个通道！
---@param pData userdata 保存的数据指针
---@param nWidth number 图片宽度
---@param nHeight number 图片高度
---@param strPNGPath string png文件名
---@param bOverturn boolean 是否翻转（引擎的纹理不用翻转）
---@return boolean 是否成功
function XEUtility:SaveDataToPNGFile(pData, nWidth, nHeight, strPNGPath, bOverturn) end


---@public 根据跟随规则清洗矩阵
---@param eFollowRules number
---@param transformPre  XETransform
---@param matCur XMATRIX4
---@return XMATRIX4 返回清洗矩阵
function XEUtility:WashMatrixByFollowRules(eFollowRules, transformPre, matCur) end


---@public 根据跟随规则清洗矩阵
---@param pActor XEActor 待查找的Actor
---@param pWorld XEWorld Actor所属的世界
---@return XEPrefabInstance 包含Actor的Prefab实例
function XEUtility:IsPartOfPrefabInstance(pActor, pWorld) end


---@public XEUtility_PostAttachToActor00
---@param pChildActor XEActor
---@param pParentActor XEActor
---@return void
function XEUtility:PostAttachToActor(pChildActor, pParentActor) end


---@public XEUtility_PreDetachFromActor00
---@param pChildActor XEActor
---@param pParentActor XEActor
---@return void
function XEUtility:PreDetachFromActor(pChildActor, pParentActor) end


---@public 获取资源有效路径
---@param pFullRelativeAssetPackagePath string .xscene文件的全路径
---@param pEvalAssetPath string 资源路径
---@param bNoRepeatPortionPath boolean 是否去掉重复文件夹，默认是不去掉
---@return string 返回拼接后的资源有效路径
function XEUtility:GetAssetPackageValidPath(pFullRelativeAssetPackagePath, pEvalAssetPath, bNoRepeatPortionPath) end


---@class XEAsyncLoading
XEAsyncLoading = {}


---@type number @enum ResultType
XEAsyncLoading.Failed = 0


---@type number @enum ResultType
XEAsyncLoading.Succeeded = 0


---@type number @enum ResultType
XEAsyncLoading.Canceled = 0


