---@class XEActor : XEEventReceiver
XEActor = {}


---@type number @enum EDrawDebugType 除了渲染 XEActor 本身外，不渲染任何其他辅助元素。
XEActor.EDD_DRAW_NONE = 0


---@type number @enum EDrawDebugType 除了渲染 XEActor 本身外，还渲染其他辅助部件，如相机视椎体的线框。such as camera frustum..
XEActor.EDD_DRAW_AUXILIARY = 0


---@type number @enum EDrawDebugType 除了渲染 XEActor 本身外，还渲染 dummy.draw dummy
XEActor.EDD_DUMMY_SHAPE = 0


---@type number @enum EDrawDebugType 除了渲染 XEActor 本身外，还渲染包围盒. draw bounding box
XEActor.EDD_BOUNDINGBOX = 0


---@type number @enum EDrawDebugType
XEActor.EDD_OUTLINE = 0


---@public 更新当前XEActor帧
---@param fDelMs number 表示当前XEActor每帧更新的时间间隔(ms)
---@param bForceTick boolean 是否强制Tick.如果为true，不管当前Actor是否隐藏，都会更新；如果为false，当前Actor如果隐藏时不更新。
---@return void
function XEActor:Tick(fDelMs, bForceTick) end


---@public 获取当前XEActor的类型，如XECameraActor的类型是“CameraActor”；XEDirLightActor的类型是 “DirLightActor”。
---@return string
function XEActor:GetTypeName() end


---@public 在初始化完成后， 可能会进行一些后处理操作
---@return void
function XEActor:PostInitialized() end


---@public 获取Actor渲染顺序影响因子（位置的z分量）
---@return number
function XEActor:GetRenderOrderFactor() end


---@public 更新物理
---@param fDel number 间隔
---@return void
function XEActor:PresentPhysics(fDel) end


---@public 渲染当前XEActor的辅助元素，默认不渲染任何辅助元素，子类可重写此函数来渲染不同的元素，如相机Actor可渲染其视椎体的线框。
---@param pViewport XEViewport 当前Actor所属的世界对象绑定的视口指针
---@return void
function XEActor:RenderDrawDebug(pViewport) end


---@public 设置当前XEActor的根组件。
---如果当前 XEActor 的根组件为空，则直接将pRootComponent赋值给根组件；
---如果当前根组件不为空并且不是pRootComponent，则把当前XEActor的根组件修改为pRootComponent。
---@param pRootComponent XEActorComponent
---@return boolean 表示给当前XEActor根组件赋值成功或失败
function XEActor:SetRootComponent(pRootComponent) end


---@public 根据指定的嵌套规则，将当前XEActor附加到指定XEActor(pActor)上，即父子Actor嵌套。
---@param pActor XEActor 当前XEActor将要附加到的XEActor，也就是pActor将变为当前XEActor的父节点。
---@return void
---@attention 此函数默认采用KeepWorld的嵌套规则，含义是子Actor附加到父Actor时，子Actor的世界状态（位置、朝向和大小）不改变。
function XEActor:AttachToActor(pActor) end


---@public 附加到其他Actor,采用KeepWorld的嵌套规则，将当前 XEActor 附加到指定 XEActor(pActor)上，即父子 Actor 嵌套。
---@param pActor XEActor 当前XEActor将要附加到的XEActor，也就是pActor将变为当前XEActor的父节点。
---@param attachRules  XEAttachRules 指定的父子Actor嵌套规则
---@return void
---@attention 目前XECoreSDK中支持三种父子嵌套的规则，分别是KeepRelative 、KeepWorld 、SnapToTarget，具体可参见 XEAttachRules 部分
function XEActor:AttachToActor(pActor, attachRules) end


---@public 将当前 XEActor 附加到指定pParentActor的指定节点上，即父子Actor嵌套。如果父Actor不存在szBindNodeName对应的节点，
---则父子嵌套失败。默认采用XEAttachRules::SnapToTargetNotIncludingScale 嵌套规则。
---子 Actor 的平移和旋转采用父 Actor的节点的平移和旋转，子 Actor 的缩放还是采用自身的世界坐标系的缩放。
---@param pParentActor XEActor 当前XEActor将要附加到的XEActor，也就是pActor将变为当前XEActor的父节点。
---@param szBindNodeName string 用于绑定子Actor的父Actor上的节点名称，可以是骨骼名称，也可以是槽名称。
---@return void
---@attention 此函数采用XEAttachRules::SnapToTargetNotIncludingScale 嵌套规则，表示子 Actor 附加到父 Actor 的指定节点时，
function XEActor:AttachToActorNode(pParentActor, szBindNodeName) end


---@public 根据指定的嵌套规则，将当前XEActor附加到指定pParentActor的指定节点上，即父子Actor嵌套。
---如果父 Actor 不存在szBindNodeName对应的节点，则父子嵌套失败。
---@param pParentActor XEActor 当前XEActor将要附加到的XEActor，也就是pActor将变为当前XEActor的父节点。
---@param szBindNodeName string 用于绑定子Actor的父Actor上的节点名称，可以是骨骼名称，也可以是槽名称。
---@param attachRules  XEAttachRules 指定子Actor嵌套到父Actor指定节点的规则
---@return void
function XEActor:AttachToActorNode(pParentActor, szBindNodeName, attachRules) end


---@public 采用KeepWorld规则解除当前Actor与其父Actor的父子关系，也就是保持当前Actor的世界状态不改变
---并自动转移到所属的XELevel！
---@return void
function XEActor:DetachFromActor() end


---@public 根据指定的解除规则，解除当前Actor与其父Actor的父子关系
---并自动转移到所属的XELevel！
---@param detachRules  XEDetachmentTransformRules 表示当前Actor与其父Actor解除父子关系时，当前Actor的世界状态如何改变的规则
---@return void
---@attention 目前XECoreSDK 支持两种解除父子关系的规则，分别是KeepRelative 和 KeepWorld，具体可参见 XEDetachmentTransformRules.
function XEActor:DetachFromActor(detachRules) end


---@public 获取当前 XEActor 的 AABB 包围盒，并返回
---@return XCusAABB
function XEActor:GetCusAABB() end


---@public 对当前 XEActor 执行拾取运算，并返回拾取结果
---@param hr XEHitResult [in][out]拾取结果结构体，包含输入的射线起始位置和方向；输出的拾取到的XEActor、拾取到的3D场景的坐标点等，具体参考XEHitResult的介绍.
---@return boolean 是否拾取成功
function XEActor:RayPick(hr) end


---@public 对当前 XEActor 执行拾取运算，并返回拾取结果
---@param hr XEHitResult [in][out]拾取结果结构体，包含输入的射线起始位置和方向；输出的拾取到的XEActor、拾取到的3D场景的坐标点等，具体参考XEHitResult的介绍.
---@param vScreenPoint XVECTOR2 拾取时的像素坐标，例如在编辑器的窗口中进行拾取时，鼠标的坐标.
---@param viewport XViewport 当前拾取坐标所在窗口绑定的视口对象.
---@return boolean 是否拾取成功
function XEActor:RayPick(hr, vScreenPoint, viewport) end


---@public 对当前 XEActor 执行拾取运算，并返回拾取结果
---@param vScreenPoint XVECTOR2 拾取时的像素坐标，例如在编辑器的窗口中进行拾取时，鼠标的坐.
---@param pViewport XViewport 当前拾取坐标所在窗口绑定的视口对象.
---@return XEHitResult 拾取结果结构体，具体参考XEHitResult的介绍.
function XEActor:RayPick(vScreenPoint, pViewport) end


---@public 聚焦当前Actor
---@param bFocus boolean
---@return void
function XEActor:FocusActor(bFocus) end


---@public 当当前XEActor被绑定到其他槽上时，用于根据槽的变换更新当前XEActor的状态。
---@param pBindSocketIns XEBindSocketInstance
---@param matWorld XMATRIX4 用于更新当前XEActor状态的世界矩阵
---@return void
function XEActor:OnSocketTick(pBindSocketIns, matWorld) end


---@public 当当前XEActor被绑定到其他槽上时，用于渲染绑定物体
---@param pBindSocketIns XEBindSocketInstance 来源插槽
---@return void
function XEActor:OnSocketRender(pBindSocketIns) end


---@public 设置当前XEActor在世界坐标系中的位置
---@param fX number 在世界中指定位置的x分量
---@param fY number 在世界中指定位置的y分量
---@param fZ number 在世界中指定位置的z分量
---@return void
function XEActor:SetActorLocation(fX, fY, fZ) end


---@public 设置当前XEActor在世界坐标系中的位置
---@param loc XVECTOR3 在世界中指定的位置
---@return void
function XEActor:SetActorLocation(loc) end


---@public 设置当前XEActor在世界坐标系中的朝向
---@param fPitch number 在世界坐标系下，绕x轴旋转角(弧度制)
---@param fYaw number 在世界坐标系下，绕y轴旋转角(弧度制)
---@param fRoll number 在世界坐标系下，绕z轴旋转角(弧度制)
---@return void
function XEActor:SetActorRotation(fPitch, fYaw, fRoll) end


---@public 设置当前XEActor在世界坐标系中的朝向
---@param rot XQUATERNION 代表当前XEActor在世界中朝向的四元数
---@return void
function XEActor:SetActorRotation(rot) end


---@public 设置删除状态
---@param bDelete boolean 是否删除
---@return void
function XEActor:SetDeleted(bDelete) end


---@public 设置隐藏状态
---@param bHide boolean 是否隐藏
---@return void
function XEActor:SetHidden(bHide) end


---@public 设置当前Actor是否在世界运行态时隐藏
---@param bHide boolean
---@return void
function XEActor:SetHiddenInGame(bHide) end


---@public 设置当前XEActor的名称, 子类可对此方法进行重载。注意， 改变Actor的名字的行为有风险！您需要在子类中解决名字改变带来的风险
---@param szActorName string 代表要为XEActor设置名称的字符串
---@param pContext XEWorld 当前XEActor所属的世界指针，以允许该Actor在未指定所属世界时，外部传入一个世界上下文。
---@return boolean 表示设置是否成功
function XEActor:SetActorName(szActorName, pContext) end


---@public 获取当前XEActor的根组件
---@return XEActorComponent
function XEActor:GetRootComponent() end


---@public 获取当前Actor属于哪个Actor的子ActorComponent
---@return XEChildActorComponent
function XEActor:GetBelongToChildActorComponent() end


---@public 根据索引获取该Actor的（子）组件
---@param nIndex number 索引
---@return XEActorComponent 获取到的组件指针
function XEActor:GetComponentOfIndex(nIndex) end


---@public 获取当前Actor的父Actor
---@return XEActor
function XEActor:GetParentActor() end


---@public 获取当前XEActor包含的直接子Actor，不包括其子Actor包含的子孙Actor
---@return XEActor[]
---@return void
function XEActor:GetChildActors() end


---@public 获取当前XEActor包含的所有子孙Actor，包括其子Actor包含的子孙Actor
---@return XEActor[]
---@return void
function XEActor:GetAllChildActors() end


---@public 获取当前Actor在世界坐标系中的位置
---@return XVECTOR3
function XEActor:GetActorLocation() end


---@public 获取当前Actor在世界坐标系中的朝向
---@return XQUATERNION
function XEActor:GetActorRotation() end


---@public 获取当前Actor在世界坐标系中的缩放值
---@return XVECTOR3
function XEActor:GetActorScale() end


---@public 设置当前Actor在世界坐标系中的缩放值
---@param sca XVECTOR3
---@return void
function XEActor:SetActorScale(sca) end


---@public 获取当前Actor相对于父Actor坐标系的局部坐标位置
---@return XVECTOR3
function XEActor:GetActorLocalLocation() end


---@public 获取当前Actor相对于父Actor坐标系的局部坐标位置
---@param location XVECTOR3
---@return void
function XEActor:SetActorLocalLocation(location) end


---@public 获取当前Actor相对于父Actor坐标系的局部坐标旋转
---@return XQUATERNION
function XEActor:GetActorLocalRotation() end


---@public 设置当前Actor相对于父Actor坐标系的局部坐标旋转
---@param quat XQUATERNION
---@return void
function XEActor:SetActorLocalRotation(quat) end


---@public 获取当前Actor相对于父Actor坐标系的局部坐标缩放
---@return XVECTOR3
function XEActor:GetActorLocalScale() end


---@public 设置当前Actor相对于父Actor坐标系的局部坐标缩放
---@param scale XVECTOR3
---@return void
function XEActor:SetActorLocalScale(scale) end


---@public 获取当前XEActor的原始世界矩阵，实际是从引擎获取当前实例的世界矩阵
---@return XMATRIX4
function XEActor:GetRawWorldTransform() end


---@public 获取当前XEActor的世界矩阵
---@return XMATRIX4
function XEActor:GetWorldTransform() end


---@public 获取当前XEActor的相对矩阵
---@return XMATRIX4
function XEActor:GetLocalTransform() end


---@public 修改子Actor的筛选路径
---@param strParentOriginName string 原始路径名
---@param strParentNewName string 新路径名
---@return boolean
function XEActor:ChangeSubActorFilterPath(strParentOriginName, strParentNewName) end


---@public 获取一个有效的组件索引值
---@return number
function XEActor:GetComponentValidIndex() end


---@public 设置当前代表头饰的XEActor的世界矩阵，目前此方法仅用于头饰模型，如果想为非头饰的模型设置世界矩阵，可通过调用ApplyWorldTransform函数。
---@param toMatrix XMATRIX4 设置当前代表头饰的XEActor的世界矩阵
---@return boolean 是否设置成功
function XEActor:MergeToWorldTransform(toMatrix) end


---@public 设置当前非头饰的XEActor的世界矩阵
---@param matrix XMATRIX4 设置当前非头饰的XEActor的世界矩阵
---@param bSyncGuestFromParent boolean 是否同步更新与其关联的子Actor组件的世界矩阵（当本Actor作为子Actor组件嵌套到了其他Actor上，本Actor会记录这个子Actor组件）
---@return boolean 是否设置成功
function XEActor:ApplyWorldTransform(matrix, bSyncGuestFromParent) end


---@public 设置当前非头饰的XEActor的相对矩阵
---@param matrix XMATRIX4 设置当前非头饰的XEActor的相对矩阵
---@param bSyncGuestFromParent boolean 是否同步更新与其关联的子Actor组件的世界矩阵（当本Actor作为子Actor组件嵌套到了其他Actor上，本Actor会记录这个子Actor组件）
---@return boolean 是否设置成功
function XEActor:ApplyLocalTransform(matrix, bSyncGuestFromParent) end


---@public 当前Actor离开自己的世界，到其他世界去
---@param pGuestWorld XEWorld 当前Actor去往的其他世界指针
---@return boolean 是否成功
function XEActor:TravelToGuestWorld(pGuestWorld) end


---@public 当前Actor回到自己的世界
---@return boolean 是否成功
function XEActor:ReturnBackToOwnerWorld() end


---@public 当前Actor是否在其他世界，返回true，表示目前在其他世界；返回false，表示目前在自己所在的世界
---@return boolean
function XEActor:IsInGuestWorld() end


---@public 获取当前Actor的短名字（只有名字，没有前缀）
---@return string
function XEActor:GetActorShortName() end


---@public 获取attach时过滤父Actor的类型
---@return string[]
function XEActor:GetParentActorTypeFilterList() end


---@public 添加过滤父Actor的类型, 如果在此列表中，则该类型Actor不允许挂载其他Actor
---@param strActorType string
---@return void
function XEActor:AddParentActorTypeFilter(strActorType) end


---@public 获取显隐的合并状态值，每两位组成一对， 高位表示该状态是否有效， 低位表示是否显示， 当所有有效位对应的显示状态为1时，隐藏，否则显示
---@param nBit number 要获取的位
---@return boolean 该位的显隐状态
function XEActor:GetMergeRenderHidden(nBit) end


---@public 设置显隐的合并状态值
---@param nMergeBit number
---@param bHidden boolean
---@return number 当前合并状态值
function XEActor:SetMergeRenderHidden(nMergeBit, bHidden) end


---@public 设置显隐的合并状态值的指定有效位是否有效
---@param nMergeBit number 要设置的位
---@param bEnable boolean 要设置的显隐状态
---@return number 当前合并状态值
function XEActor:SetMergeRenderHiddenEnable(nMergeBit, bEnable) end


---@public 重置显隐的合并状态值
---@return void
function XEActor:ResetMergeRenderHidden() end


---@public 更新当前Actor内记录的与其关联的子Actor组件的矩阵
---@return void
function XEActor:UpdateLocalTransformForChildComponent() end


---@public 【适用于人脸追踪的3D头饰】 设置变换是否是合并模式
---@param bMerge boolean 是否合并，为xtrue时，将会被标记为变换合并模式，该模式会影响该Actor的变换行为，例如将会将自身坐标系变换到外部传递的坐标系内。
---@param bRecursion boolean 是否递归影响其子节点
---@return void
function XEActor:SetTransformMergeMode(bMerge, bRecursion) end


---@public 为当前XEActor添加指定类型的组件
---@param szType string 组件类型名称
---@return XEActorComponent 返回添加的组件指针
function XEActor:AddActorComponent(szType) end


---@public XEActor_GetActorComponent00
---@param szType string
---@return XEActorComponent
function XEActor:GetActorComponent(szType) end


---@public XEActor_GetActorComponent01
---@param szType string
---@param runType number
---@return XEActorComponent
function XEActor:GetActorComponent(szType, runType) end


---@public XEActor_GetRootComponent01
---@return  XEActorComponent
function XEActor:GetRootComponent() end


---@public 获取当前Actor在世界坐标系下的朝向(Z)单位向量
---@return XVECTOR3
function XEActor:GetActorForwardVector() end


---@public 获取当前Actor在世界坐标系下的UP(Y)单位向量
---@return XVECTOR3
function XEActor:GetActorUpVector() end


---@public 获取当前Actor在世界坐标系下的向右(X)单位向量
---@return XVECTOR3
function XEActor:GetActorRightVector() end


---@public 在世界坐标系下，设置当前XEActor的朝向向量和UP向量。通过设置朝向向量和UP向量设置当前XEActor的旋转朝向
---@param vForwardDir XVECTOR3
---@param vUp XVECTOR3
---@return void
function XEActor:SetForwardDirAndUp(vForwardDir, vUp) end


---@public 在世界坐标系下，设置当前XEActor的位置、朝向向量和UP向量，其中设置朝向向量和UP向量是为了计算当前XEActor的旋转状态
---@param vPosition XVECTOR3
---@param vForwardDir XVECTOR3
---@param vUp XVECTOR3
---@return void
function XEActor:SetPositionAndForwardDirUp(vPosition, vForwardDir, vUp) end


---@public 将当前XEActor绕X轴旋转fDeltaRadian弧度。
---@param fDeltaRadian number
---@return void
function XEActor:RotateX(fDeltaRadian) end


---@public 将当前XEActor绕Y轴旋转fDeltaRadian弧度。
---@param fDeltaRadian number
---@return void
function XEActor:RotateY(fDeltaRadian) end


---@public 将当前XEActor绕Z轴旋转fDeltaRadian弧度。
---@param fDeltaRadian number
---@return void
function XEActor:RotateZ(fDeltaRadian) end


---@public 将当前XEActor绕vRotateAxis轴旋转fDeltaRadian弧度
---@param vRotateAxis XVECTOR3
---@param fDeltaRadian number
---@return void
function XEActor:RotateAxis(vRotateAxis, fDeltaRadian) end


---@public 获取当前Actor是否隐藏
---@return boolean
function XEActor:IsHidden() end


---@public 获取当前Actor是否在世界运行态时隐藏的状态
---@return boolean
function XEActor:IsHiddenInGame() end


---@public 设置当前Actor的包围盒颜色
---@param clVal number
---@return void
function XEActor:SetBoundingBoxColor(clVal) end


---@public 获取当前Actor的包围盒颜色
---@return number
function XEActor:GetBoundingBoxColor() end


---@public 获取当前Actor名字
---@return string
function XEActor:GetActorName() end


---@public 获取当前Actor的唯一Id字符串
---@return string
function XEActor:GetActorIdString() end


---@public 获取当前Actor作为复制体时的来源ActorId字符串[运行时]
---@return string
function XEActor:GetActorOriginalIdString() end


---@public 设置当前Actor是否允许Tick
---@param bEnable boolean
---@return void
function XEActor:SetActorTickEnabled(bEnable) end


---@public 获取当前Actor是否允许Tick
---@return boolean
function XEActor:IsActorTickable() end


---@public 设置当前XEActor的序号，用于排序使用
---@param nOrder number
---@return void
function XEActor:SetOrder(nOrder) end


---@public 获取当前XEActor的序号
---@return number
function XEActor:GetOrder() end


---@public 判断当前XEActor的是否被标记为已删除
---@return boolean
function XEActor:IsDeleted() end


---@public 判断当前XEActor(包括它的组件)是否被标记为已修改
---@return boolean
function XEActor:IsModified() end


---@public 设置当前Actor是否被修改了
---@param bModified boolean
---@return void
function XEActor:SetModified(bModified) end


---@public 获取当前XEActor的拾取掩码
---@return number
function XEActor:GetPickMask() end


---@public 获取当前XEActor的拾取优先级
---@return number
function XEActor:GetPickPriority() end


---@public 判断当前XEActor的是否允许拾取
---@return boolean
function XEActor:IsPickEnable() end


---@public 设置当前XEActor的拾取掩码
---@param nMask number
---@return void
function XEActor:SetPickMask(nMask) end


---@public 设置当前XEActor的拾取优先级
---@param nPriority number
---@return void
function XEActor:SetPickPriority(nPriority) end


---@public 设置当前XEActor的筛选路径，默认把路径小写
---@param szFilterPath string
---@return void
function XEActor:SetFilterPath(szFilterPath) end


---@public 设置当前XEActor的筛选路径
---@param szFilterPath string
---@param bIsToLower boolean 是否把路径字符串小写
---@return void
function XEActor:SetFilterPath(szFilterPath, bIsToLower) end


---@public 获取筛选路径字符串
---@return string
function XEActor:GetFilterPath() end


---@public 判断Transform是否处于合并模式
---@return boolean
function XEActor:IsTransformMergeMode() end


---@public 设置当前Actor渲染的辅助类型
---@param nDebug number
---@return void
function XEActor:SetDrawDebugType(nDebug) end


---@public 获取当前Actor渲染的辅助类型
---@return number
function XEActor:GetDrawDebugType() end


---@public 判断渲染辅助类型EDD_DRAW_AUXILIARY是否被标记
---@return boolean
function XEActor:IsDrawAuxiliary() end


---@public 包围盒是否可见
---@return boolean
function XEActor:IsBoundingBoxVisible() end


---@public Actor的示意图例/渲染示意形状是否可见
---@return boolean
function XEActor:IsDummyShapeVisible() end


---@public 获取当前Actor的碰撞通道
---@return XECollisionChannelMeta
function XEActor:GetCollisionChannel() end


---@public 设置当前Actor的碰撞通道
---@param ccm  XECollisionChannelMeta
---@return void
function XEActor:SetCollisionChannel(ccm) end


---@public 根据嵌套时选择的父Actor的骨骼或槽点，得到对应的矩阵信息
---@param pParentActor XEActor 当前Actor的父Actor
---@return XMATRIX4
---@return boolean
function XEActor:ReCalculateParentMatrixByUserNode(pParentActor) end


---@public 更新父子嵌套的挂载节点信息
---@param bBindUserNodeData XEBindUserNodeData
---@return void
function XEActor:UpdateBindDataFromParentUserNode(bBindUserNodeData) end


---@public 获取父子嵌套时挂载节点信息
---@return XEBindUserNodeData
function XEActor:GetBindUserNodeData() end


---@public 设置是否根据挂载节点更新当前Actor的Transform
---@param bIsUpdate boolean
---@return void
function XEActor:SetUpdateTranfromFromUserNode(bIsUpdate) end


---@public 是否根据挂载节点更新当前Actor的Transform
---@return boolean
function XEActor:GetIsUpdateTranformFromUserNode() end


---@public 判断某个Actor是否是当前Actor的子Actor
---@param pChildActor  XEActor
---@return boolean
function XEActor:IsChildActor(pChildActor) end


---@public 获取当前Actor所属的世界对象指针
---@return XEWorld
function XEActor:GetOwner() end


---@public 获取当前Actor所在的关卡对象指针
---@return XELevel
function XEActor:GetLevelOwner() end


---@public 完整克隆并在Level中产出新的拷贝Actor对象，自动分配唯一名称，克隆的Actor对象将会储存在所属Level中
---@return XEActor
function XEActor:SpawnCloneActor() end


---@public 获取Actor的序列化字符串(xml格式)
---@return string
function XEActor:GeSerializeContent() end


---@public 从序列化字符串中还原Actor的参数信息（Warning! 如果Actor已经被反序列化，则存在数据丢失或者冲突风险）
---@param strContent string
---@return boolean
function XEActor:DeserializeFromContent(strContent) end


---@public 将当前组件的Prefab实例指向pPrefabIns
---@param pPrefabIns XEPrefabInstance
---@return void
function XEActor:SetPrefabInstance(pPrefabIns) end


---@public XEActor_GetPrefabInstance00
---@return XEPrefabInstance
function XEActor:GetPrefabInstance() end


---@public Actor是否为Prefab实例的根Actor
---@return boolean
function XEActor:IsPrefabInstanceRoot() end


---@public 获取拥有者Container
---@return XEActorContainer
function XEActor:GetOwnerContainer() end


---@public 设置拥有者Container
---@param pContainer XEActorContainer
---@return void
function XEActor:SetOwnerContainer(pContainer) end


---@public 获取Actor的渲染分组
---@return number
function XEActor:GetRenderGroup() end


---@public 设置Actor的渲染分组
---@param eARG number
---@return void
function XEActor:SetRenderGroup(eARG) end


---@type boolean 是否隐藏
XEActor.m_bHidden = false


---@type boolean 是否在运行态时隐藏
XEActor.m_bHiddenInGame = false


---@type number 显隐的合并状态值
XEActor.m_nMergeHidden = 0


---@type string @readonly Actor类型名，这里会被设置为"EmptyAcotr"
XEActor.ACTOR_TYPENAME = ''


---@type string @readonly 所在的碰撞通道
XEActor.RC_CHANNEL = ''


---@type string @readonly 简化的Actor名称
XEActor.ACTOR_SHORT_NAME = ''


