---此类代表相机组件，用于封装引擎的XBaseCamera 对象。
---目前支持两种类型的投影方式的相机，分别是透视投影(XPerspectiveCamera)和正交投影(XOrthoCamera)，两者均是 XBaseCamera 的子类。
---@class XECameraComponent : XEPrimitiveComponent
XECameraComponent = {}


---@type number @enum XEProjectionModel 透视投影模式
XECameraComponent.XEPM_PERSPECTIVE = 0


---@type number @enum XEProjectionModel 正交投影模式
XECameraComponent.XEPM_ORTHO = 0


---@public XECameraComponent_new00
---@return XECameraComponent
function XECameraComponent:new() end


---@public 创建透视投影的相机(XPerspectiveCamera，引擎中封装的对象),并设置相机的视角(FOV)、远近裁剪平面(NEAR/FAR)和视口宽高比（Ratio）。
---透视投影的视椎体是个平截头体，位于视椎体内的物体才能被“看到”。
---@return XPerspectiveCamera 创建成功的透视投影的相机指针.
function XECameraComponent:SetAsPerspectiveCamera() end


---@public XECameraComponent_SetAsPerspectiveCamera01
---@param fFov number
---@param fZNear number
---@param fZFar number
---@param fRatio number
---@return XPerspectiveCamera
function XECameraComponent:SetAsPerspectiveCamera(fFov, fZNear, fZFar, fRatio) end


---@public 创建正交投影的相机(XOrthoCamera，引擎中封装的对象),并分别设置视景体左平面、右平面、上平面、下平面、近平面、远平面到相机的距离。
---正交投影的视椎体是一个长方体或立方体，拥有六个平面。
---@param fLeft number 正交投影时，视椎体左平面到相机的距离。
---@param fRight number 正交投影时，视椎体右平面到相机的距离。
---@param fBottom number 正交投影时，视椎体下平面到相机的距离。
---@param fTop number 正交投影时，视椎体上平面到相机的距离。
---@param fZNear number 正交投影时，视椎体近平面到相机的距离。
---@param fZFar number 正交投影时，视椎体远平面到相机的距离。
---@return XOrthoCamera 创建成功的正交投影的相机指针.
function XECameraComponent:SetASOrthoCamera(fLeft, fRight, fBottom, fTop, fZNear, fZFar) end


---@public 判断当前组件内记录的相机是否是场景中起作用的相机
---@return boolean
function XECameraComponent:IsSystemCamera() end


---@public 将当前组件内记录的相机指针与视口绑定，这是将当前组件内记录的相机在场景中起作用的前提
---@return boolean 判断当前组件内记录的相机是否与视口绑定成功
function XECameraComponent:ApplyAsSystemCamera() end


---@public 将当前组件内记录的相机的投影方式改为 eModel 类型
---@param eModel number 相机的投影方式（正交投影/透视投影）
---@return boolean
function XECameraComponent:SwitchProjectModel(eModel) end


---@public 获取某个世界的场景相机
---@param pWorldContext XEWorld
---@return XBaseCamera
function XECameraComponent:GetSystemCamera(pWorldContext) end


---@public 获取当前组件内记录的相机指针
---@return XBaseCamera
function XECameraComponent:GetCamera() end


---@public 判断当前组件内记录的相机是否是透视投影
---@return boolean
function XECameraComponent:IsPerspectiveCamera() end


---@public 判断当前组件内记录的相机是否是正交投影
---@return boolean
function XECameraComponent:IsOrthoCamera() end


---@public 判断当前组件内记录的相机是否处于激活状态，即是否在场景中起作用
---@return boolean
function XECameraComponent:IsActiveCamera() end


---@public 设置当前组件内记录的相机的激活状态，即是否在场景中起作用
---@param bActive boolean
---@return void
function XECameraComponent:SetActiveCamera(bActive) end


---@public 设置当前组件内记录的相机的近裁剪面
---@param fZNear number
---@param bUpdateProjMat boolean
---@return boolean
function XECameraComponent:SetZNear(fZNear, bUpdateProjMat) end


---@public 设置当前组件内记录的相机的远裁剪面
---@param fZFar number
---@param bUpdateProjMat boolean
---@return boolean
function XECameraComponent:SetZFar(fZFar, bUpdateProjMat) end


---@public 设置当前组件内记录的相机的视角
---@param fFov number
---@return boolean
function XECameraComponent:SetFov(fFov) end


---@public 获取当前组件内记录的相机的远裁剪面
---@return number
function XECameraComponent:GetZFar() end


---@public 获取当前组件内记录的相机的近裁剪面
---@return number
function XECameraComponent:GetZNear() end


---@public 获取当前组件内记录的相机的视角
---@return number
function XECameraComponent:GetFov() end


---@public 设置正交投影的视椎体的近裁剪面的宽
---@param fOrthoWidth number
---@return boolean
function XECameraComponent:SetOrthoWidth(fOrthoWidth) end


---@public 获取正交投影的视椎体的近裁剪面的宽
---@return number
function XECameraComponent:GetOrthoWidth() end


---@type string @readonly Component类型名
XECameraComponent.COMPONENT_TYPENAME = ''


