---模型实例引擎渲染图元的子视图图元代理
---@class XEModelInsSubviewPrimitive : XESubviewPrimitiveAgent
XEModelInsSubviewPrimitive = {}


---此类代表骨骼模型的组件
---用于封装引擎的IXModelInstance对象、XESkeletonInstance、XEAnimMontageInstance、XEAnimSocketMounterInstance等。
---此类封装了加载mdl文件的函数，移动、旋转和缩放组件的函数，加载柔体cth文件，加载刚体phy文件，播放蒙太奇动画等。
---@class XEModelComponent : XEPrimitiveComponent
XEModelComponent = {}


---@manual xelua_XEngine_XEModelComponent_LoadAssetAsync_manual
---@public XEModelComponent_LoadAssetAsync_manual
---@param pPath string
---@param Delegate std::function<void( _cstring , XEActorComponent*, ResultType)>
---@return void
function XEModelComponent:LoadAssetAsync(pPath, Delegate) end


---@public 根据蒙皮索引和 cth 路径创建布料资源并绑定到模型上，内部是根据材质名进行匹配
---@param szClothPath string 布料资源(cth)的路径，此路径是相对工程文件夹下.xscene文件的路径
---@param pWorld XEWorld 当前组件所处的世界对象
---@param nSkinIndex number 模型对象的蒙皮索引
---@return boolean 布料是否创建成功
function XEModelComponent:CreateClothAttachModel(szClothPath, pWorld, nSkinIndex) end


---@public 同CreateClothAttachModel
---@param szClothPath string
---@param pWorld XEWorld
---@param nSkinIndex number
---@return IXCloth 返回创建的布料指针
function XEModelComponent:CreateClothAttachModelByPath(szClothPath, pWorld, nSkinIndex) end


---@public 从模型指定的 mesh 上移除布料并释放
---@param szMeshName string 模型上mesh名称
---@return void
function XEModelComponent:RemoveAndReleaseClothAssetFromMesh(szMeshName) end


---@public 获取模型指定的 mesh 上绑定布料资源对应的指针
---@param szMeshName string 模型上mesh名称
---@return IXCloth
function XEModelComponent:GetClothPrimitive(szMeshName) end


---@public 将模型实例所绑定的所有布料资源添加到物理 scene，只有将布料资源添加到物理 scene 才能被物理世界更新和渲染
---@param pWorld XEWorld 当前组件所处的世界指针
---@return void
function XEModelComponent:AddAllClothToSceneWithModel(pWorld) end


---@public 移除指定布料
---@param pCloth IXCloth 要移除的布料指针
---@return void
function XEModelComponent:RemoveCloth(pCloth) end


---@public 获取模型实例所绑定的所有布料资源
---@return IXCloth[]
---@return void
function XEModelComponent:GetClothPrimitive() end


---@public 获取动画控制器
---@return XEAnimController 动画控制器
---@attention could be montage animation controller or model-animation controller.
function XEModelComponent:GetAnimController() end


---@public 获取当前播放的动画资源路径
---@return string 当前播放的动画资源路径
function XEModelComponent:GetCurPlayAnimation() end


---@public 获取模型指针
---@param pAssetPath string 模型路径（全路径），取到后引用+1
---@return XModel 模型指针
function XEModelComponent:GetXModelFromAsset(pAssetPath) end


---@public 创建骨骼实例
---@return boolean 是否创建成功
function XEModelComponent:BuildSkeletonInstance() end


---@public 销毁骨骼实例
---@return boolean 如果销毁返回xtrue,如果原本骨骼实例为空，返回xfalse
function XEModelComponent:DestroySkeletonInstance() end


---@public 设置骨骼实例
---@param pSkeleIns XESkeletonInstance 骨骼实例指针
---@return void
function XEModelComponent:SetSkeletonInstance(pSkeleIns) end


---@public 如果动画播放列表不存在，创建一个
---@return XEAnimComponentPlayList 动画播放列表指针
function XEModelComponent:AssignAnimPlayList() end


---@public 获取动画播放列表
---@return XEAnimComponentPlayList 动画播放列表指针
function XEModelComponent:GetAnimPlayList() end


---@public 由UV获取顶点位置信息
---@param szMeshName string [in]mesh名称
---@param szSkinName string [in]蒙皮名称
---@param uv XVECTOR2 [in]uv信息
---@return XVECTOR3
---@return boolean 是否获取成功
function XEModelComponent:GetVertexPositionFromUV(szMeshName, szSkinName, uv) end


---@public 由SourceModel，创建新的模型模板
---@return boolean
function XEModelComponent:EmbedCurrentModel() end


---@public 由szSkin，创建新的蒙皮
---@param szSkin string 源skin名字
---@param pEmbedSkinName string 新蒙皮名字
---@return boolean
function XEModelComponent:EmbedCutModelSkin(szSkin, pEmbedSkinName) end


---@public 为skin中指定的rawmesh,创建新的材质实例
---@param szSkin string 指定的skin
---@param szRawMeshName string 指定的RawMesh名称
---@param nLod number 指定的Lod
---@param pEmbedMatInsName string [out]创建的材质实例名称
---@return boolean
function XEModelComponent:EmbedMeshMaterialIns(szSkin, szRawMeshName, nLod, pEmbedMatInsName) end


---@public 由源skin name获取新的 skin name
---@param szSourceSkin string 旧skin名称
---@return string
function XEModelComponent:GetEmbedSkinName(szSourceSkin) end


---@public 由源skin和源材质实例name，获取新的材质实例name
---@param szSourceSkin string 旧skin名称
---@param szSourceMaterialInsName string 旧材质实例名字
---@return string 新的材质实例名字
function XEModelComponent:GetEmbedMaterialInsName(szSourceSkin, szSourceMaterialInsName) end


---@public 清除名为szskin的嵌入skin
---@param szSkin string
---@param bSource boolean
---@return boolean
function XEModelComponent:ClearEmbedRecoredSkin(szSkin, bSource) end


---@public 清除全部嵌入材质信息
---@param bClearModel boolean 是否清除嵌入模型模板
---@return boolean
function XEModelComponent:ClearEmbedRecord(bClearModel) end


---@public 获取当前组件中记录的模型实例
---@return IXModelInstance 模型实例指针
function XEModelComponent:GetModelInstance() end


---@public 获取当前组件中记录的换装实例
---@return IXEDressup 换装实例指针
function XEModelComponent:GetDressUp() end


---@public 获取当前组件中记录的模型实例的资源路径(mdl)的路径
---@return string 模型实例的资源路径(mdl)的路径
function XEModelComponent:GetAssetPath() end


---@public 获取当前组件中记录的骨骼实例
---@return XESkeletonInstance 骨骼实例指针
function XEModelComponent:GetXESkeletonInstance() end


---@public 获取当前组件中记录的蒙太奇实例
---@return XEAnimMontageInstance 蒙太奇实例指针
function XEModelComponent:GetMontageInstance() end


---@public 获取当前组件中记录的融合动画实例（blend）
---@return XEAnimBlendInstance 融合动画实例指针
function XEModelComponent:GetBlendInstance() end


---@public 获取当前组件中记录的挂点实例
---@return XEAnimSocketMounterInstance 挂点实例指针
function XEModelComponent:GetMounterInstance() end


---@public 替换模型的dressup, 并不会对骨架、动画控制器等产生影响
---@param pAssetPath string dressup资源路径
---@return boolean 是否替换成功，该dressup的模型骨架必须与当前一致，否则替换不成功
function XEModelComponent:ReplaceDressup(pAssetPath) end


---@manual 合并材质实例相同的mesh，以减少绘制批次
---@public XEModelComponent_CombineMeshesWithSameMaterialIns_manual
---@param pMeshArray  XArray<MeshToBeCombined>
---@return boolean 是否合并成功
function XEModelComponent:CombineMeshesWithSameMaterialIns(pMeshArray) end


---@public XEModelComponent_CancelCombineMeshes00
---@return void
function XEModelComponent:CancelCombineMeshes() end


---@public 加载挂点资源并创建对应的挂点实例
---@param pAssetPath string 挂点资源路径
---@param bReloadAsset boolean 是否重新加载
---@return boolean 是否挂载成功
function XEModelComponent:AttachMounterAsset(pAssetPath, bReloadAsset) end


---@public 将当前组件的蒙太奇动画实例指向pMontageIns,引用+1
---@param pMontageIns XEAnimMontageInstance 外部已经创建好的蒙太奇动画实例
---@return void
function XEModelComponent:AttachMontageInstance(pMontageIns) end


---@public 当前组件绑定的蒙太奇动画实例引用-1
---@return void
---@attention 当引用为0时，解除当前组件绑定的蒙太奇动画实例，即释放或置空蒙太奇动画指针对象
function XEModelComponent:DetachMontageInstance() end


---@public 将当前组件的挂点实例指向pMounterIns,引用+1
---@param pMounterIns XEAnimSocketMounterInstance 外部已经创建好的挂点实例
---@return void
function XEModelComponent:AttachMounterInstance(pMounterIns) end


---@public 当前组件绑定的挂点实例引用-1
---@return void
---@attention 当引用为0时，解除当前组件绑定的挂点实例，即释放或置空挂点实例指针对象
function XEModelComponent:DetachMounterInstance() end


---@public 将当前组件的融合动画实例指向pBlendIns,引用+1
---@param pBlendIns XEAnimBlendInstance 外部已经创建好的融合动画实例
---@return void
function XEModelComponent:AttachBlendInstance(pBlendIns) end


---@public 当前组件绑定的融合动画实例引用-1
---@return void
---@attention 当引用为0时，解除当前组件绑定的融合动画实例，即释放或置空挂点实例指针对象
function XEModelComponent:DetachBlendInstance() end


---@public 加载软骨文件
---@param szAssetPath string 软骨文件路径
---@return number errorcode错误码
function XEModelComponent:LoadSoftSkeleton(szAssetPath) end


---@public 创建软骨
---@return boolean 是否创建成功
function XEModelComponent:BuildSoftSkeleton() end


---@public 销毁软骨
---@return void
function XEModelComponent:DestroySoftSkeleton() end


---@public 销毁软骨
---@return XESoftSkeleton 软骨
function XEModelComponent:GetSoftSkeleton() end


---@public 创建Subview代理，如果已经存在，则返回该代理
---@return XESubviewAgent
function XEModelComponent:CreateSubviewAgent() end


---@public 作为持有体绑定到子视图, 当前组件世界必须存在
---@param pSubviewName string 渲染的子视图名称
---@param bCreatSubviewIfNotExist boolean 如果子视图不存在,则指定是否自动创建一个
---@param bCreateCameraForSubview boolean 是否为subview创建一个内部相机对象,并使用该相机,以当前视口中相机参数进行创建，如果要修改相机参数，请获取该视口相机并进行修改
---@return boolean 是否成功
function XEModelComponent:BindSubview(pSubviewName, bCreatSubviewIfNotExist, bCreateCameraForSubview) end


---@public 从子视图中解除绑定
---@param bRemoveSubview boolean 是否在解除绑定后删除子视图
---@param pSubviewName string 指定子视图名称，如果为空，则解绑关联的所有子视图
---@return boolean 是否成功
function XEModelComponent:UnBindSubview(bRemoveSubview, pSubviewName) end


---@public 关联Montage相关到subview
---@param pSubviewName string
---@param pMontageInstance XEAnimMontageInstance
---@return void
function XEModelComponent:PutCurrentMontageToSubview(pSubviewName, pMontageInstance) end


---@public 关联Mounter相关到subview
---@param pSubviewName string
---@return void
function XEModelComponent:PutCurrentMounterToSubview(pSubviewName) end


---@public 给ModelIns设置材质
---@param strSkinName string
---@param nLodId number
---@param strMeshName string
---@param strMaterialFile string
---@return boolean
function XEModelComponent:SetModelInsMaterial(strSkinName, nLodId, strMeshName, strMaterialFile) end


---@public 获取某个材质实例指针
---@param nSkinID number
---@param nLodID number
---@param nMeshID number
---@return IXMaterialInstance
function XEModelComponent:GetMaterialIns(nSkinID, nLodID, nMeshID) end


---@public XEModelComponent_GetMaterialIns01
---@param strSkinName string
---@param nLodID number
---@param strMeshName string
---@return IXMaterialInstance
function XEModelComponent:GetMaterialIns(strSkinName, nLodID, strMeshName) end


---@type string @readonly Component类型名
XEModelComponent.COMPONENT_TYPENAME = ''


