---XEActorContainer
---Actor容器，内部维护一个Actor列表。
---@class XEActorContainer
XEActorContainer = {}


---@public XEActorContainer_new00
---@return XEActorContainer
function XEActorContainer:new() end


---@public 为这个关卡的非删除Actor表示物理世界
---@param fDelSecond number
---@return void
function XEActorContainer:PresentPhysicsForActors(fDelSecond) end


---@public 释放所有Actor
---@return void
function XEActorContainer:ReleaseAllActors() end


---@public 更新关卡Actor列表中未被标记为delete的Actor，更新物理世界、执行事件回调以及执行绑定脚本编辑器中的Tick响应函数等。
---@param fDelSecond number
---@return void
function XEActorContainer:TickImpl(fDelSecond) end


---@public 渲染
---@param pViewport XEViewport
---@return void
function XEActorContainer:RenderImpl(pViewport) end


---@public 为Actor排序，根据Actor的order
---@return void
function XEActorContainer:SortActorInOrder() end


---@public 创建指定类型的XEActor,并添加进当前所有关卡中
---@param szActorType string Actor类型名称
---@param szActorName string Actor名称
---@param szActorIdString string Actor唯一id
---@param bCreateAnyway boolean 指定当容器中已经存在名称为strActorName或者IdString已经存在的Actor时，返回NULL(=false)还是以新的可用名字/id创建。
---@param bResortGroupActors boolean 是否对分组Actor列表进行重新构建和排序
---@return XEActor
function XEActorContainer:CreateActor(szActorType, szActorName, szActorIdString, bCreateAnyway, bResortGroupActors) end


---@public 判断是否存在某个Actor,从当前容器包含的Actor中查找,不查找PrefabActor内部Actor
---当为true时，表示查找时如果找到了该Actor，不论它是否被标记为删除，都返回true;
---当为false时，表示即使查找到了该Actor，但是它被标记为删除，那么返回false。
---@param pActor  XEActor 判断的Actor指针
---@param bIgnoreDeleted boolean 是否忽略Actor被删除的标记，默认为true。
---@return boolean 是否找到
function XEActorContainer:HasActorNotChildPrefab(pActor, bIgnoreDeleted) end


---@public 查找某种类型的Actor,只在m_aActor中查找，不查找PrefabActor内部的Actor
---@param strActorType string 要查找的Actor类型
---@return XEActor[]
---@return void
function XEActorContainer:GetActorsOfTypeNoPrefab(strActorType) end


---@public 获取当前容器中所有的Actor，涉及到Actor列表的遍历和拷贝，尽量不要在Tick/Render中使用
---@return XEActor[]
function XEActorContainer:GetAllActors() end


---@public 获取当前实例管理的Actor列表
---@return XEActor[]
---@return void
function XEActorContainer:GetActors() end


---@public 获取当前容器中所有的actor哈希表，涉及到Actor哈希表的遍历和拷贝，尽量不要在Tick/Render中使用
---@return xhashtable_XString_and_XEActor_p_
function XEActorContainer:GetActorFastMap() end


---@public XEActorContainer_GetOwner00
---@return XEWorld
function XEActorContainer:GetOwner() end


---@public 在为关卡加载场景/反序列化Prefab之前，需要忽略序列化的某个Actor
---@param pActorName string
---@return void
function XEActorContainer:AddIgnoreLoadingActor(pActorName) end


---@public 将指定Actor添加进Actor列表 (m_aActor和m_mActorFastR)
---将Prefab资产在指定Actor容器中实例化
---@param pActorContainer XEActorContainer PrefabActor所属的容器
---@param szRelativePath string prefab资产相对路径
---@return XEPrefabInstance Prefab实例
function XEActorContainer:LoadPrefabAsset(pActorContainer, szRelativePath) end


