---全局的事件管理器，是一个单例类，包含事件列表组(例如普通事件EventArray、广播事件EventArray或其他特殊的EventArray)和广播接收者组
---@class XEEventManager
XEEventManager = {}


---@public 更新某个世界的事件列表
---@param fDel number 间隔（s）
---@param pWorld XEWorld 指定的世界指针
---@return void
function XEEventManager:Tick(fDel, pWorld) end


---@public 生成一个事件，并放到对应的事件列表中，如果该事件为自动执行事件，则等待事件管理器来进行基于事件队列的处理
---@param sender userdata 事件发送者
---@param executeable userdata 事件执行者
---@param pEventType string 事件类型
---@param pWorld XEWorld 事件所在的世界
---@return XEEventBase 生成的事件指针
function XEEventManager:SpawnEvent(sender, executeable, pEventType, pWorld) end


---@public 手动删除某个世界中的某个事件（一般用于custom event，普通事件一般不用手动删除）
---@param pEventToConsume XEEventBase 要删除的事件指针
---@param pWorld XEWorld 事件所在的世界
---@return boolean 是否删除成功
function XEEventManager:ConsumeEventNow(pEventToConsume, pWorld) end


---@public 手动执行并分发并消费一个事件
---@param pEventToConsume XEEventBase 要消费的事件指针
---@param pWorld XEWorld 事件所在的世界
---@return boolean 是否删除成功
function XEEventManager:ExecuteAndConsumeAndBroadCastEventNow(pEventToConsume, pWorld) end


---@public 往广播接收者组中添加一个广播接收者pReceiver
---@param pReceiver XEEventReceiver
---@return void
function XEEventManager:AddEventReceiver(pReceiver) end


---@public 从广播接收者组中删除某个广播接收者
---@param pReceiver XEEventReceiver 要删除的接收者指针
---@return boolean 是否删除成功
function XEEventManager:RemoveEventReceiver(pReceiver) end


---@public 根据通道名称获取接收者列表组
---@param pChannelName string 指定通道名称
---@return XEEventReceiver[]
---@return number 获取到的接收者列表数目
---@attention 需要手动释放接收者内存！
function XEEventManager:GetEventReceiversForChannel(pChannelName) end


---@public 根据通道名称和接受者名称查找接收者
---@param pChannelName string 指定通道名称
---@param pReceiverName string 指定的接收者名称
---@return XEEventReceiver 查找到的接收者指针
function XEEventManager:FindEventReceiver(pChannelName, pReceiverName) end


---@public 获取到一个有效的事件列表名称
---@param pPrefix string 指定前缀，默认是"EventList"
---@return string 获取到的有效名称
function XEEventManager:GetValidEventListName(pPrefix) end


---@public 获取到一个有效的广播接收者名称
---@param pPrefix string 指定前缀，默认是"EventReceiver"
---@return string 获取到的有效名称
function XEEventManager:GetValidEventReceiverName(pPrefix) end


---@public 释放指定的世界pWorld中的所有事件
---@param pWorld  XEWorld
---@return void
function XEEventManager:ReleaseEventsInWorld(pWorld) end


