---2d骨骼动画渲染组件
---@class XSkeleton2dRenderComponent : X2DRenderComponent
XSkeleton2dRenderComponent = {}


---@public 创建一个XSkeleton2dRenderComponent渲染组件
---@param pNode XUINode 目标节点
---@return XSkeleton2dRenderComponent 创建出的XSkeleton2dRenderComponent组件
function XSkeleton2dRenderComponent:Create(pNode) end


---@public XSkeleton2dRenderComponent_Create01
---@return XSkeleton2dRenderComponent
function XSkeleton2dRenderComponent:Create() end


---@public 重置
---@return boolean
function XSkeleton2dRenderComponent:Reset() end


---@public 加载2d骨骼资源
---@param asset string
---@return boolean
function XSkeleton2dRenderComponent:LoadAsset(asset) end


---@public 获取2d骨骼资源
---@return string
function XSkeleton2dRenderComponent:GetAsset() end


---@type number @enum SK_EventType
XSkeleton2dRenderComponent.SK_EventType_Start = 0


---@type number @enum SK_EventType
XSkeleton2dRenderComponent.SK_EventType_Interrupt = 0


---@type number @enum SK_EventType
XSkeleton2dRenderComponent.SK_EventType_End = 0


---@type number @enum SK_EventType
XSkeleton2dRenderComponent.SK_EventType_Complete = 0


---@type number @enum SK_EventType
XSkeleton2dRenderComponent.SK_EventType_Dispose = 0


---@type number @enum SK_EventType
XSkeleton2dRenderComponent.SK_EventType_Event = 0


---@public 设置/获取当前播放的动画名称。
---@param name cppstring name动画名称
---@return void
function XSkeleton2dRenderComponent:SetCurAnimationName(name) end


---@public XSkeleton2dRenderComponent_GetCurAnimationName00
---@return cppstring
function XSkeleton2dRenderComponent:GetCurAnimationName() end


---@public 设置当前动画。队列中的任何的动画将被清除。缓存模式下，trackIndex应设置为0
---@param name cppstring
---@param loop boolean
---@param trackIndex number trackIndex轨道索引，缓存模式不用设置
---@return number TrackEntryid
function XSkeleton2dRenderComponent:SetAnimation(name, loop, trackIndex) end


---@public 添加一个动画到动画队列尾部，还可以延迟指定的秒数。缓存模式下，trackIndex应设置为0
---@param name cppstring
---@param loop boolean
---@param delay number
---@param trackIndex number trackIndex轨道索引，缓存模式不用设置
---@return number
function XSkeleton2dRenderComponent:AddAnimation(name, loop, delay, trackIndex) end


---@public 用来为指定的 TrackEntry 设置动画的事件监听。
---@param entryid number
---@param listener  XSkeleton2DAnimationListener
---@param type number
---@return void
function XSkeleton2dRenderComponent:SetTrackListener(entryid, listener, type) end


---@public 用来为指定的 TrackEntry 设置动画播放过程中帧事件的监听。
---@param entryid number
---@param listener  XSkeleton2DEventListener
---@return void
function XSkeleton2dRenderComponent:SetTrackEventListener(entryid, listener) end


---@public 设置/获取当前播放的动画索引。
---@param index number index索引，默认-1
---@return void
function XSkeleton2dRenderComponent:SetCurAnimationIndex(index) end


---@public XSkeleton2dRenderComponent_GetCurAnimationIndex00
---@return number
function XSkeleton2dRenderComponent:GetCurAnimationIndex() end


---@public 清除所有 track 的动画状态。
---@return void
function XSkeleton2dRenderComponent:ClearTracks() end


---@public 清除出指定 track 的动画状态。
---@param trackIndex number
---@return void
function XSkeleton2dRenderComponent:ClearTrack(trackIndex) end


---@public 还原到起始动作。
---@return void
function XSkeleton2dRenderComponent:SetToSetupPose() end


---@public 设置 bone 到起始动作
---使用 SkeletonData 中的 BoneData 列表中的值
---@return void
function XSkeleton2dRenderComponent:SetBonesToSetupPose() end


---@public 设置 slot 到起始动作
---使用 SkeletonData 中的 SlotData 列表中的值
---@return void
function XSkeleton2dRenderComponent:SetSlotsToSetupPose() end


---@public 更新某个动画缓存, 预计算动画中所有帧数据，由于在单帧计算所有数据，所以较消耗性能。
---若想更新缓存，可使用 InvalidAnimationCache 方法，具有较高性能。
---@param animName cppstring
---@return void
function XSkeleton2dRenderComponent:UpdateAnimationCache(animName) end


---@public 使动画缓存失效，之后会在每帧重新计算。
---@return void
function XSkeleton2dRenderComponent:InvalidAnimationCache() end


---@public 按名称查找皮肤，激活该皮肤。这里对每个皮肤的名称进行了比较。
---注意：设置皮肤不会改变 attachment 的可见性。
---@param skinName cppstring
---@return void
function XSkeleton2dRenderComponent:SetSkin(skinName) end


---@public 设置/获取默认皮肤索引。
---@param index number index索引，默认-1
---@return void
function XSkeleton2dRenderComponent:SetDefaultSkinIndex(index) end


---@public XSkeleton2dRenderComponent_GetDefaultSkinIndex00
---@return number
function XSkeleton2dRenderComponent:GetDefaultSkinIndex() end


---@public 通过 slot 和 attachment 的名字来设置 attachment。
---Skeleton 优先查找它的皮肤，然后才是 Skeleton Data 中默认的皮肤。
---@param slotName cppstring
---@param attachmentName cppstring
---@return void
function XSkeleton2dRenderComponent:SetAttachment(slotName, attachmentName) end


---@public 为所有关键帧设定混合及混合时间（从当前值开始差值）。
---@param fromAnimation cppstring
---@param toAnimation cppstring
---@param duration number
---@return void
function XSkeleton2dRenderComponent:SetMix(fromAnimation, toAnimation, duration) end


---@public 用来设置动画的事件监听。
---@param listener  XSkeleton2DAnimationListener
---@param type number
---@return void
function XSkeleton2dRenderComponent:SetListener(listener, type) end


---@public 用来设置动画播放过程中帧事件的监听。
---@param listener  XSkeleton2DEventListener
---@return void
function XSkeleton2dRenderComponent:SetEventListener(listener) end


---@public 是否启用贴图预乘。
---@param value boolean
---@return void
function XSkeleton2dRenderComponent:SetOpacityModifyRGB(value) end


---@public XSkeleton2dRenderComponent_IsOpacityModifyRGB00
---@return boolean
function XSkeleton2dRenderComponent:IsOpacityModifyRGB() end


---@public 是否循环播放当前骨骼动画。
---@param loop boolean
---@return void
function XSkeleton2dRenderComponent:SetLoop(loop) end


---@public XSkeleton2dRenderComponent_IsLoop00
---@return boolean
function XSkeleton2dRenderComponent:IsLoop() end


---@public 当前骨骼中所有动画的时间缩放率。
---@param scale number
---@return void
function XSkeleton2dRenderComponent:SetTimeScale(scale) end


---@public XSkeleton2dRenderComponent_GetTimeScale00
---@return number
function XSkeleton2dRenderComponent:GetTimeScale() end


---@public 是否启用染色效果。
---@param enabled boolean
---@return void
function XSkeleton2dRenderComponent:SetUseTint(enabled) end


---@public XSkeleton2dRenderComponent_IsUseTint00
---@return boolean
function XSkeleton2dRenderComponent:IsUseTint() end


---@public 设置骨骼插槽可视范围，设置[-1，-1]清除此范围。仅限非缓存模式使用
---@param startSlotIndex number
---@param endSlotIndex number
---@return void
function XSkeleton2dRenderComponent:SetSlotsRange(startSlotIndex, endSlotIndex) end


---@public XSkeleton2dRenderComponent_Skeleton2DSpaceToNodeSpace00
---@param point XVECTOR2
---@return XVECTOR2
function XSkeleton2dRenderComponent:Skeleton2DSpaceToNodeSpace(point) end


---@public XSkeleton2dRenderComponent_NodeSpaceToSkeleton2DSpace00
---@param point XVECTOR2
---@return XVECTOR2
function XSkeleton2dRenderComponent:NodeSpaceToSkeleton2DSpace(point) end


---@public XSkeleton2dRenderComponent_SetScale00
---@param scale number
---@return void
function XSkeleton2dRenderComponent:SetScale(scale) end


---@public XSkeleton2dRenderComponent_GetScale00
---@return number
function XSkeleton2dRenderComponent:GetScale() end


---@type string @readonly 
XSkeleton2dRenderComponent.COMPONENT_TYPENAME = ''


