---@type number @enum EWorldMode
WM_EDITTING = 0


---@type number @enum EWorldMode
WM_RUNTIME = 0


---@class XEWorld
XEWorld = {}


---@public 更新世界可表示的关卡中的Actor列表中未被标记为delete的Actor，更新物理世界、执行事件回调以及执行绑定脚本编辑器中的Tick响应函数等。
---@param fDelSecond number
---@return void
function XEWorld:Tick(fDelSecond) end


---@type number @enum ESceneType 新GAME类型-MagicCubeV2中的default类型
XEWorld.ST_GAME = 0


---@type number @enum ESceneType 新GFX工程类型-MagicCubeV2中的头饰工程类型
XEWorld.ST_GFX = 0


---@type number @enum ESceneType 新视频礼物工程类型-MagicCubeV3新增
XEWorld.ST_VIDEO_GIFT = 0


---@type number @enum ESceneType 新SVGA工程类型-MagicCubeV3新增
XEWorld.ST_SVGA = 0


---@type number @enum ESceneType
XEWorld.ST_NUM = 0


---@public 从世界的Actor列表中移除pActor，并释放pActor
---@param pActor XEActor
---@return void
function XEWorld:ReleaseActor(pActor) end


---@public 为默认关卡加载场景文件和创建物理场景对象。 XECoreSDK指定的场景文件是.xscene 格式的文件,其内部实现是执行反序列化函数Deserialize.
---@param pRelativePath string 代表场景文件的相对路径，此处的相对路径是指xscene文件相对于工程文件夹的路径。
---@param bUseRelPathAsHome boolean 默认为false，如果为true，在world里加载的资源会自动拼接上这个xscene文件所在的路径，作为物理路径；否则不会拼接。
---@return boolean
function XEWorld:LoadScene(pRelativePath, bUseRelPathAsHome) end


---@public 创建指定类型的XEActor,并添加进当前默认关卡中
---@param strActorType string Actor类型名称
---@return XEActor
function XEWorld:CreateActor(strActorType) end


---@public 创建指定类型和指定名称的XEActor,并添加进当前默认关卡中
---@param strActorType string Actor类型名称
---@param strActorName string Actor名称
---@return XEActor
function XEWorld:CreateActor(strActorType, strActorName) end


---@public 功能同ReleaseActor
---@param pActor XEActor
---@return void
function XEWorld:DeleteActor(pActor) end


---@public 从当前所有关卡中,把名为strActorOldName的Actor改名为strActorNewName
---@param strActorOldName string
---@param strActorNewName string
---@return XEActor
function XEWorld:UpdateNameOfActor(strActorOldName, strActorNewName) end


---@public 从当前所有关卡中,合并显隐状态值
---@param pCurSelectActor  XEActor 设置的Actor指针
---@return void
function XEWorld:MergeActorHiddenStatus(pCurSelectActor) end


---@public 创建一个关卡(世界中关卡>1将会有额外的序列化操作)
---@param strLevelName string 关卡名称
---@return XELevel 关卡对象
function XEWorld:CreateLevel(strLevelName) end


---@public 从关卡队列中删除一个关卡
---@param pLevel XELevel 关卡对象
---@return boolean 是否成功
function XEWorld:DeleteLevel(pLevel) end


---@public 清空关卡
---@return void
function XEWorld:ClearLevels() end


---@public 为世界分配默认关卡(关卡索引值为0),如果关卡不存在,则创建
---@return XELevel 关卡对象
function XEWorld:AssignDefaultLevel() end


---@public 获取一个关卡
---@param strLevelName string 关卡名称
---@return XELevel 关卡对象
function XEWorld:FindLevel(strLevelName) end


---@public 获取一个关卡
---@param nLevelIndex number 关卡索引
---@return XELevel 关卡对象
function XEWorld:FindLevel(nLevelIndex) end


---@public 是否存在指定一个关卡
---@param pLevel XELevel
---@return boolean
function XEWorld:HasLevel(pLevel) end


---@public 获取该世界中的Actor的所属关卡
---@param pActor XEActor 该世界中的Actor
---@return XELevel 关卡对象
function XEWorld:GetLevelForActor(pActor) end


---@public 获取该世界中的关卡数量
---@return number
function XEWorld:GetLevelCount() end


---@public 判断是否可以Tick
---@return boolean
function XEWorld:IsTickable() end


---@public 设置是否可以Tick
---@param bEnable boolean
---@return void
function XEWorld:SetTickable(bEnable) end


---@public 判断物理是否Tick
---@return boolean
function XEWorld:IsTickPhysics() end


---@public 设置物理是否Tick
---@param bEnable boolean
---@return void
function XEWorld:SetTickPhysicsable(bEnable) end


---@public 判断物理是否渲染
---@return boolean
function XEWorld:IsRenderPhysics() end


---@public 设置物理是否渲染
---@param bEnable boolean
---@return void
function XEWorld:SetRenderPhysicsable(bEnable) end


---@public 清除Tick状态（表示是否已经Tick）
---@return void
function XEWorld:ClearTickState() end


---@public 设置当前世界模式
---@param mode number
---@return void
function XEWorld:SetWorldMode(mode) end


---@public 获取当前世界模式
---@return number
function XEWorld:GetWorldMode() end


---@public 设置当前世界名称
---@param szName string
---@return void
function XEWorld:SetWorldName(szName) end


---@public 获取当前世界名称
---@return string
function XEWorld:GetWorldName() end


---@public 在world里加载的资源是否会自动拼接xscene文件所在路径为物理路径
---@return boolean
function XEWorld:IsAssetRelativeToPackage() end


---@public 设置是否是预览模式
---@param bSet boolean
---@return void
function XEWorld:SetPreviewRenderMode(bSet) end


---@public 判断是否是预览模式
---@return boolean
function XEWorld:IsInPreviewRenderMode() end


---@public 判断是否在渲染时Level发生了立即渲染需求
---@return boolean
function XEWorld:IsLevelNeedRenderImmediately() end


---@public 获取xscene文件路径
---@return string
function XEWorld:GetSceneAssetPath() end


---@public 设置xscene文件路径
---@param pAssetPath string
---@return void
function XEWorld:SetSceneAssetPath(pAssetPath) end


---@public 获取Asset路径
---@return string
function XEWorld:GetAssetPackage() end


---@public 设置Asset路径
---@param pPackagePath string
---@return void
function XEWorld:SetAssetPackage(pPackagePath) end


---@public 从当前所有关卡中,查找指定名称的XEActor
---@param strActorName string
---@return XEActor
function XEWorld:FindActor(strActorName) end


---@public 从当前所有关卡中,查找指定IdString的XEActor
---@param strActorIdString string
---@return XEActor
function XEWorld:FindActorByIdString(strActorIdString) end


---@public 从当前所有关卡中,查找指定IdString的来源Actor
---@param strActorIdString string
---@return XEActor
function XEWorld:FindActorByOriginalIdString(strActorIdString) end


---@public 判断当前所有关卡中是否存在某个Actor
---当为true时，表示查找时如果找到了该Actor，不论它是否被标记为删除，都返回true;
---当为false时，表示即使查找到了该Actor，但是它被标记为删除，那么返回false。
---@param pActor  XEActor 判断的Actor指针
---@param bIgnoreDeleted boolean 是否忽略Actor被删除的标记，默认为true。
---@return boolean 是否找到
function XEWorld:HasActor(pActor, bIgnoreDeleted) end


---@public 返回当前所有关卡中Actor的个数
---@param strActorType string
---@return number
function XEWorld:GetActorCount(strActorType) end


---@public 查找当前所有关卡中某种类型的Actor
---@param strActorType string 要查找的Actor类型
---@return XEActor[]
---@return void
function XEWorld:GetActorsOfType(strActorType) end


---@public 获取当前所有关卡一个有效的Actor名称
---@param strActorType string
---@return string
function XEWorld:GetActorValidName(strActorType) end


---@public 获取当前所有关卡一个有效的Actor排序索引
---@return number
function XEWorld:GetActorValidOrder() end


---@public 获取默认关卡中的全部Actor,注:该函数为版本兼容函数! 请在其关卡中获取
---@return XEActor[]
function XEWorld:GetAllActors() end


---@public 获取默认关卡中的Actor map,保存了Actor的名称和指针
---@return xhashtable_XString_and_XEActor_p_
function XEWorld:GetActorFastMap() end


---@public 获取当前所有关卡一个有效的关卡名称
---@return string
function XEWorld:GetLevelValidName() end


---@public 检查并决定是否需要释放XETemporalObject
---@param handle userdata 分发的指针
---@return void
function XEWorld:VerifyAndReleaseTemporalObject(handle) end


---@public 当前所有关卡中, 恢复指定Viewport对应的激活相机
---@param pViewport XEViewport 当前世界绑定的视口指针.
---@return boolean
function XEWorld:RestoreActiveCamera(pViewport) end


---@public 获取世界的一个激活相机
---@return XBaseCamera
function XEWorld:GetOneActiveCamera() end


---@public 获取物理场景名称
---@return string
function XEWorld:GetPhysicsSceneName() end


---@public 根据给定的物理场景名称创建物理场景
---@param szSceneName string
---@return void
function XEWorld:CreatePhysicsScene(szSceneName) end


---@public 获取物理场景指针
---@return IXPhysicsScene
function XEWorld:GetPhysicsScene() end


---@public 获取物理场景指针,如果为空,则创建一个空物理场景
---新版本为效率考虑，不再默认创建物理场景
---@return IXPhysicsScene
function XEWorld:GetOrCreatePhysicsScene() end


---@public 释放物理场景
---@return void
function XEWorld:ReleasePhysicsScene() end


---@public 设置场景（工程）类型，（default/facetracker/mobile_ar）
---@param eSceneType number
---@return void
function XEWorld:SetSceneType(eSceneType) end


---@public 获取场景（或者说工程）类型（default/facetracker/mobile_ar）
---@return number
function XEWorld:GetSceneType() end


---@public 获取工程版本号（xint32）
---@return number
function XEWorld:GetSceneVersionValue() end


---@public 获取工程版本号（XString）
---@return string
function XEWorld:GetSceneVersion() end


---@public 设置工程版本号（XString）
---@param strVersion string
---@return void
function XEWorld:SetSceneVersion(strVersion) end


---@manual 当前可表示关卡中,射线拾取
---@public XEWorld_RayPick_manual
---@param vScreenPosition XVECTOR2
---@param HitResult XEHitResult
---@param pHitResultList XEHitResult[] 拾取结果列表.
---@param pRayCollisionChannel number[] 过滤的碰撞通道，表示这些通道不进行拾取测试.
---@param pActorsExclude XEActor[] 过滤的Actor数组.
---@return boolean 是否拾取成功
function XEWorld:RayPick(vScreenPosition, HitResult, pHitResultList, pRayCollisionChannel, pActorsExclude) end


---@manual 当前可表示关卡中,射线拾取
---@public XEWorld_RayPick_manual
---@param HitResult XEHitResult
---@param pHitResultList XEHitResult[] 拾取结果列表.
---@param pRayCollisionChannel number[] 过滤的碰撞通道，表示这些通道不进行拾取测试.
---@param pActorsExclude XEActor[] 过滤的Actor数组.
---@return boolean 是否拾取成功
function XEWorld:RayPick(HitResult, pHitResultList, pRayCollisionChannel, pActorsExclude) end


---@public 当前所有关卡中, 拷贝选中的Actor
---@param aActors XEActor[] 要拷贝的Actor列表
---@param bIsChangeCopyName boolean 是否改变Actor名称，默认为true
---@param bIsResetActorProperty boolean 是否重置Actor属性，默认为true
---@return void
function XEWorld:CopySelectedActors(aActors, bIsChangeCopyName, bIsResetActorProperty) end


---@public 当前所有关卡中, 黏贴选中的Actors
---@return XEActor[] 返回黏贴的Actors指针列表
function XEWorld:PasteSelectedActors() end


---@public 当前所有关卡中, 重新绑定Actor到父节点Actor上
---@param pSourceActor XEActor 子Actor指针
---@param pParentActor XEActor 父Actor指针
---@param pBindUesrNode userdata 绑定的UserNode节点信息
---@return void
function XEWorld:ReAttachToActor(pSourceActor, pParentActor, pBindUesrNode) end


---@public 获取当前所有关卡Attach的Viewport指针
---@return XEViewport
function XEWorld:GetAttachedViewport() end


---@public 创建一个subview, 如果不指定subviewname, 则自动创建一个，前缀为SubView_[$snowid]
---@param szSubViewName string
---@return XESubview
function XEWorld:CreateSubview(szSubViewName) end


---@public 根据名字找到subview
---@param szSubViewName string
---@return XESubview
function XEWorld:GetSubview(szSubViewName) end


---@public 根据subview的别名获取subview
---@param szSubviewAlias string
---@return XESubview
function XEWorld:GetSubviewByAlias(szSubviewAlias) end


---@public 将当前世界中视口的灯光、相机(如果子视图指定了内部相机，则使用内部相机)设置到指定子视图
---@param pSubview XESubview 子视图对象
---@return boolean
function XEWorld:ApplySubviewParam(pSubview) end


---@public 设置子视图的渲染背景，开启自定义背景时，引擎默认背景将不再渲染到此子视图中
---@param pSubview XESubview 子视图对象
---@param pTex IXTexture2D
---@param fLeftTexcoord number 纹理空间内左坐标[0,1]
---@param fTopTexcoord number 纹理空间内顶坐标[0,1]
---@param fWidthTexcoord number 纹理空间内宽[0,1]
---@param fHeightTexcoord number 纹理空间内高[0,1]
---@return boolean
function XEWorld:SetSubviewBgTexture(pSubview, pTex, fLeftTexcoord, fTopTexcoord, fWidthTexcoord, fHeightTexcoord) end


---@public 删除subview,如果不指定 pSubview，则删除所有
---@param pSubview XESubview
---@return boolean
function XEWorld:RemoveSubview(pSubview) end


---@public 释放subview, 如果不指定 pSubview，则重置所有
---@param pSubview XESubview
---@return void
function XEWorld:ReleaseSubview(pSubview) end


---@public 获取所有子视图
---@return XESubview[]
function XEWorld:GetAllSubviews() end


---@public 从所有世界中获取所有的subview
---@return XESubview[]
function XEWorld:GetAllSubviewsFromAllWorld() end


---@public XEWorld_ComponentSweepMulti00
---@param vOutHits XEHitResult[]
---@param pShapeComp XEShapeComponent
---@param vStart XVECTOR3
---@param vEnd XVECTOR3
---@param qRot XQUATERNION
---@return boolean
function XEWorld:ComponentSweepMulti(vOutHits, pShapeComp, vStart, vEnd, qRot) end


---@public 获取当前世界的世界属性结构体指针
---@return XEWorldParam
function XEWorld:GetWorldParam() end


