---@class XBaseCamera : XOwnerRecorder
XBaseCamera = {}


---@public 初始化相机
---@param fZNear number 近裁剪面距离相机的距离
---@param fZFar number 远裁剪面距离相机的距离
---@return boolean 是否初始化成功
function XBaseCamera:Init(fZNear, fZFar) end


---@public 释放
---@return void
function XBaseCamera:Release() end


---@public 判断是否是透视投影相机
---@return boolean 是否是透视投影相机
function XBaseCamera:IsPerspective() end


---@public 判断是否是正交投影相机
---@return boolean 是否是正交投影相机
function XBaseCamera:IsOrthogonal() end


---@public 设置前方向和上方向方向向量
---@param vecDir XVECTOR3 前方向方向向量
---@param vecUp XVECTOR3 正方向方向向量
---@return void
function XBaseCamera:SetDirAndUp(vecDir, vecUp) end


---@public 相机向前移动一段距离
---@param fDistance number 移动的距离
---@return boolean 是否移动成功
function XBaseCamera:MoveForward(fDistance) end


---@public 相机向后移动一段距离
---@param fDistance number 移动的距离
---@return boolean 是否移动成功
function XBaseCamera:MoveBack(fDistance) end


---@public 相机向左移动一段距离
---@param fDistance number 移动的距离
---@return boolean 是否移动成功
function XBaseCamera:MoveLeft(fDistance) end


---@public 相机向右移动一段距离
---@param fDistance number 移动的距离
---@return boolean 是否移动成功
function XBaseCamera:MoveRight(fDistance) end


---@public 相机移动一段距离
---@param vecDelta XVECTOR3 移动的信息（包含了前/后、左/右、上/下的移动信息）
---@return boolean 是否移动成功
function XBaseCamera:MoveDelta(vecDelta) end


---@public 让相机以vecPos为参考点围绕向量vecAxis旋转一定弧度
---@param vecPos XVECTOR3 参考点
---@param vecAxis XVECTOR3 表示旋转轴的向量
---@param fDeltaRad number 绕指定轴旋转的弧度角
---@return boolean 是否旋转成功
function XBaseCamera:RotateCameraAroundAxisInWorld(vecPos, vecAxis, fDeltaRad) end


---@public 调整水平偏航角
---@param vDelta number 偏移量，单位为度
---@return boolean 是否设置成功
function XBaseCamera:DegDelta(vDelta) end


---@public 调整垂直俯仰角
---@param vDelta number 偏移量，单位为度
---@return boolean 是否设置成功
function XBaseCamera:PitchDelta(vDelta) end


---@public 设置水平偏航角
---@param vDeg number 新的偏航角的值，单位为度
---@return boolean 是否设置成功
function XBaseCamera:SetDeg(vDeg) end


---@public 设置垂直俯仰角
---@param vPitch number 新的俯仰角的值，单位为度
---@return boolean 是否设置成功
function XBaseCamera:SetPitch(vPitch) end


---@public 设置镜像相机，为引擎内部逻辑调用函数
---@param pCamera XBaseCamera 设置的镜像相机
---@param vOrgin XVECTOR3 镜像的参考平面
---@param vNormal XVECTOR3 镜像平面的法线
---@return boolean 是否设置成功
function XBaseCamera:SetMirrorCamera(pCamera, vOrgin, vNormal) end


---@public 设置相机视图矩阵
---@param matView XMATRIX4 相机视图矩阵
---@return boolean 是否设置成功
function XBaseCamera:SetViewMatrix(matView) end


---@public 设置相机投影矩阵
---@param matProjection XMATRIX4 投影矩阵
---@return boolean 是否设置成功
function XBaseCamera:SetProjectionMatrix(matProjection) end


---@public 设置相机远近裁剪距离
---@param fFront number 近裁剪面距离
---@param fBack number 远裁剪面距离
---@param bUpdateProjMat boolean 如果是xtrue,同时更新透视投影矩阵，默认为xtrue
---@return boolean 是否设置成功
function XBaseCamera:SetZNearFar(fFront, fBack, bUpdateProjMat) end


---@public 返回近裁剪面到相机距离
---@return number 近裁剪面到相机距离
function XBaseCamera:GetZNear() end


---@public 返回远裁剪面到相机距离
---@return number 远裁剪面到相机距离
function XBaseCamera:GetZFar() end


---@public 设置相机位置
---@param vPos XVECTOR3 相机位置坐标
---@return void
function XBaseCamera:SetPos(vPos) end


---@public 返回相机视图矩阵
---@return XMATRIX4 相机视图矩阵
function XBaseCamera:GetViewMatrix() end


---@public 返回相机投影矩阵
---@return XMATRIX4 相机投影矩阵
function XBaseCamera:GetProjectionMatrix() end


---@public 返回相机视图与投影矩阵积
---@return XMATRIX4 相机视图与投影矩阵的积
function XBaseCamera:GetViewProjMatrix() end


---@public 返回相机前方向法向量
---@return XVECTOR3 相机前方向法向量
function XBaseCamera:GetDir() end


---@public 返回相机XZ平面上的前方向，实际为相机前方向在XZ平面上的投影
---@return XVECTOR3 相机XZ平面上的前方向，为单位向量
function XBaseCamera:GetHorizontalDir() end


---@public 返回相机上方向法向量
---@return XVECTOR3 相机上方向法向量
function XBaseCamera:GetUp() end


---@public 返回相机右方向法向量
---@return XVECTOR3 相机右方向法向量
function XBaseCamera:GetRight() end


---@public 返回相机左方向法向量
---@return XVECTOR3 相机左方向法向量
function XBaseCamera:GetLeft() end


---@public 返回相机XZ平面上的左方向向量，实际为相机左方向在XZ平面上的投影
---@return XVECTOR3 相机XZ平面上左方向向量，为单位向量
function XBaseCamera:GetHorizontalLeft() end


---@public 返回相机XZ平面上的右方向向量，实际为相机右方向在XZ平面上的投影
---@return XVECTOR3 相机XZ平面上右方向向量，为单位向量
function XBaseCamera:GetHorizontalRight() end


---@public 判断AABB包围盒是否在相机视椎体内
---@param aabb  XCusAABB 判断的包围盒信息
---@return boolean 如果在，返回xtrue，否则，返回false.
function XBaseCamera:IsAABBInViewFrustum(aabb) end


---@public 判断AABB包围盒是否在相机视椎体内
---@param vMins XVECTOR3 AABB包围盒“最小”点
---@param vMaxs XVECTOR3 AABB包围盒“最大”点
---@return boolean 如果在，返回xtrue，否则，返回false.
function XBaseCamera:IsAABBInViewFrustum(vMins, vMaxs) end


---@public 判断球体是否在相机视椎体内
---@param vCenter XVECTOR3 球体中心点坐标
---@param fRadius number 球体半径
---@return boolean 如果在，返回xtrue，否则，返回false.
function XBaseCamera:IsSphereInViewFrustum(vCenter, fRadius) end


---@public 判断点是否在相机视椎体内
---@param vPos XVECTOR3 点坐标
---@return boolean 如果在，返回xtrue，否则，返回false.
function XBaseCamera:IsPointInViewFrustum(vPos) end


---@public XBaseCamera_TransformWorldToProj00
---@param vWorld XVECTOR3
---@return XVECTOR3
---@return boolean
function XBaseCamera:TransformWorldToProj(vWorld) end


---@public XBaseCamera_InvTransformProjToWorld00
---@param vProj XVECTOR3
---@return XVECTOR3
---@return boolean
function XBaseCamera:InvTransformProjToWorld(vProj) end


---@public 获取相机位置
---@return XVECTOR3 相机位置坐标
function XBaseCamera:GetCameraPos() end


---@public 获取相机水平偏航角
---@return number 相机水平偏航角
function XBaseCamera:GetDeg() end


---@public 获取相机垂直俯仰角
---@return number 相机垂直俯仰角
function XBaseCamera:GetPitch() end


---@public 获取相机再投影矩阵，相当于投影后乘以此矩阵，进行附加的投影操作，一般为引擎内部逻辑使用
---@return XMATRIX4 相机再投影矩阵
function XBaseCamera:GetPostProjectMatrix() end


---@public 设置相机再投影矩阵，相当于投影后乘以此矩阵，进行附加的投影操作，一般为引擎内部逻辑使用
---@param matPostProjectTM XMATRIX4 相机再投影矩阵
---@return void
function XBaseCamera:SetPostProjectMatrix(matPostProjectTM) end


---@public 获取世界空间的视椎体
---@return XCameraViewFrustum 世界空间的视椎体
function XBaseCamera:GetWorldFrustum() end


---@public 获取相机空间的视椎体
---@return XCameraViewFrustum 相机空间的视椎体
function XBaseCamera:GetViewFrustum() end


---@public 获取相机是否是镜像相机
---@return boolean 是否为镜像相机
function XBaseCamera:IsMirrored() end


---@public 获取关联的镜像相机指针
---@return XBaseCamera 镜像相机的指针
function XBaseCamera:GetMirrorCamera() end


---@public 获取镜像矩阵
---@return XMATRIX4 返回镜像矩阵
function XBaseCamera:GetMirrorMatrix() end


