---@class XBaseCoordSpace
XBaseCoordSpace = {}


---@public XBaseCoordSpace_new00
---@return XBaseCoordSpace
function XBaseCoordSpace:new() end


---@public 设置世界坐标系下的绝对位置
---@param vPosition XVECTOR3 世界坐标系下的绝对位置
---@return void
function XBaseCoordSpace:SetAbsolutePosition(vPosition) end


---@public 返回世界坐标系下的绝对位置
---@return XVECTOR3 世界坐标系下的绝对位置
function XBaseCoordSpace:GetAbsolutePosition() end


---@public 设置世界坐标变换矩阵
---@param matrix XMATRIX4 世界坐标变换矩阵
---@return void
function XBaseCoordSpace:SetAbsoluteMatrix(matrix) end


---@public 返回世界坐标变换矩阵
---@return XMATRIX4 世界坐标变换矩阵
function XBaseCoordSpace:GetAbsoluteMatrix() end


---@public 设置相对坐标变换矩阵
---@param matrix XMATRIX4 相对坐标变换矩阵
---@return void
function XBaseCoordSpace:SetRelativeMatrix(matrix) end


---@public 返回相对坐标变换矩阵
---@return XMATRIX4 相对坐标变换矩阵
function XBaseCoordSpace:GetRelativeMatrix() end


---@public 设置前方向、上方向
---@param vForwardDir XVECTOR3 前方向法向量
---@param vUp XVECTOR3 上方向法向量
---@return void
function XBaseCoordSpace:SetForwardDirAndUp(vForwardDir, vUp) end


---@public 设置位置、前方向、上方向
---@param vPosition XVECTOR3 位置
---@param vForwardDir XVECTOR3 前方向法向量
---@param vUp XVECTOR3 上方向法向量
---@return void
function XBaseCoordSpace:SetPositionAndForwardDirUp(vPosition, vForwardDir, vUp) end


---@public 设置相对父坐标系的位置
---@param vPosition XVECTOR3 相对父坐标系的位置
---@return void
function XBaseCoordSpace:SetRelativePosition(vPosition) end


---@public 设置相对父坐标系的前方向、上方向
---@param vForwardDir XVECTOR3 前方向法向量
---@param vUp XVECTOR3 上方向法向量
---@return void
function XBaseCoordSpace:SetRelativeForwardDirAndUp(vForwardDir, vUp) end


---@public 设置相对父坐标系的位置、前方向、上方向
---@param vPosition XVECTOR3 位置
---@param vForwardDir XVECTOR3 前方向法向量
---@param vUp XVECTOR3 上方向法向量
---@return void
function XBaseCoordSpace:SetRelativePositionAndForwardDir(vPosition, vForwardDir, vUp) end


---@public 返回世界坐标系下的前方向
---@return XVECTOR3 世界坐标系下的前方向
function XBaseCoordSpace:GetAbsoluteDir() end


---@public 返回世界坐标系下的上方向
---@return XVECTOR3 世界坐标系下的上方向
function XBaseCoordSpace:GetAbsoluteUp() end


---@public 返回世界坐标系下的右方向
---@return XVECTOR3 世界坐标系下的右方向
function XBaseCoordSpace:GetAbsoluteRight() end


---@public 在世界坐标系下移动一个Delta
---@param vDelta XVECTOR3 移动的信息
---@return void
function XBaseCoordSpace:AbsoluteMove(vDelta) end


---@public 在父坐标系下移动一个Delta
---@param vDelta XVECTOR3 移动的信息
---@return void
function XBaseCoordSpace:RelativeMove(vDelta) end


---@public 绕X轴旋转一个弧度
---@param fDeltaRadian number 旋转量，单位弧度
---@param bLocalSpace boolean xtrue:在本地坐标系下旋转，xfalse：在世界坐标系下旋转
---@return void
function XBaseCoordSpace:RotateX(fDeltaRadian, bLocalSpace) end


---@public 绕Y轴旋转一个弧度
---@param fDeltaRadian number 旋转量，单位弧度
---@param bLocalSpace boolean xtrue:在本地坐标系下旋转，xfalse：在世界坐标系下旋转
---@return void
function XBaseCoordSpace:RotateY(fDeltaRadian, bLocalSpace) end


---@public 绕Z轴旋转一个弧度
---@param fDeltaRadian number 旋转量，单位弧度
---@param bLocalSpace boolean xtrue:在本地坐标系下旋转，xfalse：在世界坐标系下旋转
---@return void
function XBaseCoordSpace:RotateZ(fDeltaRadian, bLocalSpace) end


---@public 绕轴旋转一个弧度量
---@param vRotateAxis XVECTOR3 表示旋转轴
---@param fDeltaRadian number 旋转量，单位弧度
---@param bLocalSpace boolean xtrue:在本地坐标系下旋转，xfalse：在世界坐标系下旋转
---@return void
function XBaseCoordSpace:RotateAxis(vRotateAxis, fDeltaRadian, bLocalSpace) end


---@public 增加相对（子）坐标系
---@param pChildSpace XBaseCoordSpace 增加的相对（子）坐标系
---@return boolean 是否增加成功
function XBaseCoordSpace:AddChildCoordSpace(pChildSpace) end


---@public 删除相对（子）坐标系
---@param pChildSpace XBaseCoordSpace 删除的相对（子）坐标系
---@return void
function XBaseCoordSpace:RemoveChildCoordSpace(pChildSpace) end


---@public 删除所有相对（子）坐标系
---@return void
function XBaseCoordSpace:RemoveAllChildrenCoordSpaces() end


---@public 返回相对（子）坐标系的数量
---@return number 相对（子）坐标系的数量
function XBaseCoordSpace:GetChildrenCoordSpaceNum() end


---@public 设置相对（父）坐标系
---@param pParentSpace XBaseCoordSpace 相对（父）坐标系
---@return void
function XBaseCoordSpace:SetParentCoordSpace(pParentSpace) end


---@public 返回相对（父）坐标系
---@return XBaseCoordSpace 相对（父）坐标系
function XBaseCoordSpace:GetParentCoordSpace() end


