---@type number @enum XModelType
XSMT_ANIMAMODEL = 0


---@type number @enum XModelType
XSMT_STATICMODEL = 0


---@type number @enum XModelType
XSMT_NUM = 0


---@class XModel : XOwnerRecorder
XModel = {}


---@public 释放模型资源
---@return void
function XModel:Release() end


---@public 获取模型资源文件名
---@return string 模型资源文件名
function XModel:GetModelFile() end


---@public 获取模型Skin总个数
---@return number 模型Skin总个数
function XModel:GetSkinNum() end


---@public 获取模型版本号
---@return number 模型版本号
function XModel:GetVersion() end


---@public 获取模型某个skin
---@param nIndex number 指定Skin索引
---@return  XSkin skin对象
function XModel:GetSkin(nIndex) end


---@public 获取模型某个skin
---@param nIndex number 指定Skin索引
---@return XSkin skin对象
function XModel:GetSkin(nIndex) end


---@public 给模型添加skin
---@param szSkinFile string skin文件路径名
---@param bReload boolean 是否重新加载
---@param szSkeletonPath string 对应的骨架路径名
---@param strLoadLog string
---@return boolean 是否添加成功
function XModel:AddSkin(szSkinFile, bReload, szSkeletonPath, strLoadLog) end


---@public 移除某个skin
---@param szSkinFile string 要移除的skin文件路径名
---@return void
function XModel:RemoveSkin(szSkinFile) end


---@public 绑定骨架对象
---@param pSkeleton XSkeleton 骨架对象
---@return void
function XModel:BindSkeleton(pSkeleton) end


---@public 获取模型类型
---@return number 模型类型
function XModel:GetModelType() end


---@public 获取模型骨架对象文件路径名
---@return string 骨架对象文件路径名
function XModel:GetSkeletonFile() end


---@public 获取模型骨架对象
---@return XSkeleton 骨架对象
function XModel:GetSkeleton() end


---@public 判断是否有融合目标
---@return boolean 是否有融合目标
function XModel:SkinHaveBlendShapeTargets() end


---@public 判断模型三角形面总个数
---@return number 三角形面总个数
function XModel:GetFaceNum() end


---@public 根据skin名称获取skin索引
---@param szSkinFile string skin名称
---@param bCmpFullPath boolean 是否是全路径
---@return number 对应的skin索引
function XModel:GetSkinIndexBySkinFileName(szSkinFile, bCmpFullPath) end


---@public 根据骨头索引获取骨头的OBB包围盒
---@param nBoneIndex number 骨头索引
---@return  XCusOBB 骨头的OBB包围盒
function XModel:GetBoneOBB(nBoneIndex) end


---@public 保存模型模板信息
---@param bRecursive boolean 是否递归遍历
---@return void
function XModel:Save(bRecursive) end


---@class IXModelManager : XMemBase
IXModelManager = {}


---@public 初始化
---@return boolean 是否初始化成功
function IXModelManager:Init() end


---@public 释放模型资源
---@return void
function IXModelManager:Release() end


---@public 释放模型资源
---从文件中加载模型
---@param szNewSkinModelFile string
---@param szSkeletonFile string
---@return XModel
function IXModelManager:CreateModel(szNewSkinModelFile, szSkeletonFile) end


---@public 获取模型对象
---@param szSkinModelFile string
---@param bReload boolean
---@param strLoadLog string
---@return XModel 模型对象
function IXModelManager:GetModel(szSkinModelFile, bReload, strLoadLog) end


---@public 获取模型某个skin
---@param szFileName string
---@param bReload boolean
---@param szSkeletonPath string
---@param strLoadLog string
---@return XSkin skin对象
function IXModelManager:GetSkin(szFileName, bReload, szSkeletonPath, strLoadLog) end


---@public 创建Skin
---@param szNewSkinFile string
---@param szSkinDatXFile string
---@param szSkeletonFile string
---@return XSkin 蒙皮对象
function IXModelManager:CreateSkin(szNewSkinFile, szSkinDatXFile, szSkeletonFile) end


---@public 获取SkinData数据
---@param szSkinDatXFileName string
---@param bReload boolean
---@return XSkinData 蒙皮数据
function IXModelManager:GetSkinData(szSkinDatXFileName, bReload) end


---@public 创建SkinData数据
---@param szSkinDatXFileName string
---@param nNumLODs number
---@return XSkinData 蒙皮数据
function IXModelManager:CreateSkinData(szSkinDatXFileName, nNumLODs) end


---@public 创建模型实例指针
---@param szSkinModelFileName string
---@param strLoadLog string
---@return IXModelInstance 模型实例指针
function IXModelManager:CreateSkinModelInstance(szSkinModelFileName, strLoadLog) end


---@public 重新加载骨架资源
---@param szSkeletonFile string
---@return void
function IXModelManager:ReloadSkeleton(szSkeletonFile) end


---@public 重新加载蒙皮模型
---@param szSkinModelFile string
---@return void
function IXModelManager:ReloadSkinModel(szSkinModelFile) end


---@public 重新加载蒙皮
---@param szFileName string
---@return void
function IXModelManager:ReloadSkin(szFileName) end


---@public 重新加载蒙皮数据
---@param szSkinDatXFileName string
---@return void
function IXModelManager:ReloadSkinData(szSkinDatXFileName) end


---@public 判断骨架是否存在(内存+硬盘)
---@param szSkeletonFile string
---@return boolean 是否存在
function IXModelManager:IsSkeletonExist(szSkeletonFile) end


---@public 判断模型是否存在(内存+硬盘)
---@param szSkinModelFile string
---@return boolean 是否存在
function IXModelManager:IsModelExist(szSkinModelFile) end


---@public 判断蒙皮是否存在(内存+硬盘)
---@param szFileName string
---@return boolean 是否存在
function IXModelManager:IsSkinExist(szFileName) end


---@public 判断蒙皮数据是否存在(内存+硬盘)
---@param szSkinDataFileName string
---@return boolean 是否存在
function IXModelManager:IsSkinDataExist(szSkinDataFileName) end


---@public 判断骨架是否加载成功
---@param szSkeletonFile string 骨架资源文件名
---@return boolean 是否加载成功
function IXModelManager:IsSkeletonLoaded(szSkeletonFile) end


---@public 判断蒙皮模型是否加载成功
---@param szSkinModelFile string 蒙皮模型文件名
---@return boolean 是否加载成功
function IXModelManager:IsSkinModelLoaded(szSkinModelFile) end


---@public 判断蒙皮是否加载成功
---@param szFileName string 蒙皮文件名
---@return boolean 是否加载成功
function IXModelManager:IsSkinLoaded(szFileName) end


---@public 判断蒙皮数据是否加载成功
---@param szSkinDatXFileName string 蒙皮数据文件名
---@return boolean 是否加载成功
function IXModelManager:IsSkinDataLoaded(szSkinDatXFileName) end


---@public IXModelManager_UpdateUpwardFromSkinData00
---@param pSkinData XSkinData
---@return void
function IXModelManager:UpdateUpwardFromSkinData(pSkinData) end


