---@class IXCanvasBase
IXCanvasBase = {}


---@public 绘制字符串
---@param x number 绘制的位置坐标的x分量
---@param y number 绘制的位置坐标的y分量
---@param szString string 要绘制的字符串内容
---@param clr  XCOLORBASE 绘制颜色（XCOLORBASE格式）
---@return void
function IXCanvasBase:DrawString(x, y, szString, clr) end


---@public 绘制四边形
---@param x number 绘制的起始位置坐标的x分量
---@param y number 绘制的起始位置坐标的y分量
---@param nWidth number 绘制的四边形宽度
---@param nHeight number 绘制的四边形高度
---@param clr  XCOLORBASE 绘制颜色（XCOLORBASE格式）
---@param bSolid boolean 是否用颜色填充四边形区域，默认是false
---@param pMat XMATRIX3 叠加矩阵，默认为空。（如果设置了叠加矩阵，绘制信息会叠加上这个矩阵数据）
---@return void
function IXCanvasBase:DrawQuad(x, y, nWidth, nHeight, clr, bSolid, pMat) end


---@public 绘制2D直线
---@param xBegin number 直线的起始点坐标x分量
---@param yBegin number 直线的起始点坐标y分量
---@param xEnd number 直线的结束点坐标x分量
---@param yEnd number 直线的结束点坐标y分量
---@param clr  XCOLORBASE 绘制颜色（XCOLORBASE格式）
---@param pMat XMATRIX3 叠加矩阵，默认为空。（如果设置了叠加矩阵，绘制信息会叠加上这个矩阵数据）
---@return void
function IXCanvasBase:Render2DLine(xBegin, yBegin, xEnd, yEnd, clr, pMat) end


---@public IXCanvasBase_Render2DCircle00
---@param vPos XVECTOR2
---@param fRadius number
---@param vStartNormalizedDir XVECTOR2
---@param vEndNormalizedDir XVECTOR2
---@param color  XCOLORBASE
---@param bClockWise boolean
---@param bSolid boolean
---@param pMat XMATRIX3
---@return void
function IXCanvasBase:Render2DCircle(vPos, fRadius, vStartNormalizedDir, vEndNormalizedDir, color, bClockWise, bSolid, pMat) end


---@public 绘制一条3D直线
---@param vBegin XVECTOR3 直线起始点坐标
---@param vEnd XVECTOR3 直线结束点坐标
---@param clr  XCOLORBASE 绘制颜色（XCOLORBASE格式）
---@param bZEnabled boolean 是否开启深度测试，默认为xtrue(开启后，只绘制观察者可见到的部分)
---@return void
function IXCanvasBase:RenderLine(vBegin, vEnd, clr, bZEnabled) end


---@public IXCanvasBase_RenderLines00
---@param aVerts XVECTOR3
---@param nNumVert number
---@param aIndices number
---@param nNumIndex number
---@param clr  XCOLORBASE
---@param aColors  XCOLORBASE
---@param nNumColor number
---@param bZEnabled boolean
---@return void
function IXCanvasBase:RenderLines(aVerts, nNumVert, aIndices, nNumIndex, clr, aColors, nNumColor, bZEnabled) end


---@public 绘制AABB包围盒
---@param aabb  XCusAABB 要绘制的包围盒信息
---@param clr  XCOLORBASE 绘制颜色（XCOLORBASE格式）
---@param bSolid boolean 是否用颜色填充绘制的区域，默认是false
---@param bLight boolean 是否绘制光照信息，默认为xtrue
---@param bZEnabled boolean 是否开启深度测试，默认为xtrue(开启后，只绘制观察者可见到的部分)
---@return void
function IXCanvasBase:RenderAABB(aabb, clr, bSolid, bLight, bZEnabled) end


---@public 绘制球状
---@param vPos XVECTOR3 要绘制的包围盒信息
---@param fRadius number 要绘制的包围盒信息
---@param clr  XCOLORBASE 绘制颜色（XCOLORBASE格式）
---@param bSolid boolean 是否用颜色填充绘制的区域，默认是false
---@param bLight boolean 是否绘制光照信息，默认为xtrue
---@param bZEnabled boolean 是否开启深度测试，默认为xtrue(开启后，只绘制观察者可见到的部分)
---@param pMat XMATRIX4 叠加矩阵，默认为空。（如果设置了叠加矩阵，绘制信息会叠加上这个矩阵数据）
---@return void
function IXCanvasBase:RenderSphere(vPos, fRadius, clr, bSolid, bLight, bZEnabled, pMat) end


---@public 绘制OBB包围盒
---@param obb  XCusOBB 要绘制的包围盒信息
---@param clr  XCOLORBASE 绘制颜色（XCOLORBASE格式）
---@param bSolid boolean 是否用颜色填充绘制的区域，默认是false
---@param bLight boolean 是否绘制光照信息，默认为xtrue
---@param bZEnabled boolean 是否开启深度测试，默认为xtrue(开启后，只绘制观察者可见到的部分)
---@param pMat XMATRIX4 叠加矩阵，默认为空。（如果设置了叠加矩阵，绘制信息会叠加上这个矩阵数据）
---@return void
function IXCanvasBase:RenderOBB(obb, clr, bSolid, bLight, bZEnabled, pMat) end


---@public IXCanvasBase_RenderBox00
---@param vPos XVECTOR3
---@param vDir XVECTOR3
---@param vUp XVECTOR3
---@param vRight XVECTOR3
---@param vExts XVECTOR3
---@param clr  XCOLORBASE
---@param bSolid boolean
---@param bLight boolean
---@param bZEnabled boolean
---@param pMat XMATRIX4
---@return void
function IXCanvasBase:RenderBox(vPos, vDir, vUp, vRight, vExts, clr, bSolid, bLight, bZEnabled, pMat) end


---@public 绘制椎体
---@param cone  XCusCone 要绘制的椎体信息
---@param clr  XCOLORBASE 绘制颜色（XCOLORBASE格式）
---@param bSolid boolean 是否用颜色填充绘制的区域，默认是false
---@param bLight boolean 是否绘制光照信息，默认为xtrue
---@param bZEnabled boolean 是否开启深度测试，默认为xtrue(开启后，只绘制观察者可见到的部分)
---@param pMat XMATRIX4 叠加矩阵，默认为空。（如果设置了叠加矩阵，绘制信息会叠加上这个矩阵数据）
---@return void
function IXCanvasBase:RenderCone(cone, clr, bSolid, bLight, bZEnabled, pMat) end


---@public IXCanvasBase_RenderCustomGeometry00
---@param aVerts XVECTOR3
---@param nNumVert number
---@param aIndices number
---@param nNumIndex number
---@param clr  XCOLORBASE
---@param aColors  XCOLORBASE
---@param nNumColor number
---@param aNormals XVECTOR3
---@param nNumNormal number
---@param bLight boolean
---@param bZEnabled boolean
---@return void
function IXCanvasBase:RenderCustomGeometry(aVerts, nNumVert, aIndices, nNumIndex, clr, aColors, nNumColor, aNormals, nNumNormal, bLight, bZEnabled) end


---@public IXCanvasBase_RenderCustomGeometry01
---@param aVerts XVECTOR3
---@param aColors  XCOLORBASE
---@param aTexcoords XVECTOR2
---@param nNumVert number
---@param aIndices number
---@param nNumIndex number
---@param pTex IXTexture
---@param bZEnabled boolean
---@return void
function IXCanvasBase:RenderCustomGeometry(aVerts, aColors, aTexcoords, nNumVert, aIndices, nNumIndex, pTex, bZEnabled) end


---@public IXCanvasBase_RenderCircle00
---@param vPos XVECTOR3
---@param fRadius number
---@param vStartNormalizedDir XVECTOR3
---@param vEndNormalizedDir XVECTOR3
---@param vNormalizedRotationAxis XVECTOR3
---@param color  XCOLORBASE
---@param bSolid boolean
---@param bZEnabled boolean
---@param pWorldMat XMATRIX4
---@return void
function IXCanvasBase:RenderCircle(vPos, fRadius, vStartNormalizedDir, vEndNormalizedDir, vNormalizedRotationAxis, color, bSolid, bZEnabled, pWorldMat) end


---@public 绘制胶囊体
---@param capsule  XCusCapsule 要绘制的胶囊体信息
---@param clr  XCOLORBASE 绘制颜色（XCOLORBASE格式）
---@param bSolid boolean 是否用颜色填充绘制的区域，默认是false
---@param bLight boolean 是否绘制光照信息，默认为xtrue
---@param bZEnabled boolean 是否开启深度测试，默认为xtrue(开启后，只绘制观察者可见到的部分)
---@param pMat XMATRIX4 叠加矩阵，默认为空。（如果设置了叠加矩阵，绘制信息会叠加上这个矩阵数据）
---@return void
function IXCanvasBase:RenderCapsule(capsule, clr, bSolid, bLight, bZEnabled, pMat) end


