---@type number @enum XLightType
XLT_DIRECTION = 0


---@type number @enum XLightType
XLT_POINT = 0


---@type number @enum XLightType
XLT_SPOT = 0


---@type number @enum XLightType
XLT_ENV = 0


---@type number @enum XLightType
XLT_NUM = 0


---@class XPointLightDesc
XPointLightDesc = {}


---@type XCOLORBASE
XPointLightDesc.clrColorVal = {}


---@type number
XPointLightDesc.fLuminance = 0


---@type XVECTOR3
XPointLightDesc.vPos = {}


---@type number
XPointLightDesc.fRadius = 0


---@type number
XPointLightDesc.fFallOffExponent = 0


---@public XPointLightDesc_new00
---@return XPointLightDesc
function XPointLightDesc:new() end


---@public XPointLightDesc_new01
---@param _clrColorVal  XCOLORBASE
---@param _fLuminance number
---@param _vPos XVECTOR3
---@param _fRadius number
---@param _fFallOffExponent number
---@return XPointLightDesc
function XPointLightDesc:new(_clrColorVal, _fLuminance, _vPos, _fRadius, _fFallOffExponent) end


---@class XSpotLightDesc
XSpotLightDesc = {}


---@type XCOLORBASE
XSpotLightDesc.clrColorVal = {}


---@type number
XSpotLightDesc.fLuminance = 0


---@type XVECTOR3
XSpotLightDesc.vPos = {}


---@type XVECTOR3
XSpotLightDesc.vDir = {}


---@type number
XSpotLightDesc.fRadius = 0


---@type number
XSpotLightDesc.fFallOffExponent = 0


---@type number
XSpotLightDesc.fConeInnerAngle = 0


---@type number
XSpotLightDesc.fConeOuterAngle = 0


---@public XSpotLightDesc_new00
---@return XSpotLightDesc
function XSpotLightDesc:new() end


---@public XSpotLightDesc_new01
---@param _clrColorVal  XCOLORBASE
---@param _fLuminance number
---@param _vPos XVECTOR3
---@param _vDir XVECTOR3
---@param _fRadius number
---@param _fFallOffExponent number
---@param _fConeInnerAngle number
---@param _fConeOuterAngle number
---@return XSpotLightDesc
function XSpotLightDesc:new(_clrColorVal, _fLuminance, _vPos, _vDir, _fRadius, _fFallOffExponent, _fConeInnerAngle, _fConeOuterAngle) end


---@class IXLightManager
IXLightManager = {}


---@public 创建方向光,并设置光源颜色、方向和强度
---@param vDir XVECTOR3 平行光的方向，单位化的向量
---@param clrColorVal  XCOLORBASE 光源颜色
---@param fLuminance number 光照强度
---@return IXLightBase 创建的方向光对象指针
function IXLightManager:CreateDirectionLight(vDir, clrColorVal, fLuminance) end


---@public 创建环境光对象，并设置光源颜色和强度
---@param clrColorVal  XCOLORBASE 光源颜色
---@param fLuminance number 光照强度
---@return IXLightBase 创建的环境光对象指针
function IXLightManager:CreateEnvironmentLight(clrColorVal, fLuminance) end


---@public 创建点光源对象，并设置光源参数
---@param desc  XPointLightDesc 点光源参数结构体
---@return IXLightBase
function IXLightManager:CreatePointLight(desc) end


---@public 创建聚光源对象，并设置光源参数
---@param desc  XSpotLightDesc 聚光源参数结构体
---@return IXLightBase
function IXLightManager:CreateSpotLight(desc) end


---@public 释放对应的光源资源
---@param pLight IXLightBase 要释放的光源对象指针
---@return void
function IXLightManager:ReleaseLight(pLight) end


---@class IXLightBase
IXLightBase = {}


---@public 获取光源类型
---@return number 光源类型
function IXLightBase:GetType() end


---@public 获取光源AABB包围盒信息
---@return  XCusAABB 光源AABB包围盒信息
function IXLightBase:GetAABB() end


---@public 获取光源影响半径
---@return number 光源影响半径
function IXLightBase:GetRadius() end


---@public 获取光源颜色
---@return number 光源颜色（XCOLOR格式）
function IXLightBase:GetColor() end


---@public 获取光源颜色
---@return  XCOLORBASE 光源颜色（XCOLORBASE格式）
function IXLightBase:GetColorValue() end


---@public 获取光照强度
---@return number 光照强度
function IXLightBase:GetLuminance() end


---@public 设置光源颜色
---@param clrColorVal  XCOLORBASE 光源颜色
---@return void
function IXLightBase:SetColorValue(clrColorVal) end


---@public 设置光照强度
---@param fLuminance number 光照强度
---@return void
function IXLightBase:SetLuminance(fLuminance) end


---@public 获取光源是否开启
---@return boolean 光源是否开启
function IXLightBase:IsEnable() end


---@public 设置光源是否开启
---@param enabled boolean 光源是否开启
---@return void
function IXLightBase:Enable(enabled) end


---@public 是否投射阴影
---@return boolean 是否投射阴影
function IXLightBase:IsCastShadow() end


---@public 开启或关闭投射阴影
---@param bEnabled boolean 开启或关闭投射阴影
---@return void
function IXLightBase:EnableCastShadow(bEnabled) end


---@public 释放资源
---@return void
function IXLightBase:Release() end


---@class IXDirectionLight : IXLightBase
IXDirectionLight = {}


---@public 获取方向光方向
---@return XVECTOR3 方向光方向向量
function IXDirectionLight:GetDir() end


---@public 设置方向光方向
---@param vDir XVECTOR3 方向光方向向量
---@return void
function IXDirectionLight:SetDir(vDir) end


---@class IXPointLight : IXLightBase
IXPointLight = {}


---@public 获取点光源位置
---@return XVECTOR3 点光源位置
function IXPointLight:GetPos() end


---@public 设置点光源位置
---@param vPos XVECTOR3 点光源位置
---@return void
function IXPointLight:SetPos(vPos) end


---@public 设置点光源影响半径
---@param fRadius number 点光源影响半径
---@return void
function IXPointLight:SetRadius(fRadius) end


---@public 获取光源衰减值
---@return number 光源衰减值
function IXPointLight:GetFallOffExponent() end


---@public 可以设置光源衰减值
---@param fFallOffExponent number 光源衰减值
---@return void
function IXPointLight:SetFallOffExponent(fFallOffExponent) end


---@class IXSpotLight : IXPointLight
IXSpotLight = {}


---@public 获取方向光方向
---@return XVECTOR3 方向光方向向量
function IXSpotLight:GetDir() end


---@public 设置方向光方向
---@param vDir XVECTOR3 方向光方向向量
---@return void
function IXSpotLight:SetDir(vDir) end


---@public 获取聚光源内锥角
---@return number 聚光源内锥角大小
function IXSpotLight:GetConeInnerAngle() end


---@public 设置聚光源内锥角
---@param fAngle number 聚光源内锥角大小
---@return void
function IXSpotLight:SetConeInnerAngle(fAngle) end


---@public 获取聚光源外锥角
---@return number 聚光源外锥角大小
function IXSpotLight:GetConeOuterAngle() end


---@public 设置聚光源外锥角
---@param fAngle number 聚光源外锥角大小
---@return void
function IXSpotLight:SetConeOuterAngle(fAngle) end


